
import pytest

from mercury_engine_data_structures.formats.bsmat import BSMAT
from test.test_lib import parse_build_compare_editor

all_bsmat = [
	"system/engine/surfaces/default.bsmat",
	"system/engine/surfaces/defaultforward.bsmat",
	"system/engine/surfaces/error.bsmat",
	"system/engine/surfaces/mp_aberrationx021.bsmat",
	"system/engine/surfaces/mp_accesspointabstractcubes.bsmat",
	"system/engine/surfaces/mp_accesspointabstractcubesorbital.bsmat",
	"system/engine/surfaces/mp_addblend.bsmat",
	"system/engine/surfaces/mp_animatedblend.bsmat",
	"system/engine/surfaces/mp_animatedmorphballtunnellight.bsmat",
	"system/engine/surfaces/mp_animfresnel.bsmat",
	"system/engine/surfaces/mp_animfresnelaxis.bsmat",
	"system/engine/surfaces/mp_animfresnelaxisnoise.bsmat",
	"system/engine/surfaces/mp_animfresnelaxisnoiseradial.bsmat",
	"system/engine/surfaces/mp_animtextureadd00.bsmat",
	"system/engine/surfaces/mp_animtexturedecal00.bsmat",
	"system/engine/surfaces/mp_animtexturemtl00.bsmat",
	"system/engine/surfaces/mp_aqua_window.bsmat",
	"system/engine/surfaces/mp_atmos_planetzdr.bsmat",
	"system/engine/surfaces/mp_autsharpspikesaura.bsmat",
	"system/engine/surfaces/mp_background.bsmat",
	"system/engine/surfaces/mp_backgroundat.bsmat",
	"system/engine/surfaces/mp_background_fw.bsmat",
	"system/engine/surfaces/mp_background_fw_ibl.bsmat",
	"system/engine/surfaces/mp_basictexmtl00.bsmat",
	"system/engine/surfaces/mp_beacon.bsmat",
	"system/engine/surfaces/mp_bigxtranslucent.bsmat",
	"system/engine/surfaces/mp_billboardmtl00.bsmat",
	"system/engine/surfaces/mp_billboardmtl01.bsmat",
	"system/engine/surfaces/mp_blackdoorfr_fw.bsmat",
	"system/engine/surfaces/mp_blend.bsmat",
	"system/engine/surfaces/mp_blendanimquads.bsmat",
	"system/engine/surfaces/mp_blendconstantcolor.bsmat",
	"system/engine/surfaces/mp_blendconstantcolor_outline.bsmat",
	"system/engine/surfaces/mp_blendconstantcolor_texvertexcolor.bsmat",
	"system/engine/surfaces/mp_blendconstantcolor_vertexcolor.bsmat",
	"system/engine/surfaces/mp_blendselfillumtex.bsmat",
	"system/engine/surfaces/mp_blendshadow.bsmat",
	"system/engine/surfaces/mp_blenduvdisplacement.bsmat",
	"system/engine/surfaces/mp_blenduvdisplacement_nofog.bsmat",
	"system/engine/surfaces/mp_blendvertexanimfluid.bsmat",
	"system/engine/surfaces/mp_blendvertexanimfluidmtl01_nonormal.bsmat",
	"system/engine/surfaces/mp_blendvertexanimfluid_coloranim.bsmat",
	"system/engine/surfaces/mp_blendvertexanimfluid_coloranim_nonormal.bsmat",
	"system/engine/surfaces/mp_blendvertexanimsoftbody.bsmat",
	"system/engine/surfaces/mp_blendvertexanimsprites.bsmat",
	"system/engine/surfaces/mp_blinkblend.bsmat",
	"system/engine/surfaces/mp_blinkerpbr.bsmat",
	"system/engine/surfaces/mp_breakeable_organic.bsmat",
	"system/engine/surfaces/mp_bubblespipe.bsmat",
	"system/engine/surfaces/mp_bubblespipeheight.bsmat",
	"system/engine/surfaces/mp_bubblespipe_baselab.bsmat",
	"system/engine/surfaces/mp_bubbles_behindaqua.bsmat",
	"system/engine/surfaces/mp_caustics01.bsmat",
	"system/engine/surfaces/mp_charactermtl00.bsmat",
	"system/engine/surfaces/mp_checker.bsmat",
	"system/engine/surfaces/mp_chozocommander.bsmat",
	"system/engine/surfaces/mp_chozosoldierblade.bsmat",
	"system/engine/surfaces/mp_chozowarriormudbeam.bsmat",
	"system/engine/surfaces/mp_chozowarriormudbeamsplash.bsmat",
	"system/engine/surfaces/mp_chozowarriormudwave.bsmat",
	"system/engine/surfaces/mp_chozowarriortentacle.bsmat",
	"system/engine/surfaces/mp_chozozombie.bsmat",
	"system/engine/surfaces/mp_chozozombiebase.bsmat",
	"system/engine/surfaces/mp_chozozombietrail.bsmat",
	"system/engine/surfaces/mp_chozozombietrail_close.bsmat",
	"system/engine/surfaces/mp_circlemtl00.bsmat",
	"system/engine/surfaces/mp_cloudlightning.bsmat",
	"system/engine/surfaces/mp_conequad.bsmat",
	"system/engine/surfaces/mp_conequad_cinematicas.bsmat",
	"system/engine/surfaces/mp_cooldown.bsmat",
	"system/engine/surfaces/mp_cooldownfresnel.bsmat",
	"system/engine/surfaces/mp_cooldownxbosslavacarpet.bsmat",
	"system/engine/surfaces/mp_cooldownxbosslavacolumn.bsmat",
	"system/engine/surfaces/mp_cooldownxbosslavafloor.bsmat",
	"system/engine/surfaces/mp_cooldownxbosslavawall.bsmat",
	"system/engine/surfaces/mp_cooldownxfanmud.bsmat",
	"system/engine/surfaces/mp_cooldown_arms.bsmat",
	"system/engine/surfaces/mp_cooldown_arms_dissolve.bsmat",
	"system/engine/surfaces/mp_cooldown_fog_grab.bsmat",
	"system/engine/surfaces/mp_cooldown_fog_intro.bsmat",
	"system/engine/surfaces/mp_cooldown_head.bsmat",
	"system/engine/surfaces/mp_crystal_map.bsmat",
	"system/engine/surfaces/mp_crystal_map_copy.bsmat",
	"system/engine/surfaces/mp_debug.bsmat",
	"system/engine/surfaces/mp_debugdarkgrey.bsmat",
	"system/engine/surfaces/mp_decal000.bsmat",
	"system/engine/surfaces/mp_decalanim00.bsmat",
	"system/engine/surfaces/mp_decalmap00.bsmat",
	"system/engine/surfaces/mp_decalmap00_anim.bsmat",
	"system/engine/surfaces/mp_decalmapnobc00.bsmat",
	"system/engine/surfaces/mp_decalmapnobc00_dissolve.bsmat",
	"system/engine/surfaces/mp_decalmapnobcnoat000.bsmat",
	"system/engine/surfaces/mp_deferredbillboardmtl00.bsmat",
	"system/engine/surfaces/mp_deferredbillboardmtl01.bsmat",
	"system/engine/surfaces/mp_displacefresnel.bsmat",
	"system/engine/surfaces/mp_disruptedtile.bsmat",
	"system/engine/surfaces/mp_dissolvecubesemmy.bsmat",
	"system/engine/surfaces/mp_dissolvedircolorinternalmtl00.bsmat",
	"system/engine/surfaces/mp_dissolvedirmtl00.bsmat",
	"system/engine/surfaces/mp_dissolveemmymtl00.bsmat",
	"system/engine/surfaces/mp_dissolvemtl00.bsmat",
	"system/engine/surfaces/mp_distortion.bsmat",
	"system/engine/surfaces/mp_distortionblend.bsmat",
	"system/engine/surfaces/mp_distortionmeshmtl00.bsmat",
	"system/engine/surfaces/mp_distortionmeshmtl01.bsmat",
	"system/engine/surfaces/mp_distortionmeshopaquemtl00.bsmat",
	"system/engine/surfaces/mp_distortionopaque.bsmat",
	"system/engine/surfaces/mp_dooremmy.bsmat",
	"system/engine/surfaces/mp_dooremmy_cinematic.bsmat",
	"system/engine/surfaces/mp_doorwavebeam.bsmat",
	"system/engine/surfaces/mp_door_fog.bsmat",
	"system/engine/surfaces/mp_droplifecinematicmtl00.bsmat",
	"system/engine/surfaces/mp_droplifemtl00.bsmat",
	"system/engine/surfaces/mp_emmyalphatestmtl00.bsmat",
	"system/engine/surfaces/mp_emmyconepatrolsearch.bsmat",
	"system/engine/surfaces/mp_emmymtl00.bsmat",
	"system/engine/surfaces/mp_emmyzoneletters00.bsmat",
	"system/engine/surfaces/mp_fedshiphologram.bsmat",
	"system/engine/surfaces/mp_fireoverwall.bsmat",
	"system/engine/surfaces/mp_flipbookmanual.bsmat",
	"system/engine/surfaces/mp_flipbooktexturemtl00.bsmat",
	"system/engine/surfaces/mp_flowadditivealphaclipmtl00.bsmat",
	"system/engine/surfaces/mp_foglayers00.bsmat",
	"system/engine/surfaces/mp_forwardbillboardmtl00.bsmat",
	"system/engine/surfaces/mp_fresnelmtl00.bsmat",
	"system/engine/surfaces/mp_fresnelnoise.bsmat",
	"system/engine/surfaces/mp_frozenstate.bsmat",
	"system/engine/surfaces/mp_frozen_glass.bsmat",
	"system/engine/surfaces/mp_fxabovewatermtl00.bsmat",
	"system/engine/surfaces/mp_fxbarrieraura.bsmat",
	"system/engine/surfaces/mp_fxchozocommanderlaseraperture.bsmat",
	"system/engine/surfaces/mp_fxdamage.bsmat",
	"system/engine/surfaces/mp_fxflipbookalphatimemtl00.bsmat",
	"system/engine/surfaces/mp_fxflipbookalphatimemtl01.bsmat",
	"system/engine/surfaces/mp_fxfresnelmtl00.bsmat",
	"system/engine/surfaces/mp_fxglowingcracks.bsmat",
	"system/engine/surfaces/mp_fxgradientmtl00.bsmat",
	"system/engine/surfaces/mp_fxhologram.bsmat",
	"system/engine/surfaces/mp_fxhologrammtl00.bsmat",
	"system/engine/surfaces/mp_fxmeshmtl00.bsmat",
	"system/engine/surfaces/mp_fxmetroinization.bsmat",
	"system/engine/surfaces/mp_fxmodelmtl00.bsmat",
	"system/engine/surfaces/mp_fxmodelmtl01.bsmat",
	"system/engine/surfaces/mp_fxmodelmtl01_fire.bsmat",
	"system/engine/surfaces/mp_fxmodelmtl02.bsmat",
	"system/engine/surfaces/mp_fxmodelxt1mtl00.bsmat",
	"system/engine/surfaces/mp_fxmtl00.bsmat",
	"system/engine/surfaces/mp_fxmtl00opaque.bsmat",
	"system/engine/surfaces/mp_fxmtl00samusmask.bsmat",
	"system/engine/surfaces/mp_fxpolyps.bsmat",
	"system/engine/surfaces/mp_fxsaturate.bsmat",
	"system/engine/surfaces/mp_fxsoftblendmtl00.bsmat",
	"system/engine/surfaces/mp_fxsoftblendtwotexmtl00.bsmat",
	"system/engine/surfaces/mp_fxsumchannelsmtl00.bsmat",
	"system/engine/surfaces/mp_fxtrail.bsmat",
	"system/engine/surfaces/mp_fxtraileffectmtl00.bsmat",
	"system/engine/surfaces/mp_fxtwotexmtl00.bsmat",
	"system/engine/surfaces/mp_fxtwotexsimplealphatimemtl00.bsmat",
	"system/engine/surfaces/mp_fxunderwatermtl00.bsmat",
	"system/engine/surfaces/mp_fxuvclamp.bsmat",
	"system/engine/surfaces/mp_fxuvdisplacementlitemtl00.bsmat",
	"system/engine/surfaces/mp_fxuvdisplacementmtl00.bsmat",
	"system/engine/surfaces/mp_fxuvdisplacementmtl00softblend.bsmat",
	"system/engine/surfaces/mp_fxuvdisplacementmtl01.bsmat",
	"system/engine/surfaces/mp_fxuvdisplacementnotimemtl00.bsmat",
	"system/engine/surfaces/mp_fxuvdisplacementnotimemtl01.bsmat",
	"system/engine/surfaces/mp_fxuvlocaldisplacementpolar.bsmat",
	"system/engine/surfaces/mp_fxuvwnoise.bsmat",
	"system/engine/surfaces/mp_fxuvwnoisemulvcolor.bsmat",
	"system/engine/surfaces/mp_fxwatervalve.bsmat",
	"system/engine/surfaces/mp_gasleak.bsmat",
	"system/engine/surfaces/mp_glass.bsmat",
	"system/engine/surfaces/mp_glassenergyfield.bsmat",
	"system/engine/surfaces/mp_glassenergyfield_blackout.bsmat",
	"system/engine/surfaces/mp_glassmaps.bsmat",
	"system/engine/surfaces/mp_glassmaps_cube.bsmat",
	"system/engine/surfaces/mp_glassmaps_dissolve.bsmat",
	"system/engine/surfaces/mp_glassmaps_plane.bsmat",
	"system/engine/surfaces/mp_glassmaps_vc.bsmat",
	"system/engine/surfaces/mp_glassmaps_white_cube.bsmat",
	"system/engine/surfaces/mp_glass_item.bsmat",
	"system/engine/surfaces/mp_glass_ship.bsmat",
	"system/engine/surfaces/mp_glass_strongreaction.bsmat",
	"system/engine/surfaces/mp_gooplot.bsmat",
	"system/engine/surfaces/mp_gooplotsplash.bsmat",
	"system/engine/surfaces/mp_gooplotsplashvertexcolor.bsmat",
	"system/engine/surfaces/mp_gooplottail.bsmat",
	"system/engine/surfaces/mp_guidemaplight.bsmat",
	"system/engine/surfaces/mp_hair.bsmat",
	"system/engine/surfaces/mp_heatdistorsion.bsmat",
	"system/engine/surfaces/mp_hecathoncone.bsmat",
	"system/engine/surfaces/mp_hologram.bsmat",
	"system/engine/surfaces/mp_hologram_atlas.bsmat",
	"system/engine/surfaces/mp_hologram_blackout.bsmat",
	"system/engine/surfaces/mp_horizontalfresnel.bsmat",
	"system/engine/surfaces/mp_hydrogiga.bsmat",
	"system/engine/surfaces/mp_hydrogiga_fw.bsmat",
	"system/engine/surfaces/mp_hydrogiga_transition.bsmat",
	"system/engine/surfaces/mp_hyperbeamblock.bsmat",
	"system/engine/surfaces/mp_hyperbeamimpactplane.bsmat",
	"system/engine/surfaces/mp_ice.bsmat",
	"system/engine/surfaces/mp_iceflea.bsmat",
	"system/engine/surfaces/mp_ice_blend.bsmat",
	"system/engine/surfaces/mp_ice_interior.bsmat",
	"system/engine/surfaces/mp_kraid.bsmat",
	"system/engine/surfaces/mp_kraidboss_fog_intro.bsmat",
	"system/engine/surfaces/mp_lava.bsmat",
	"system/engine/surfaces/mp_lavacore.bsmat",
	"system/engine/surfaces/mp_lavafall.bsmat",
	"system/engine/surfaces/mp_lavafront.bsmat",
	"system/engine/surfaces/mp_lavageneric.bsmat",
	"system/engine/surfaces/mp_lava_cooldownboss.bsmat",
	"system/engine/surfaces/mp_lava_kraidboss_death.bsmat",
	"system/engine/surfaces/mp_levelemmy.bsmat",
	"system/engine/surfaces/mp_lightningmtl00.bsmat",
	"system/engine/surfaces/mp_lightningmtl01.bsmat",
	"system/engine/surfaces/mp_lightningmtl02.bsmat",
	"system/engine/surfaces/mp_lightningsimple.bsmat",
	"system/engine/surfaces/mp_lightningstroke.bsmat",
	"system/engine/surfaces/mp_lightshaft.bsmat",
	"system/engine/surfaces/mp_lightshaft_lamps.bsmat",
	"system/engine/surfaces/mp_lightshaft_simple.bsmat",
	"system/engine/surfaces/mp_lightshaft_simple_vc.bsmat",
	"system/engine/surfaces/mp_lightshaft_simple_vcsoft.bsmat",
	"system/engine/surfaces/mp_lightshaft_simple_vctex.bsmat",
	"system/engine/surfaces/mp_lockonmissilemarker.bsmat",
	"system/engine/surfaces/mp_lockonmissilemarkerbloom.bsmat",
	"system/engine/surfaces/mp_magnetsurface.bsmat",
	"system/engine/surfaces/mp_magnetsurface_static.bsmat",
	"system/engine/surfaces/mp_manicmtl00.bsmat",
	"system/engine/surfaces/mp_minixbillboardmtl00.bsmat",
	"system/engine/surfaces/mp_mipmap.bsmat",
	"system/engine/surfaces/mp_missiledoordesintegration.bsmat",
	"system/engine/surfaces/mp_missiledoorenergydesintegration.bsmat",
	"system/engine/surfaces/mp_missiledoorsmokedesintegration.bsmat",
	"system/engine/surfaces/mp_morphballtunnellight.bsmat",
	"system/engine/surfaces/mp_moss.bsmat",
	"system/engine/surfaces/mp_moss_blended.bsmat",
	"system/engine/surfaces/mp_mountainhologram.bsmat",
	"system/engine/surfaces/mp_nebula_planetzdr.bsmat",
	"system/engine/surfaces/mp_ocean.bsmat",
	"system/engine/surfaces/mp_ocean_baselab.bsmat",
	"system/engine/surfaces/mp_ocean_left.bsmat",
	"system/engine/surfaces/mp_omegamtl00_00.bsmat",
	"system/engine/surfaces/mp_omegamtl00_01.bsmat",
	"system/engine/surfaces/mp_omnithon.bsmat",
	"system/engine/surfaces/mp_onionmtl_00.bsmat",
	"system/engine/surfaces/mp_onionmtl_01.bsmat",
	"system/engine/surfaces/mp_opaque.bsmat",
	"system/engine/surfaces/mp_opaquealphatest.bsmat",
	"system/engine/surfaces/mp_opaquealphatest_dissolve.bsmat",
	"system/engine/surfaces/mp_opaqueblend.bsmat",
	"system/engine/surfaces/mp_opaqueburn.bsmat",
	"system/engine/surfaces/mp_opaqueconstantcolor.bsmat",
	"system/engine/surfaces/mp_opaqueconstantcolorfw.bsmat",
	"system/engine/surfaces/mp_opaqueconstantselfillum_pulse.bsmat",
	"system/engine/surfaces/mp_opaquedissolve.bsmat",
	"system/engine/surfaces/mp_opaquedissolvevertexcolor.bsmat",
	"system/engine/surfaces/mp_opaquefrostbite.bsmat",
	"system/engine/surfaces/mp_opaquemaps.bsmat",
	"system/engine/surfaces/mp_opaquemapsalphatest.bsmat",
	"system/engine/surfaces/mp_opaquemapsdecal.bsmat",
	"system/engine/surfaces/mp_opaquemaps_constant_selfilum.bsmat",
	"system/engine/surfaces/mp_opaquemaps_dissolve.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simple.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simplenovc.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simplevcatt.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simple_dissolve.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simple_dissolve_z.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simple_fw.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simple_fw_dissolve.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simple_nonm.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simple_nonm_dissolve.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simple_rough.bsmat",
	"system/engine/surfaces/mp_opaquemaps_simple_selfilum.bsmat",
	"system/engine/surfaces/mp_opaquemaps_vc.bsmat",
	"system/engine/surfaces/mp_opaquemaps_vc_fw.bsmat",
	"system/engine/surfaces/mp_opaquemtl01.bsmat",
	"system/engine/surfaces/mp_opaqueradiusdissolve.bsmat",
	"system/engine/surfaces/mp_opaquetint.bsmat",
	"system/engine/surfaces/mp_opaqueuvdisplace.bsmat",
	"system/engine/surfaces/mp_opaqueuvrotate.bsmat",
	"system/engine/surfaces/mp_opaque_constant_selfillum_damage.bsmat",
	"system/engine/surfaces/mp_opaque_constant_selfilum.bsmat",
	"system/engine/surfaces/mp_opaque_constant_selfilum_dissolve.bsmat",
	"system/engine/surfaces/mp_opaque_custom_reflections.bsmat",
	"system/engine/surfaces/mp_opaque_damage.bsmat",
	"system/engine/surfaces/mp_opaque_dispnm.bsmat",
	"system/engine/surfaces/mp_opaque_nodepthtint.bsmat",
	"system/engine/surfaces/mp_opaque_nodepthtint_vc.bsmat",
	"system/engine/surfaces/mp_opaque_planetzdr.bsmat",
	"system/engine/surfaces/mp_opaque_planetzdrend.bsmat",
	"system/engine/surfaces/mp_opaque_pulse.bsmat",
	"system/engine/surfaces/mp_opaque_rainonsurface.bsmat",
	"system/engine/surfaces/mp_opaque_simple_uvdisplace.bsmat",
	"system/engine/surfaces/mp_opaque_spheremask.bsmat",
	"system/engine/surfaces/mp_opticalcamo.bsmat",
	"system/engine/surfaces/mp_opticalcamoscorpius.bsmat",
	"system/engine/surfaces/mp_orbitalroombloomplane.bsmat",
	"system/engine/surfaces/mp_orbitalroomdissolve.bsmat",
	"system/engine/surfaces/mp_orbitalroomdissolvevertical.bsmat",
	"system/engine/surfaces/mp_orbitalroomexpansivewave.bsmat",
	"system/engine/surfaces/mp_overdraw.bsmat",
	"system/engine/surfaces/mp_planesonar.bsmat",
	"system/engine/surfaces/mp_postpro.bsmat",
	"system/engine/surfaces/mp_postpro_planetzdr.bsmat",
	"system/engine/surfaces/mp_pouringwater.bsmat",
	"system/engine/surfaces/mp_powerup.bsmat",
	"system/engine/surfaces/mp_prj_blend_decal000.bsmat",
	"system/engine/surfaces/mp_prj_deferred_decal000.bsmat",
	"system/engine/surfaces/mp_purefresnel.bsmat",
	"system/engine/surfaces/mp_purefresnelvc.bsmat",
	"system/engine/surfaces/mp_quetzoawings.bsmat",
	"system/engine/surfaces/mp_railmagnet.bsmat",
	"system/engine/surfaces/mp_rain.bsmat",
	"system/engine/surfaces/mp_rainripplemtl00.bsmat",
	"system/engine/surfaces/mp_raintrail.bsmat",
	"system/engine/surfaces/mp_reflection.bsmat",
	"system/engine/surfaces/mp_rinkadecoration.bsmat",
	"system/engine/surfaces/mp_rinkasolid.bsmat",
	"system/engine/surfaces/mp_rinkatrail.bsmat",
	"system/engine/surfaces/mp_rocks_planetzdr.bsmat",
	"system/engine/surfaces/mp_rodutuk.bsmat",
	"system/engine/surfaces/mp_sabotorububbles.bsmat",
	"system/engine/surfaces/mp_saltrock.bsmat",
	"system/engine/surfaces/mp_samuslaser.bsmat",
	"system/engine/surfaces/mp_samusmtl00.bsmat",
	"system/engine/surfaces/mp_samuspbr.bsmat",
	"system/engine/surfaces/mp_savefresnel.bsmat",
	"system/engine/surfaces/mp_scorpius.bsmat",
	"system/engine/surfaces/mp_scorpiusdissolve.bsmat",
	"system/engine/surfaces/mp_scorpiusdissolveball.bsmat",
	"system/engine/surfaces/mp_scorpiusspit.bsmat",
	"system/engine/surfaces/mp_scorpiustailball.bsmat",
	"system/engine/surfaces/mp_scorpiustoxicfog.bsmat",
	"system/engine/surfaces/mp_scorpius_death_floor_fog.bsmat",
	"system/engine/surfaces/mp_selfilum.bsmat",
	"system/engine/surfaces/mp_selfilumblink_fw.bsmat",
	"system/engine/surfaces/mp_selfilumlineartransition.bsmat",
	"system/engine/surfaces/mp_selfilumpulse_fw.bsmat",
	"system/engine/surfaces/mp_selfilumtex_fw.bsmat",
	"system/engine/surfaces/mp_selfilum_cc_fw.bsmat",
	"system/engine/surfaces/mp_selfilum_fw.bsmat",
	"system/engine/surfaces/mp_selfilum_fw_dissolve.bsmat",
	"system/engine/surfaces/mp_selfilum_fw_nofog.bsmat",
	"system/engine/surfaces/mp_selfilum_vc_fw.bsmat",
	"system/engine/surfaces/mp_shakernaut.bsmat",
	"system/engine/surfaces/mp_shiphudhologram.bsmat",
	"system/engine/surfaces/mp_shiphudhologram_scaline.bsmat",
	"system/engine/surfaces/mp_shippropulsor_planetzdr.bsmat",
	"system/engine/surfaces/mp_skybox.bsmat",
	"system/engine/surfaces/mp_sonar.bsmat",
	"system/engine/surfaces/mp_sonarcube.bsmat",
	"system/engine/surfaces/mp_sonar_breakeable_organic.bsmat",
	"system/engine/surfaces/mp_sonar_sphere.bsmat",
	"system/engine/surfaces/mp_splashwater_anim.bsmat",
	"system/engine/surfaces/mp_stained_glass.bsmat",
	"system/engine/surfaces/mp_stained_glass_fog.bsmat",
	"system/engine/surfaces/mp_standardpbr.bsmat",
	"system/engine/surfaces/mp_standardpbralpha.bsmat",
	"system/engine/surfaces/mp_standardpbrtile.bsmat",
	"system/engine/surfaces/mp_standardpbr_dissolve.bsmat",
	"system/engine/surfaces/mp_starfield_planetzdr.bsmat",
	"system/engine/surfaces/mp_stargateportal.bsmat",
	"system/engine/surfaces/mp_statelessparticles_amoeba00.bsmat",
	"system/engine/surfaces/mp_statelessparticles_ashes00.bsmat",
	"system/engine/surfaces/mp_statelessparticles_blossomparticles01.bsmat",
	"system/engine/surfaces/mp_statelessparticles_dust00.bsmat",
	"system/engine/surfaces/mp_statelessparticles_dust00_lite.bsmat",
	"system/engine/surfaces/mp_statelessparticles_dust01.bsmat",
	"system/engine/surfaces/mp_statelessparticles_dustcheap.bsmat",
	"system/engine/surfaces/mp_statelessparticles_fireflies00.bsmat",
	"system/engine/surfaces/mp_statelessparticles_generic00.bsmat",
	"system/engine/surfaces/mp_statelessparticles_magma01.bsmat",
	"system/engine/surfaces/mp_statelessparticles_magma02.bsmat",
	"system/engine/surfaces/mp_statelessparticles_magma_universal.bsmat",
	"system/engine/surfaces/mp_statelessparticles_shockwave00.bsmat",
	"system/engine/surfaces/mp_statelessparticles_snow01.bsmat",
	"system/engine/surfaces/mp_statelessparticles_solid_billboard.bsmat",
	"system/engine/surfaces/mp_statelessparticles_spores00.bsmat",
	"system/engine/surfaces/mp_statelessparticles_unified.bsmat",
	"system/engine/surfaces/mp_statelessparticles_waterfallmist.bsmat",
	"system/engine/surfaces/mp_stencil_test.bsmat",
	"system/engine/surfaces/mp_surfaceanimfresnel.bsmat",
	"system/engine/surfaces/mp_teleportfresnel.bsmat",
	"system/engine/surfaces/mp_texalphamtl00.bsmat",
	"system/engine/surfaces/mp_texmtl00.bsmat",
	"system/engine/surfaces/mp_thermalstate.bsmat",
	"system/engine/surfaces/mp_tornadofire.bsmat",
	"system/engine/surfaces/mp_trailproc.bsmat",
	"system/engine/surfaces/mp_translucent.bsmat",
	"system/engine/surfaces/mp_translucent_dissolve.bsmat",
	"system/engine/surfaces/mp_translucent_fog.bsmat",
	"system/engine/surfaces/mp_vcminimaproom.bsmat",
	"system/engine/surfaces/mp_vcolor.bsmat",
	"system/engine/surfaces/mp_vcolortexmtl00.bsmat",
	"system/engine/surfaces/mp_velvet.bsmat",
	"system/engine/surfaces/mp_velvet_localuvs.bsmat",
	"system/engine/surfaces/mp_vertexoffsetanim_opaquesimple.bsmat",
	"system/engine/surfaces/mp_vignetteblend.bsmat",
	"system/engine/surfaces/mp_vignettemtl00.bsmat",
	"system/engine/surfaces/mp_vignettemtl00_1.bsmat",
	"system/engine/surfaces/mp_vignettemtl00_31.bsmat",
	"system/engine/surfaces/mp_vignettemtl00_310.bsmat",
	"system/engine/surfaces/mp_vignettemtl01.bsmat",
	"system/engine/surfaces/mp_vignetteopaque.bsmat",
	"system/engine/surfaces/mp_visor_glass.bsmat",
	"system/engine/surfaces/mp_vtbackground.bsmat",
	"system/engine/surfaces/mp_vtbackground_aqua.bsmat",
	"system/engine/surfaces/mp_vtbackground_nofog.bsmat",
	"system/engine/surfaces/mp_vtbackground_uvscroll.bsmat",
	"system/engine/surfaces/mp_vtbackground_uvscroll_nofog.bsmat",
	"system/engine/surfaces/mp_water.bsmat",
	"system/engine/surfaces/mp_waterdripping.bsmat",
	"system/engine/surfaces/mp_waterfall.bsmat",
	"system/engine/surfaces/mp_waterfallmaps.bsmat",
	"system/engine/surfaces/mp_waterfront.bsmat",
	"system/engine/surfaces/mp_waterfront_simple.bsmat",
	"system/engine/surfaces/mp_waterfront_simple_mask.bsmat",
	"system/engine/surfaces/mp_waterfrozen.bsmat",
	"system/engine/surfaces/mp_waterfrozenfront.bsmat",
	"system/engine/surfaces/mp_watertexture.bsmat",
	"system/engine/surfaces/mp_watervertexanimfluid.bsmat",
	"system/engine/surfaces/mp_watervertexanimfluidblend.bsmat",
	"system/engine/surfaces/mp_watervertexanimfluidlite.bsmat",
	"system/engine/surfaces/mp_watervertexanimfluidmtl01.bsmat",
	"system/engine/surfaces/mp_watervertexanimfluid_fog.bsmat",
	"system/engine/surfaces/mp_waterwave_opaque.bsmat",
	"system/engine/surfaces/mp_waterwires.bsmat",
	"system/engine/surfaces/mp_water_droplets.bsmat",
	"system/engine/surfaces/mp_water_effluent.bsmat",
	"system/engine/surfaces/mp_water_surface.bsmat",
	"system/engine/surfaces/mp_water_surface_opaque.bsmat",
	"system/engine/surfaces/mp_xparasite.bsmat",
	"system/engine/surfaces/mp_xtransformation_liquishthing.bsmat",
	"system/engine/surfaces/mp_xtransformation_liquishthing_commanderx.bsmat",
	"system/engine/surfaces/mp_xtransformation_splashimpact.bsmat",
	"system/engine/surfaces/mp_xtransformation_whirlwind.bsmat",
	"system/minimap/icons/icons.bsmat",
	"system/minimap/icons/icons_nomips.bsmat",
	"system/minimap/icons/overlay.bsmat",
	"system/minimap/maproom/maproom.bsmat",
	"actors/characters/emmyproto/models/imats/emmyproto_black.bsmat",
	"actors/characters/emmyproto/models/imats/emmyproto_white.bsmat",
	"actors/characters/emmycave/models/imats/emmycave_white_body.bsmat",
	"actors/characters/emmycave/models/imats/emmycave_black.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_mapmodel04_mp_opaqueblend_02.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_mapmodel09_mp_opaqueblend_02.bsmat",
	"actors/props/breakablecave003/fx/imats/material_breakablecave.bsmat",
	"actors/props/platformcavewaterb/fx/imats/watervalve_breakloop_material.bsmat",
	"maps/fx/waterstream/imats/waterstream01_water.bsmat",
	"actors/props/doorcentralunit/models/imats/doorcentralunit_mp_emmymtl00_00.bsmat",
	"maps/fx/waterstream/imats/waterstreamforest01_water.bsmat",
	"maps/fx/waterstream/imats/waterstream00_water.bsmat",
	"actors/props/platformcavewaterb/fx/imats/watervalve_initbreakloop_material.bsmat",
	"actors/props/breakablecave008/fx/imats/water_material.bsmat",
	"actors/characters/emmycave/models/imats/emmycave_white_head.bsmat",
	"maps/fx/bigwaterstream_cave/fx/imats/watervalveloop_02_material.bsmat",
	"maps/fx/bigwaterstream_cave/fx/imats/watervalveloop_material.bsmat",
	"actors/props/platformcavewaterb/fx/imats/watervalveinit_material.bsmat",
	"actors/props/platformcavewaterb/fx/imats/watervalveloop_material.bsmat",
	"actors/props/platformcavewaterb/fx/imats/watervalveend_material.bsmat",
	"maps/fx/waterstream/imats/waterstream00_splash.bsmat",
	"maps/fx/splashes/imats/splashes_waterfall_1x_cube_material.bsmat",
	"maps/fx/splashes/imats/splashes_waterfall_1x3_material.bsmat",
	"maps/fx/splashes/imats/splashes_waterfall_1x_material.bsmat",
	"maps/fx/splashes/imats/splashes_waterfall_material.bsmat",
	"maps/fx/emmymist02/fx/imats/emmymist02_material.bsmat",
	"maps/fx/emmyventilationgridgas00/fx/imats/emmyventilationgridgas01_material.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samusfacial_eyes.bsmat",
	"actors/props/platformtrapgrapple5right/models/imats/platformtrapgrapple5right_material.bsmat",
	"maps/fx/emmymist01/fx/imats/emmymist01_left_material.bsmat",
	"actors/spawnpoints/spawnpointcaterzillametallic/models/imats/spawnpointcaterzillametallic_spawnpointcaterzillametallic.bsmat",
	"actors/props/weightactivatedplatform_valve/models/imats/weightactivatedplatform_valve_material.bsmat",
	"actors/props/weightactivatedplatform_elevator_frozen/models/imats/wap_elevator_frozen_elevatorfrozen.bsmat",
	"maps/fx/effectcold02/fx/imats/effectcold02_material.bsmat",
	"actors/props/weightactivatedplatform_map/models/imats/weightactivatedplatform_map_material.bsmat",
	"actors/items/item_cube/model/imats/itemcube_cube.bsmat",
	"actors/characters/hecathon/fx/imats/disruptedtile_material_mesh1.bsmat",
	"actors/characters/hecathon/fx/imats/disruptedtile_material_mesh2.bsmat",
	"actors/props/weightactivatedplatform_access/models/imats/weightactivatedplatform_access_material01.bsmat",
	"actors/props/weightactivatedplatform_valve/models/imats/weightactivatedplatform_mp_opaque_01.bsmat",
	"actors/spawnpoints/spawnpointrockdivermetallic/models/imats/spawnpointrockdivermetallic_mp_opaque_01.bsmat",
	"cutscenes/0057scorpiusdeath/fx/imats/ashesparticles3_anim_material.bsmat",
	"cutscenes/0057scorpiusdeath/fx/imats/ashesparticles4_anim_material.bsmat",
	"actors/spawnpoints/spawnpointcaterzilla/models/imats/spawnpointcaterzilla_material.bsmat",
	"actors/props/weightactivatedplatform_total/models/imats/platform_totalrecharge_totalrecharge.bsmat",
	"actors/props/doorpresencepresence/models/imats/doorpresencepresence_mat02.bsmat",
	"actors/props/doorframepresence/models/imats/doorframepresence_mat02.bsmat",
	"actors/props/doorpresenceframe/models/imats/doorpresenceframe_mat02.bsmat",
	"actors/props/weightactivatedplatform_energy/models/imats/platform_energy_recharge.bsmat",
	"actors/props/weightactivatedplatform_save/models/imats/weightactivatedplatform_save_material.bsmat",
	"maps/fx/dustcorner00/fx/imats/dustcorner00_center02_material.bsmat",
	"maps/fx/dustcorner00/fx/imats/dustcorner00_center03_material.bsmat",
	"maps/fx/effectcold01/fx/imats/effectcold01_material.bsmat",
	"actors/props/weightactivatedplatform_ammo/models/imats/platform_ammo_recharge.bsmat",
	"actors/props/doorpresencepresence/models/imats/doorpresencepresence_mat01.bsmat",
	"maps/fx/dustcorner00/fx/imats/dustcorner00_center_material.bsmat",
	"maps/fx/dustcorner00/fx/imats/dustcorner00_right_material.bsmat",
	"maps/fx/dustcorner00/fx/imats/dustcorner00_left_material.bsmat",
	"actors/props/doorframepresence/models/imats/doorframepresence_mat01.bsmat",
	"actors/props/doorpresenceframe/models/imats/doorpresenceframe_mat01.bsmat",
	"actors/spawnpoints/spawnpointautool/models/imats/dockautool_material01.bsmat",
	"actors/props/doorshieldsupermissile/models/imats/doorshieldsupermissile_mp_opaque_01.bsmat",
	"actors/props/weightactivatedplatform_elevator_frozen/models/imats/wap_elevator_frozen_ice.bsmat",
	"maps/fx/aquabubbles/imats/aquabubbles1_aquabubbles01.bsmat",
	"maps/fx/aquabubbles/imats/aquabubbles_aquabubbles01.bsmat",
	"maps/fx/aquabubbles/imats/aquabubbles_aquabubbles02.bsmat",
	"maps/fx/aquabubbles/imats/aquabubbles1_aquabubbles02.bsmat",
	"maps/fx/dustdebris/fx/imats/dustdebris01_material.bsmat",
	"maps/fx/dustdebris/fx/imats/dustdebris02_material.bsmat",
	"actors/characters/centralunitcave/models/imats/centralunitcavebroken_mp_opaque_constant_selfilum_01.bsmat",
	"actors/props/totalrechargestation/models/imats/totalrechargestation_body.bsmat",
	"actors/props/totalrechargestation/models/imats/totalrechargestation_eyes.bsmat",
	"actors/props/burnertrapcav01/models/imats/burnertrapcav01_material.bsmat",
	"actors/props/doorcentralunit/models/imats/doorcentralunit_mp_opaque_01.bsmat",
	"actors/props/steammag01/models/imats/steammag01_material.bsmat",
	"actors/props/totalrechargestation/models/imats/totalrechargestation_base.bsmat",
	"actors/characters/centralunitcave/models/imats/centralunitcave_ojo.bsmat",
	"actors/characters/emmyproto/models/imats/emmyproto_black_eye.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samusfacial_helmet.bsmat",
	"actors/props/weightactivatedplatform_elevator/models/imats/platform_elevator_elevator.bsmat",
	"actors/characters/emmycave/models/imats/emmycave_black_eye.bsmat",
	"actors/props/box_wide_cv_001/models/imats/box_wide_cv_001_mat01box.bsmat",
	"actors/props/doorclosedgrapple/models/imats/doorclosedgrapple_grapple01.bsmat",
	"actors/props/doorclosedgrapple/models/imats/doorclosedgrapple_grapple02.bsmat",
	"actors/props/stopstation_autool/models/imats/stopstation_autool_material.bsmat",
	"actors/spawnpoints/spawnpointrockdiver/models/imats/spawnpointrockdiver_mp_opaque_01.bsmat",
	"actors/props/box_grapple_cv_001/models/imats/box_grapple_cv_001_mat01.bsmat",
	"actors/props/box_grapple_cv_001/models/imats/box_grapple_cv_001_mat02.bsmat",
	"actors/props/doorgrapplegrapple/models/imats/doorgrapplegrapple_grapple01.bsmat",
	"actors/props/doorgrapplegrapple/models/imats/doorgrapplegrapple_grapple02.bsmat",
	"actors/props/doorshieldmissile/models/imats/doorshieldmissile_mp_opaque_01.bsmat",
	"actors/props/weightactivatedplatform_teleport_frozen/models/imats/weightactivatedplatform_teleport_frozen_teleporterbase_cables_frozen.bsmat",
	"actors/props/grapplepulloff1x2/fx/imats/destruction_r_boxgrapple.bsmat",
	"actors/props/grapplepulloff1x2/fx/imats/destruction_l_boxgrapple.bsmat",
	"actors/props/grapplepulloff1x2/models/imats/grapplepulloff1x2_material.bsmat",
	"actors/characters/chozocommander_arm/models/imats/chozocommander_arm_skybase_.bsmat",
	"actors/props/weightactivatedplatform_teleport_frozen/models/imats/weightactivatedplatform_teleport_frozen_teleporterbase_frozen.bsmat",
	"actors/characters/chozocommander/models/imats/chozocommander_headcinematics.bsmat",
	"actors/characters/chozocommander/models/imats/chozocommander_barrieraura.bsmat",
	"actors/props/supermissile_cut/models/imats/supermissile_cut_mp_opaque_01.bsmat",
	"actors/props/door_shield_plasma/models/imats/doorshieldplasma_mp_opaque_01.bsmat",
	"actors/props/doorcentralunit/models/imats/doorcentralunit_mp_opaque_02.bsmat",
	"actors/props/footstepplatform/models/imats/footstepplatform_mat01.bsmat",
	"actors/items/powerup_screwattack/models/imats/powerup_screwattack_mp_opaque_01.bsmat",
	"actors/props/block_slide_reg_001/models/imats/block_slide_reg_001_mp_opaque_01.bsmat",
	"actors/characters/centralunitcave/models/imats/centralunitcavebroken_mp_opaque_01.bsmat",
	"actors/characters/centralunitcave/models/imats/centralunitcavebroken_mp_opaque_02.bsmat",
	"actors/characters/chozocommander/models/imats/chozocommander_headclean.bsmat",
	"actors/props/platformcavewaterb/models/imats/platformcavewaterb_ev_aquadrain_right.bsmat",
	"actors/props/energyrecharge/models/imats/energyrecharge_base.bsmat",
	"actors/props/energyrecharge/models/imats/energyrecharge_body.bsmat",
	"actors/props/energyrecharge/models/imats/energyrecharge_eyes.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samusfacial_hyperhelmet.bsmat",
	"actors/items/item_energyfragment/models/imats/item_energyfragment_mat02.bsmat",
	"actors/characters/centralunitcave/models/imats/centralunitcave_mp_opaque_constant_selfilum_01.bsmat",
	"actors/props/accesspoint/models/imats/accesspoint_emisivo.bsmat",
	"actors/characters/scorpius/fx/imats/maskregenerate_material.bsmat",
	"actors/props/grappleswingpoint/models/imats/grappleswingpoint_mat01.bsmat",
	"actors/props/doorcaveatrium/models/imats/doorcaveatrium_door.bsmat",
	"actors/props/ev_entercu_cv_001/models/imats/ev_entercu_cv_001_mp_opaque_01.bsmat",
	"actors/props/ammorecharge/models/imats/ammorecharge_base.bsmat",
	"actors/props/ammorecharge/models/imats/ammorecharge_body.bsmat",
	"actors/props/ammorecharge/models/imats/ammorecharge_eyes.bsmat",
	"actors/characters/chozocommander/models/imats/chozocommander_canon.bsmat",
	"actors/props/maproom/models/imats/maproom_maproom5.bsmat",
	"actors/props/doorchargecharge/models/imats/doorchargecharge_snot.bsmat",
	"actors/props/doorchargeclosed/models/imats/doorchargeclosed_snot.bsmat",
	"actors/props/doorclosedcharge/models/imats/doorclosedcharge_snot.bsmat",
	"actors/characters/chozocommander/models/imats/chozocommander_body.bsmat",
	"actors/characters/chozocommander/models/imats/chozocommander_head.bsmat",
	"actors/props/weightactivatedplatform_teleport/models/imats/platform_teleporter_base.bsmat",
	"actors/props/doorchargecharge/models/imats/doorchargecharge_eggs.bsmat",
	"actors/props/doorchargeclosed/models/imats/doorchargeclosed_eggs.bsmat",
	"actors/props/doorclosedcharge/models/imats/doorclosedcharge_eggs.bsmat",
	"actors/items/powerup_grapplebeam/models/imats/powerup_grapplebeam_grapplebeam.bsmat",
	"actors/props/ev_chainreaction_cv_010_b/models/imats/ev_chainreaction_cv_010_b_chozoallwall01x3.bsmat",
	"actors/props/doorclosedgrapple/models/imats/doorclosedgrapple_mat02.bsmat",
	"actors/characters/chozocommander/models/imats/chozocommander_wings.bsmat",
	"actors/items/powerup_variasuit/models/imats/powerup_variasuit_material01.bsmat",
	"actors/props/doorchargeclosed/models/imats/doorchargeclosed_mat02.bsmat",
	"actors/props/doorclosedcharge/models/imats/doorclosedcharge_mat02.bsmat",
	"actors/props/ev_chainreaction_cv_003/models/imats/ev_chainreaction_cv_003_chozoallwall01x3.bsmat",
	"actors/props/ev_chainreaction_cv_007/models/imats/ev_chainreaction_cv_007_chozoallwall01x3.bsmat",
	"actors/props/ev_chainreaction_cv_009/models/imats/ev_chainreaction_cv_009_chozoallwall01x3.bsmat",
	"actors/props/ev_chainreaction_cv_010/models/imats/ev_chainreaction_cv_010_chozoallwall01x3.bsmat",
	"actors/props/trap_rot_cv_002/models/imats/trap_rot_cv_002_mp_opaque_01.bsmat",
	"actors/characters/chozocommander/models/imats/chozocommander_capbroken.bsmat",
	"actors/props/doorshutter/models/imats/doorshutter_shutter.bsmat",
	"actors/props/doorwavebeam/models/imats/doorwavebeam_mp_opaque_01.bsmat",
	"actors/characters/scorpius/fx/imats/scorpiusmask_material.bsmat",
	"actors/characters/emmyproto/models/imats/emmyproto_eye_decal.bsmat",
	"actors/items/item_energyfragment/models/imats/item_energyfragment_mat01.bsmat",
	"actors/characters/emmycave/models/imats/emmycave_eye_decal.bsmat",
	"actors/events/mapev_reptile01/models/imats/reptile01_mat01.bsmat",
	"actors/events/mapev_reptile02/models/imats/reptile02_mat01.bsmat",
	"actors/props/ev_chainreaction_cv_002/models/imats/ev_chainreaction_cv_002_chozoallpath.bsmat",
	"actors/props/ev_chainreaction_cv_006/models/imats/ev_chainreaction_cv_006_chozoallpath.bsmat",
	"actors/props/maproom/models/imats/maproom_platform.bsmat",
	"maps/genericimats/lava_kraid_generic.bsmat",
	"actors/props/samus_ship_b/models/imats/samus_ship_b_shipexta.bsmat",
	"actors/props/samus_ship_b/models/imats/samus_ship_b_shipextb.bsmat",
	"actors/props/samus_ship_b/models/imats/samus_ship_b_shipextc.bsmat",
	"actors/props/weightactivatedplatform_teleport_frozen/models/imats/weightactivatedplatform_teleport_frozen_ice.bsmat",
	"actors/props/box_weight_cv_001/models/imats/box_weight_cv_001_mp_opaque_01.bsmat",
	"maps/genericimats/lavawaterfall01_generic.bsmat",
	"maps/objects/fxpouringwaterx4/imats/fxpouringwaterx4_topsplash.bsmat",
	"actors/items/itemsphere/fx/imats/impact_itemsphere_itemsphere.bsmat",
	"actors/items/item_energytank/models/imats/item_energytank_mp_opaque_01.bsmat",
	"actors/props/rinkaunit/models/imats/rinkaunit_material01.bsmat",
	"maps/fx/lavasplashes/imats/lava_explosion00_anim_material.bsmat",
	"maps/fx/lavasplashes/imats/lava_explosion01_anim_material.bsmat",
	"maps/objects/fxpouringwaterx4/imats/fxpouringwaterx4_botsplash.bsmat",
	"maps/fx/waterstream/imats/waterstream00_fallingsplash.bsmat",
	"maps/fx/waterstream/imats/waterstream01_fallingsplash.bsmat",
	"maps/genericimats/lavamat01_generic.bsmat",
	"maps/objects/fxwaterfallcave01/imats/fxwaterfallcave01_splash.bsmat",
	"maps/genericimats/lavaasset_generic.bsmat",
	"maps/objects/fxpouringwaterx4/imats/fxpouringwaterx4_splash.bsmat",
	"actors/props/maproom/models/imats/selfilumbaselab01_generic.bsmat",
	"actors/props/samuship_int/models/imats/samusship_int_seata.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samusfacial_face.bsmat",
	"actors/props/doorchargecharge/models/imats/doorchargecharge_ice.bsmat",
	"actors/props/doorchargeclosed/models/imats/doorchargeclosed_ice.bsmat",
	"actors/props/doorclosedcharge/models/imats/doorclosedcharge_ice.bsmat",
	"actors/props/dooremmy/models/imats/dooremmy_mp_opaque_01.bsmat",
	"actors/props/samuship_int/models/imats/samusship_int_controlpanel.bsmat",
	"actors/props/weightactivatedplatform_teleport/models/imats/platform_teleporter_cables.bsmat",
	"maps/genericimats/lava01_generic.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samusfacial_hair.bsmat",
	"actors/props/box_wide_cv_001/models/imats/box_wide_cv_001_mat02light1.bsmat",
	"actors/props/box_wide_cv_001/models/imats/box_wide_cv_001_mat02light2.bsmat",
	"actors/props/box_wide_cv_001/models/imats/box_wide_cv_001_mat02light3.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samusfacial_visor.bsmat",
	"maps/objects/fxwaterfallcave01/imats/fxwaterfallcave01_mist.bsmat",
	"actors/props/samuship_int/models/imats/samusship_int_door.bsmat",
	"maps/fx/aquabubbles/imats/aquabubbles1_aquabubbles03.bsmat",
	"actors/props/trap_rot_cv_001/models/imats/trap_rot_cv_001_mp_opaque_01.bsmat",
	"maps/fx/aquabubbles/imats/aquabubbles_aquabubbles03.bsmat",
	"maps/fx/aquasparks/imats/aquasparks01_aquasparks.bsmat",
	"maps/fx/aquasparks/imats/aquasparks03_aquasparks.bsmat",
	"maps/fx/pipeleaks00/fx/imats/pipeleaks00_largedrops.bsmat",
	"maps/fx/waterstream/imats/waterwave00_splash.bsmat",
	"maps/fx/waterstream/imats/waterwave01_splash.bsmat",
	"maps/fx/pipeleaks00/fx/imats/pipeleaks00_fastdrops.bsmat",
	"actors/props/weightactivatedplatform_thermal/models/imats/platform_heat_mp_opaque_01.bsmat",
	"actors/events/mapev_bigfistgrub/models/imats/bigfistgrub_material01.bsmat",
	"actors/props/maproom/models/imats/maproom_centre.bsmat",
	"maps/fx/lavadrops/imats/lava_drops00_anim_material.bsmat",
	"maps/fx/lavadrops/imats/lava_drops01_anim_material.bsmat",
	"maps/fx/lavadrops/imats/lava_drops03_anim_material.bsmat",
	"maps/fx/lavadrops/imats/lava_drops04_anim_material.bsmat",
	"actors/props/doorheat/models/imats/doorheat_mp_opaque_02.bsmat",
	"actors/items/itemsphere/models/imats/itemsphere_mp_opaque_01.bsmat",
	"actors/props/deviceheat/models/imats/deviceheat_mp_opaque_01.bsmat",
	"actors/props/dooremmy/models/imats/dooremmy_material.bsmat",
	"actors/props/maproom/models/imats/maproom_body.bsmat",
	"actors/props/savestation/models/imats/savestation_ring.bsmat",
	"actors/characters/centralunitcave/models/imats/centralunitcave_mp_opaque_01.bsmat",
	"actors/items/powerup_chargebeam/models/imats/powerup_chargebeam_autoilum.bsmat",
	"actors/weapons/missile/models/imats/cutscenemissile_cutscenemissile.bsmat",
	"actors/props/breakablecave017/models/imats/breakablecave017_mp_opaque_chozomatconcretepurple01nd.bsmat",
	"actors/characters/bigfist/models/imats/bigfist_mp_opaque_01.bsmat",
	"actors/characters/scorpius/models/imats/scorpius_eyes.bsmat",
	"actors/events/mapev_deer01/models/imats/deer_material01.bsmat",
	"actors/props/breakablecave017/models/imats/breakablecave017_mp_opaque_chozomatconcretepurple01.bsmat",
	"actors/props/asteroids/models/imats/asteroids_asteroids.bsmat",
	"actors/props/planetzdr/models/imats/planetzdr_planet.bsmat",
	"actors/characters/chozozombiex/fx/imats/gridmudcenter_gridmudcenter.bsmat",
	"actors/events/butterfly/models/imats/butterfly_body.bsmat",
	"actors/props/samuship_int/models/imats/samusship_int_seatb.bsmat",
	"actors/props/breakablecave017/models/imats/breakablecave017_mp_opaque_chozomatconcretebase02nd.bsmat",
	"actors/props/dooremmy/models/imats/dooremmy_ice.bsmat",
	"actors/props/doorheat/models/imats/doorheat_mp_opaque_01.bsmat",
	"actors/characters/chozozombiex/fx/imats/gridmudside_gridmudside.bsmat",
	"actors/props/elevator/models/imats/elevator_mat01.bsmat",
	"actors/props/zipline_frozen/models/imats/zipline_frozen_mat01.bsmat",
	"maps/genericimats/chozodecal011_generic.bsmat",
	"maps/genericimats/chozodecal010_generic.bsmat",
	"maps/genericimats/chozodecal012_generic.bsmat",
	"maps/genericimats/chozodecal07b_generic.bsmat",
	"maps/genericimats/chozodecal07_generic.bsmat",
	"actors/props/elevator/models/imats/elevator_mat02.bsmat",
	"maps/genericimats/chozodecal05_generic.bsmat",
	"maps/genericimats/chozodecal09_generic.bsmat",
	"actors/props/breakablecave002/models/imats/breakablecave002_mp_opaque_02.bsmat",
	"actors/props/breakablecave006/models/imats/breakablecave006_mp_opaque_01.bsmat",
	"actors/props/breakablecave006/models/imats/breakablecave006_mp_opaque_02.bsmat",
	"actors/props/breakablecave014/models/imats/breakablecave014_mp_opaque_01.bsmat",
	"actors/props/breakablecave014/models/imats/breakablecave014_mp_opaque_02.bsmat",
	"actors/props/zipline/models/imats/zipline_mat01.bsmat",
	"actors/props/breakablecave002/models/imats/breakablecave002_mp_opaque_01.bsmat",
	"actors/props/cutmodel49wall04/models/imats/cutmodel49wall04_mp_opaque_01.bsmat",
	"actors/props/scostatuefull_cut54/models/imats/scostatuefull_cut54_mp_opaque_61.bsmat",
	"actors/props/scostatuefull_cut54/models/imats/scostatuefull_cut54_mp_opaque_62.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca151sg_casca151_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca153sg_casca153_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca154sg_casca154_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca155sg_casca155_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca156sg_casca156_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca157sg_casca157_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca158sg_casca158_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca159sg_casca159_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca160sg_casca160_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca161sg_casca161_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca162sg_casca162_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca163sg_casca163_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca164sg_casca164_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca165sg_casca165_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca166sg_casca166_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca167sg_casca167_mp_opaque_09.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel009_mp_opaque_60.bsmat",
	"actors/props/breakablecave014/models/imats/breakablecave014_mp_opaque_pieces01.bsmat",
	"actors/props/breakablecave014/models/imats/breakablecave014_mp_opaque_pieces02.bsmat",
	"maps/objects/magmeltrockpath01x4/imats/magmeltrockpath01x4_mp_opaque_01.bsmat",
	"maps/objects/magmeltrockwall01x4/imats/magmeltrockwall01x4_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_sg_casca004_mp_opaque_103.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_sg_casca006_mp_opaque_103.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_sg_casca007_mp_opaque_103.bsmat",
	"actors/props/platformcavewaterb/models/imats/platformcavewaterb_mp_opaque_01.bsmat",
	"actors/props/platformcavewaterb/models/imats/platformcavewaterb_mp_opaque_02.bsmat",
	"maps/objects/cavlittlerock01/imats/cavlittlerock01_mp_opaque_01.bsmat",
	"cutscenes/0036enteremmyzone/fx/imats/dooremmyfx_dooremmyfx.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_sg_casca004_mp_opaque_102.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_sg_casca005_mp_opaque_102.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_sg_casca006_mp_opaque_102.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_sg_casca007_mp_opaque_102.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_x1_sg_casca008_mp_opaque_102.bsmat",
	"actors/props/doorheat/models/imats/doorheat_mp_flowadditivealphaclipmtl00_01.bsmat",
	"maps/genericimats/chozomatemissive01_generic.bsmat",
	"actors/props/doorclosedgrapple/models/imats/doorclosedgrapple_mat01.bsmat",
	"actors/props/doorchargecharge/models/imats/doorchargecharge_mat01.bsmat",
	"actors/props/doorchargeclosed/models/imats/doorchargeclosed_mat01.bsmat",
	"actors/props/doorclosedcharge/models/imats/doorclosedcharge_mat01.bsmat",
	"maps/objects/coldzoneassetn010/imats/coldzoneassetn010_mp_opaque_01.bsmat",
	"maps/objects/chozobaseassets01/imats/chozobaseassets01_mp_opaque_simple.bsmat",
	"maps/objects/chozocavproto_02/imats/chozocavproto_02_mp_opaque_02.bsmat",
	"maps/objects/coldzoneasset01/imats/coldzoneasset01_mp_opaque_01.bsmat",
	"maps/objects/coldzoneasset02/imats/coldzoneasset02_mp_opaque_01.bsmat",
	"maps/objects/coldzoneasset03/imats/coldzoneasset03_mp_opaque_01.bsmat",
	"maps/objects/coldzoneasset04/imats/coldzoneasset04_mp_opaque_01.bsmat",
	"maps/objects/coldzoneasset05/imats/coldzoneasset05_mp_opaque_01.bsmat",
	"maps/objects/coldzoneasset06/imats/coldzoneasset06_mp_opaque_01.bsmat",
	"maps/objects/coldzoneasset08/imats/coldzoneasset08_mp_opaque_01.bsmat",
	"maps/objects/coldzoneasset09/imats/coldzoneasset09_mp_opaque_01.bsmat",
	"actors/props/doorframe/models/imats/doorframe_mat01.bsmat",
	"maps/fx/emmymist00/fx/imats/emmymist00_right_material.bsmat",
	"maps/fx/emmymist00/fx/imats/emmymist00_left_material.bsmat",
	"actors/props/doorwidebeam/models/imats/doorwidebeam_bottom.bsmat",
	"actors/props/cutmodel49wall03/models/imats/cutmodel49wall03_mp_opaque_01.bsmat",
	"actors/fx/flickeringlight01/fx/imats/flickeringlshaftlamp01_mp_lightshaft_01.bsmat",
	"actors/props/accesspoint/fx/imats/hologram_letters_hololetters.bsmat",
	"actors/props/doorwidebeam/models/imats/doorwidebeam_mid.bsmat",
	"actors/props/doorwidebeam/models/imats/doorwidebeam_top.bsmat",
	"maps/genericimats/checkergrey01_generic.bsmat",
	"maps/genericimats/checkergrey02_generic.bsmat",
	"actors/fx/accesspoint01/fx/imats/accesspoint01_mp_accesspoint.bsmat",
	"actors/props/trap_thermal_horizontal/models/imats/trap_thermal_horizontal_emisive.bsmat",
	"maps/genericimats/chozodecal08_generic.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel008_mp_opaquemaps_simple088.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel065_mp_opaquemaps_simple088.bsmat",
	"maps/objects/chozofrontpath02x1b/imats/chozofrontpath02x1b_mp_opaque_01.bsmat",
	"maps/objects/chozofrontpath04x1d/imats/chozofrontpath04x1d_mp_opaque_01.bsmat",
	"maps/objects/chozofrontpath02x4/imats/chozofrontpath02x4_mp_opaque_01.bsmat",
	"actors/props/dooremmy/fx/imats/dooremmyfx_dooremmyfx.bsmat",
	"maps/objects/chozobgmagwalljointb/imats/chozobgmagwalljointb_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgmagwalljoint/imats/chozobgmagwalljoint_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel049_mp_opaquemaps_67.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel049_mp_opaquemaps_76.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_mapmodel00_mp_opaquemaps_67.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part021_e4_mapmodel17_mp_opaquemaps_simple94.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_mapmodel08_mp_opaquemaps_67.bsmat",
	"maps/objects/lshaftlamp01/imats/lshaftlamp01_mp_lightshaft_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel049_mp_opaquemaps_77.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_mapmodel00_mp_opaquemaps_77.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_mapmodel15_mp_opaquemaps_77.bsmat",
	"maps/objects/chozobgemmydoor01/imats/chozobgemmydoor01_mp_opaquemaps_simple.bsmat",
	"maps/objects/lshaftgen01/imats/lshaftgen01_mp_lightshaft_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel050_mp_opaquemaps_68.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel056_mp_opaquemaps_68.bsmat",
	"maps/objects/lshaftcave02/imats/lshaftcave02_mp_lightshaft_01.bsmat",
	"maps/objects/lshaftcave03/imats/lshaftcave03_mp_lightshaft_01.bsmat",
	"maps/objects/lshaftcave04/imats/lshaftcave04_mp_lightshaft_01.bsmat",
	"maps/objects/chozobgmagwall10/imats/chozobgmagwall10_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel053_mp_opaquemaps_80.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel053_mp_opaquemaps_81.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel053_mp_opaquemaps_82.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part012_s8_cooldown_02_mp_opaquemaps_30.bsmat",
	"maps/objects/lshaftscorpius/imats/lshaftscorpius_mp_blend_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel02_mp_opaquemaps_80.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel02_mp_opaquemaps_81.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel04_mp_opaquemaps_80.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel04_mp_opaquemaps_81.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel07_mp_opaquemaps_80.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel07_mp_opaquemaps_81.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part005_e4_mapmodel04_mp_opaquemaps_79.bsmat",
	"actors/props/breakablecave007/models/imats/breakablecave007_mp_opaquemaps_simple_04.bsmat",
	"maps/objects/lshaftcave01/imats/lshaftcave01_mp_blend_01.bsmat",
	"actors/characters/scorpius/fx/imats/opticalcamo.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel001_mp_opaquemaps_84.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel011_mp_opaquemaps_84.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel022_mp_opaquemaps_84.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel053_mp_opaquemaps_84.bsmat",
	"maps/objects/chozobgpipescorner_03/imats/chozobgpipescorner_03_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel08_mp_opaquemaps_84.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_00_mp_opaquemaps_02.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_01_mp_opaquemaps_02.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_03_mp_opaquemaps_02.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_04_mp_opaquemaps_02.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_05_mp_opaquemaps_02.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part021_e4_mapmodel17_mp_opaquemaps_simple95.bsmat",
	"maps/genericimats/chozodecal011opaque_generic.bsmat",
	"maps/genericimats/chozomatplates05_generic.bsmat",
	"maps/genericimats/chozomatplates06_generic.bsmat",
	"maps/objects/chozobgpipesend/imats/chozobgpipesend_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel001_mp_opaquemaps_83.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel022_mp_opaquemaps_83.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel053_mp_opaquemaps_83.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel01_mp_opaquemaps_83.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel03_mp_opaquemaps_83.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel08_mp_opaquemaps_83.bsmat",
	"maps/genericimats/chozomatpipes15_generic.bsmat",
	"maps/objects/chozocolmag01/imats/chozocolmag01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozocolmag02/imats/chozocolmag02_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozocolmag03/imats/chozocolmag03_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgcorner01/imats/chozobgcorner01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgpath01x1/imats/chozobgpath01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgpath01x3/imats/chozobgpath01x3_mp_opaquemaps_simple.bsmat",
	"maps/genericimats/chozodecal010opaque_generic.bsmat",
	"maps/objects/chozobgair01x1/imats/chozobgair01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgair01/imats/chozobgair01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgair02/imats/chozobgair02_mp_opaquemaps_simple.bsmat",
	"actors/props/watercave01a/models/imats/watercave01a_mp_water_2.bsmat",
	"actors/props/watercave01b/models/imats/watercave01b_mp_water_2.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel010_mp_opaquemaps_simple077.bsmat",
	"maps/genericimats/watercave01_generic.bsmat",
	"maps/genericimats/debuggrey01_generic.bsmat",
	"maps/objects/chozoallwall02cornerleft/imats/chozoallwall02cornerleft_mp_opaquemaps_simple.bsmat",
	"actors/props/door_shield_plasma/models/imats/doorshieldplasma_matfx.bsmat",
	"maps/fx/waterstream/imats/waterwave00_wave.bsmat",
	"maps/fx/waterstream/imats/waterwave01_wave.bsmat",
	"actors/props/platformcavewaterb/models/imats/platformcavewaterb_watervalvef.bsmat",
	"actors/props/watercave01a/models/imats/watercave01a_mp_waterfront_1.bsmat",
	"actors/props/watercave01b/models/imats/watercave01b_mp_waterfront_1.bsmat",
	"actors/props/doorwavebeam/models/imats/doorwavebeam_matfx.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/commander_zerolaser_explosion_medium_ball.bsmat",
	"actors/props/breakablecave010/models/imats/breakablecave010_mp_opaquemaps_simple_dissolve_7.bsmat",
	"actors/props/watercave08b/models/imats/watercave08b_water8bcave.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/animfresnel_aurascratch_border.bsmat",
	"maps/genericimats/watercavefront01_generic.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/commander_zerolaser_explosion_big_ball.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/commander_zerolaser_explosion_big_fast.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/plasmabeam_chargedprojectile_mp_fxmeshmtl00_border.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/nebula_final_01_mat.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/nebula_final_02_mat.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/nebula_final_03_mat.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/nebula_final_04_mat.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/nebula_final_05_mat.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/plasmabeam_chargedprojectile_mp_fxmeshmtl00_inner.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/plasmabeam_chargedprojectile_projectile_particles.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/handmetroidnization_fresnel.bsmat",
	"actors/props/watercave08a/models/imats/watercave08a_water08.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/plasmabeam_chargedprojectile_mp_fxmeshmtl00_fire.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/plasmabeam_chargedprojectile_mp_fxmeshmtl00_tail.bsmat",
	"actors/props/breakablecave020/models/imats/breakablecave020_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/breakablecave010/models/imats/breakablecave010_mp_opaquemaps_simple_dissolve_1.bsmat",
	"actors/props/breakablecave010/models/imats/breakablecave010_mp_opaquemaps_simple_dissolve_3.bsmat",
	"actors/props/breakablecave010/models/imats/breakablecave010_mp_opaquemaps_simple_dissolve_6.bsmat",
	"actors/props/db_reg_cv_020/models/imats/db_reg_cv_020_mp_opaquemaps_simple_dissolve_02.bsmat",
	"actors/props/db_reg_cv_020/models/imats/db_reg_cv_020_mp_opaquemaps_simple_dissolve_03.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aurascratch_noise_back.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/animfresnel_aurascratch.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aurascratch_back_back.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aurascratch_fast_back.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aurascratch_wall_back.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aurascratch_waves_bot.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/trail_cannon_endtrail.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aurascratch_back_bot.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aurascratch_fast_bot.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aurascratch_wall_bot.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/commander_misil_trailsmoke_smoke.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aurascratch_waves_back.bsmat",
	"maps/genericimats/guidemaplight_generic.bsmat",
	"actors/characters/chozocommander/fx/imats/chargeenergy_commander_center.bsmat",
	"actors/characters/scorpius/models/imats/scorpius_scorpius.bsmat",
	"actors/props/ammorecharge/fx/imats/charge_fx_waves.bsmat",
	"actors/props/energyrecharge/fx/imats/charge_fx_waves.bsmat",
	"actors/props/totalrechargestation/fx/imats/charge_fx_waves.bsmat",
	"actors/props/breakablecave009/models/imats/breakablecave009_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samusfacial_hypervisor.bsmat",
	"actors/props/breakablecave007/models/imats/breakablecave007_mp_opaquemaps_simple_05.bsmat",
	"actors/props/breakablecave008/models/imats/breakablecave008_mp_opaquemaps_simple_01.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/samus_metroidnization_energy.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/shootinggrab_zerolaser_cap.bsmat",
	"actors/props/db_reg_cv_021/models/imats/db_reg_cv_021_mp_opaquemaps_simple_26.bsmat",
	"actors/props/db_reg_cv_020/models/imats/db_reg_cv_020_mp_opaquemaps_simple_dissolve_01.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/zerolaser_airburst_small.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/zerolaser_airstrong_small.bsmat",
	"actors/props/db_reg_cv_021/models/imats/db_reg_cv_021_mp_opaquemaps_simple_24.bsmat",
	"actors/props/db_reg_cv_021/models/imats/db_reg_cv_021_mp_opaquemaps_simple_28.bsmat",
	"actors/weapons/plasmabeam/fx/imats/explosion_fresnexplosion.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/zerolaser_airstrong_big.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/zerolaser_airstrong_glow.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_burst_laser.bsmat",
	"actors/props/breakablecave002/models/imats/breakablecave002_mp_opaquemaps_simple_01.bsmat",
	"actors/props/breakablecave014/models/imats/breakablecave014_mp_opaquemaps_simple_01.bsmat",
	"actors/props/breakablecave014/models/imats/breakablecave014_mp_opaquemaps_simple_02.bsmat",
	"actors/props/db_dif_cv_001/models/imats/chozomatconcretebase02_generic.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/zerolaser_airburst_big.bsmat",
	"maps/genericimats/thermalstate_generic.bsmat",
	"maps/genericimats/thermalstate01_generic.bsmat",
	"actors/props/breakablecave017/models/imats/breakablecave017_cascamat.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/hyperdash_trail_close.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/hyperdash_trail_trail.bsmat",
	"actors/weapons/plasmabeam/fx/imats/explosion_transparent.bsmat",
	"maps/objects/communicationroom2door/imats/communicationroom2door_mat_01.bsmat",
	"maps/objects/communicationroom4door/imats/communicationroom4door_mat_01.bsmat",
	"actors/weapons/plasmabeam/fx/imats/explosion_inner_wall.bsmat",
	"actors/weapons/plasmabeam/fx/imats/explosion_shine_wall.bsmat",
	"system/fx/generic/imats/varia_chestenergysupport_varia_chestenergysupport.bsmat",
	"actors/props/breakablecave007/models/imats/breakablecave007_mp_opaquemaps_simple_02.bsmat",
	"actors/props/breakablecave014/models/imats/breakablecave014_mp_opaquemaps_simple_06.bsmat",
	"actors/props/totalrechargestation/fx/imats/prop_energy_border.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/shootinggrab_zerolaser_grunge.bsmat",
	"actors/props/totalrechargestation/fx/imats/prop_energy_arcs.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/animfresnel2.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/shootinggrab_zerolaser_cover.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/shootinggrab_zerolaser_floor.bsmat",
	"cutscenes/0057scorpiusdeath/fx/imats/fresnel_ilum_tail.bsmat",
	"actors/props/db_reg_cv_021/models/imats/db_reg_cv_021_mp_opaquemaps_simple_06.bsmat",
	"actors/props/db_reg_cv_021/models/imats/db_reg_cv_021_mp_opaquemaps_simple_07.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/shootinggrab_zerolaser_core.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/shootinggrab_zerolaser_wave.bsmat",
	"cutscenes/0054scorpiuspresentation/fx/imats/camerafog_scorpiuspresentation_camerafog_scorpiuspresentation.bsmat",
	"actors/props/ammorecharge/fx/imats/charge_fx_glow.bsmat",
	"actors/props/db_reg_cv_022/models/imats/db_reg_cv_022_mp_opaquemaps_simple06.bsmat",
	"actors/props/energyrecharge/fx/imats/charge_fx_glow.bsmat",
	"actors/props/totalrechargestation/fx/imats/charge_fx_glow.bsmat",
	"actors/weapons/plasmabeam/fx/imats/explosion_inner.bsmat",
	"actors/weapons/plasmabeam/fx/imats/explosion_shine.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/animfresnel.bsmat",
	"maps/objects/fxwaterfallcave01/imats/fxwaterfallcave01_shine.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_05_mp_opaquemaps_01.bsmat",
	"maps/objects/fxpouringwaterx4/imats/fxpouringwaterx4_shine.bsmat",
	"actors/props/db_reg_cv_021/models/imats/db_reg_cv_021_cascamat02.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/commander_zerolaser_explosion_medium_border.bsmat",
	"actors/props/ammorecharge/fx/imats/charge_fx_cover.bsmat",
	"actors/props/breakablecave003/models/imats/breakablecave003_cascamat.bsmat",
	"actors/props/breakablecave007/models/imats/breakablecave007_cascamat.bsmat",
	"actors/props/breakablecave008/models/imats/breakablecave008_cascamat.bsmat",
	"actors/props/breakablecave014/models/imats/breakablecave014_cascamat.bsmat",
	"actors/props/breakablecave018/models/imats/breakablecave018_cascamat.bsmat",
	"actors/props/energyrecharge/fx/imats/charge_fx_cover.bsmat",
	"actors/props/totalrechargestation/fx/imats/charge_fx_cover.bsmat",
	"actors/props/breakablecave003/models/imats/breakablecave003_rocks4.bsmat",
	"actors/props/breakablecave018/models/imats/breakablecave018_rocks2.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/commander_zerolaser_explosion_big_border.bsmat",
	"system/fx/generic/imats/varia_end_shoulderenergy_varia_end_shoulderenergy.bsmat",
	"system/fx/generic/imats/varia_displacementaura_displacement_aura_varia.bsmat",
	"system/fx/generic/imats/varia_end_leftarmenergy_varia_end_leftarmenergy.bsmat",
	"actors/props/breakablecave009/models/imats/breakablecave009_cascamat01.bsmat",
	"maps/objects/chozoallpipe03/imats/chozoallpipe03_mp_opaquemaps_simple.bsmat",
	"actors/items/item_cube/model/imats/itemcube_emisive.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/nebula_04_mat.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/nebula_05_mat.bsmat",
	"cutscenes/0112endgame/fx/imats/starfield_mat.bsmat",
	"system/fx/generic/imats/varia_cannon_smallcover_cover_end.bsmat",
	"actors/items/item_missiletankplus/models/imats/item_missiletankplus_mp_fxhologram_01.bsmat",
	"actors/props/breakablecave017/models/imats/breakablecave017_mp_opaquemaps_simple.bsmat",
	"actors/props/db_reg_cv_021/models/imats/db_reg_cv_021_cascamat01.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/nebula_03_mat.bsmat",
	"actors/props/db_reg_cv_020/models/imats/db_reg_cv_020_cascamat.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/planet_atmos_mat.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/shootinggrab_zerolaser_twist.bsmat",
	"system/fx/generic/imats/varia_jumpsmoke_varia_jumpsmoke.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/kistrike_wave_energy.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/zerolaser_energybase_center.bsmat",
	"actors/items/item_powerbombtank/models/imats/item_powerbombtank_mp_fxhologram_01.bsmat",
	"actors/props/breakablecave010/models/imats/breakablecave010_mp_opaquemaps_simple_dissolve_8.bsmat",
	"actors/props/platformcavmagnet4down/models/imats/platformcavmagnet4down_latform.bsmat",
	"actors/props/platformcavmagnet5down/models/imats/platformcavmagnet5down_latform.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_energy_energy.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/energy_wavety_arcs.bsmat",
	"cutscenes/0054scorpiuspresentation/fx/imats/verticaldust_scorpius_verticaldust_scorpius.bsmat",
	"actors/items/item_missiletank/models/imats/item_missiletank_mp_fxhologram_01.bsmat",
	"actors/props/teleporter/fx/imats/trail_inactive_top_trail_inactive.bsmat",
	"maps/genericimats/mudmatcave07a_generic.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/zerolaser_energybase_big.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/zerolaser_energybase_mid.bsmat",
	"maps/objects/evrodhorde_a/imats/evrodhorde_a_material01.bsmat",
	"maps/objects/evrodhorde_c/imats/evrodhorde_c_material01.bsmat",
	"maps/objects/evrodhorde_d/imats/evrodhorde_d_material01.bsmat",
	"actors/props/db_reg_cv_022/models/imats/db_reg_cv_022_cascamat01.bsmat",
	"actors/props/weightactivatedplatform_train/fx/imats/shaft_train_vertical_shaft_vertical.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/energy_wavety_vertical.bsmat",
	"system/fx/generic/imats/varia_trailsjump01_varia_trailsjump01.bsmat",
	"actors/props/ammorecharge/fx/imats/charge_fx_smoke.bsmat",
	"actors/props/energyrecharge/fx/imats/charge_fx_smoke.bsmat",
	"actors/props/totalrechargestation/fx/imats/charge_fx_smoke.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/energy_wavety_center.bsmat",
	"cutscenes/0053genericcupowerobtention/fx/imats/absortion_meshes_init_auras.bsmat",
	"cutscenes/0054scorpiuspresentation/fx/imats/speedtunnel_samus_speedtunnel_samus.bsmat",
	"actors/props/weightactivatedplatform_teleport/fx/imats/trails_inactive_trail_inactive_platform.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/absortion_energy_hand_absortionenergy.bsmat",
	"cutscenes/0054scorpiuspresentation/fx/imats/cameradust_samus_cameradust_samus.bsmat",
	"actors/props/accesspoint/fx/imats/hologram_base_mp_holooutside.bsmat",
	"cutscenes/0054scorpiuspresentation/fx/imats/frontdustfinal_frontdustfinal.bsmat",
	"actors/props/platformcavmagnet3left/models/imats/platformcavmagnet3left_material.bsmat",
	"actors/props/weightactivatedplatform_teleport/fx/imats/shaft_teleport_material.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/init_auras_aurasinit.bsmat",
	"cutscenes/0054scorpiuspresentation/fx/imats/bodydustfinal_bodydustfinal.bsmat",
	"cutscenes/0054scorpiuspresentation/fx/imats/scorpiusscream_scorpiusscream.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel064_mp_opaquemaps_simple089.bsmat",
	"actors/props/accesspoint/fx/imats/hologram_base_mp_hologram_base.bsmat",
	"actors/props/weightactivatedplatform_ammo/fx/imats/shaft_ammo_inner_shaft.bsmat",
	"actors/props/weightactivatedplatform_teleport/fx/imats/platform_glow_outterglow.bsmat",
	"actors/props/doorcentralunit/fx/imats/doorpannerplane_culight.bsmat",
	"actors/props/weightactivatedplatform_ammo/fx/imats/shaft_ammo_material.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/energy_absortion_absortion_big.bsmat",
	"actors/weapons/plasmabeam/fx/imats/muzzle_3d_muzzle_radial.bsmat",
	"actors/props/maproom/fx/imats/sphere_map_map.bsmat",
	"actors/weapons/plasmabeam/fx/imats/muzzle_3d_muzzle_main.bsmat",
	"actors/props/maproom/fx/imats/sphere_map_grid.bsmat",
	"actors/props/platformcavewaterb/models/imats/platformcavewaterb_fx.bsmat",
	"cutscenes/0053genericcupowerobtention/fx/imats/absortion_meshes_absortion.bsmat",
	"maps/objects/chozoallcorner01a/imats/chozoallcorner01a_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallcorner01b/imats/chozoallcorner01b_mp_opaquemaps_simple.bsmat",
	"actors/props/fx_heat_door/fx/imats/heatplane_heat.bsmat",
	"actors/props/fx_heat_tunnel/fx/imats/heatplane_heat.bsmat",
	"maps/genericimats/railmagnet_generic.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part004_o6_water01_part004_p_water01.bsmat",
	"cutscenes/0040sancemmypresentation_part2b/fx/imats/fakelightshot_fakelight_shot.bsmat",
	"maps/objects/chozoallwall01x3/imats/chozoallwall01x3_mp_opaquemaps_simple.bsmat",
	"actors/items/powerup_chargebeam/models/imats/powerup_chargebeam_body.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/energy_center_center.bsmat",
	"maps/objects/chozoallpath01x1/imats/chozoallpath01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallpath01x3/imats/chozoallpath01x3_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallwall01x1/imats/chozoallwall01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallassetmachine02/imats/chozoallassetmachine02_mp_opaquemaps_simple.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/mat_bigenginepropulsion.bsmat",
	"actors/props/watercave02/models/imats/watercave02_mp_water_surface.bsmat",
	"actors/props/weightactivatedplatform_teleport/fx/imats/platform_glow_basicglow.bsmat",
	"actors/props/samus_ship_b/models/imats/samus_ship_b_mat_enginepropulsion.bsmat",
	"maps/genericimats/lavafront01_generic.bsmat",
	"actors/props/breakablecave010/models/imats/breakablecave010_mp_opaquemaps_simple_dissolve_2.bsmat",
	"maps/objects/cavecolumcrystal05/imats/cavecolumcrystal05_mp_opaque_01.bsmat",
	"actors/events/butterfly/models/imats/butterfly_wings.bsmat",
	"cutscenes/0054scorpiuspresentation/fx/imats/ocsphere_ocsphere.bsmat",
	"maps/genericimats/glassyellow_generic.bsmat",
	"maps/objects/coldzoneasset07/imats/coldzoneasset07_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca148sg_casca148_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca149sg_casca149_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca150sg_casca150_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca151sg_casca151_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca152sg_casca152_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca159sg_casca159_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca160sg_casca160_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca161sg_casca161_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca162sg_casca162_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca165sg_casca165_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca171sg_casca171_mp_opaquemaps_simple_13.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca172sg_casca172_mp_opaquemaps_simple_13.bsmat",
	"maps/objects/cavpathrock01v6/imats/cavpathrock01v6_mp_opaque_01.bsmat",
	"maps/objects/cavpathrock02v2/imats/cavpathrock02v2_mp_opaque_01.bsmat",
	"maps/objects/chozoallbgemmy01cornice1x4/imats/chozoallbgemmy01cornice1x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallbgemmy01cornice2x4/imats/chozoallbgemmy01cornice2x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallbgemmy01corniceext/imats/chozoallbgemmy01corniceext_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallbgemmy01corniceint/imats/chozoallbgemmy01corniceint_mp_opaquemaps_simple.bsmat",
	"actors/characters/chozocommander/fx/imats/kistrike_speedenergy_energy.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca168sg_casca168_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca169sg_casca169_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_breakable_casca170sg_casca170_mp_opaquemaps_simple_18.bsmat",
	"maps/objects/chozoallbgemmy01cornicex1/imats/chozoallbgemmy01cornicex1_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_mapmodel00_chozocorridoremmyx100xjp1.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_mapmodel00_chozocorridoremmyx101xjp1.bsmat",
	"maps/objects/chozoallpathceilingcorner/imats/chozoallpathceilingcorner_mp_opaquemaps_simple_02.bsmat",
	"system/fx/generic/imats/varia_leftshoulderenergy_varia_leftshoulderenergy_varia_leftshoulderenergy.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part015_e6_casca_01sg_casca056_mp_opaquemaps_simple_31.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part015_e6_casca_02sg_casca057_mp_opaquemaps_simple_31.bsmat",
	"maps/objects/chozoallpathceiling04x4a/imats/chozoallpathceiling04x4a_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallpathceiling04x4b/imats/chozoallpathceiling04x4b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozocavechaincolumn01/imats/chozocavechaincolumn01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallpathceiling01x1/imats/chozoallpathceiling01x1_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoallpathceiling02x2/imats/chozoallpathceiling02x2_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoallbgemmy01corext/imats/chozoallbgemmy01corext_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallbgemmy01corint/imats/chozoallbgemmy01corint_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallassetmachine01/imats/chozoallassetmachine01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozocorridoremmy01/imats/chozocorridoremmy01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozocorridoremmy01/imats/chozocorridoremmy01_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozocorridoremmy02/imats/chozocorridoremmy02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozocorridoremmy02/imats/chozocorridoremmy02_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmybg01cornice1x4/imats/chozoemmybg01cornice1x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmybg01corniceext/imats/chozoemmybg01corniceext_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel064_mp_opaquemaps_simple088.bsmat",
	"maps/objects/chozoallassetbottleplat03/imats/chozoallassetbottleplat03_mp_opaquemaps_simple_2.bsmat",
	"maps/objects/chozoallassetbottleplat04/imats/chozoallassetbottleplat04_mp_opaquemaps_simple_2.bsmat",
	"maps/objects/chozoemmybg01cornicex1/imats/chozoemmybg01cornicex1_mp_opaquemaps_simple.bsmat",
	"actors/props/door_frblack_protoemmy/models/imats/door_frblack_protoemmy_mp_opaquemaps_simple_03.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_12_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_12_mp_opaquemaps_simple_40.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part015_e6_chozopathemmy01v301_part015_wall.bsmat",
	"maps/objects/cavdigrockplatform01/imats/cavdigrockplatform01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopipesthermal01cornerinvert/imats/chozopipesthermal01cornerinvert_pipes.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part015_e6_casca_11sg_casca185_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part015_e6_casca_94sg_casca094_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part015_e6_mapmodel13_mp_opaquemaps_simple_35.bsmat",
	"maps/objects/chozoallassetbottleplat01/imats/chozoallassetbottleplat01_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozoallassetbottleplat02/imats/chozoallassetbottleplat02_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozoallassetbottleplat03/imats/chozoallassetbottleplat03_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozoallassetbottleplat04/imats/chozoallassetbottleplat04_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozoalltunnelbg01corner/imats/chozoalltunnelbg01corner_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgwallemmycorner01/imats/chozobgwallemmycorner01_mp_opaque_01.bsmat",
	"maps/objects/chozoemmytunnelbg01set/imats/chozoemmytunnelbg01set_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathmag01endright/imats/chozopathmag01endright_mp_opaquemaps_simple_05.bsmat",
	"maps/objects/chozoplatformpipes01x1/imats/chozoplatformpipes01x1_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoplatformpipes01x1/imats/chozoplatformpipes01x1_mp_opaquemaps_simple_03.bsmat",
	"maps/objects/chozoplatformpipes01x4/imats/chozoplatformpipes01x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoplatformpipes01x4/imats/chozoplatformpipes01x4_mp_opaquemaps_simple_03.bsmat",
	"actors/props/ev_chainreaction_cv_005/models/imats/ev_chainreaction_cv_005_mp_opaquemaps_simple_01.bsmat",
	"actors/props/ev_chainreaction_cv_005/models/imats/ev_chainreaction_cv_005_mp_opaquemaps_simple_02.bsmat",
	"maps/genericimats/chozomatconcreteblue05cut_generic.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_12_mp_opaquemaps_simple_41.bsmat",
	"maps/objects/chozoalltunnelbg01_in/imats/chozoalltunnelbg01_in_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoalltunnelbg01x3b/imats/chozoalltunnelbg01x3b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathmag01endleft/imats/chozopathmag01endleft_mp_opaquemaps_simple_05.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel011_mp_opaquemaps_simple077.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel022_mp_opaquemaps_simple077.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part011_m1_mapmodel067_mp_opaquemaps_simple071.bsmat",
	"maps/objects/chozoallassetbottle01/imats/chozoallassetbottle01_mp_opaquemaps_simple_2.bsmat",
	"maps/objects/chozoallassetbottle02/imats/chozoallassetbottle02_mp_opaquemaps_simple_2.bsmat",
	"maps/objects/chozoallassetbottle03/imats/chozoallassetbottle03_mp_opaquemaps_simple_2.bsmat",
	"maps/objects/chozoallassetbottle04/imats/chozoallassetbottle04_mp_opaquemaps_simple_2.bsmat",
	"maps/objects/chozoallassetbottle05/imats/chozoallassetbottle05_mp_opaquemaps_simple_2.bsmat",
	"maps/objects/chozoallassetbottle06/imats/chozoallassetbottle06_mp_opaquemaps_simple_2.bsmat",
	"maps/objects/chozoallbgemmy01ax4/imats/chozoallbgemmy01ax4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmybg01corext/imats/chozoemmybg01corext_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybg01corint/imats/chozoemmybg01corint_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagemmypath01endl/imats/chozomagemmypath01endl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagemmypath01endl/imats/chozomagemmypath01endl_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozomagemmypath01endr/imats/chozomagemmypath01endr_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagemmypath01endr/imats/chozomagemmypath01endr_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozopathgeneric01endl/imats/chozopathgeneric01endl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopipesyellowadorn01/imats/chozopipesyellowadorn01_mp_opaque_01.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/rayscannon_048_init_rays.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part020_e10_mapmodel_21_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallassettube01/imats/chozoallassettube01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallbgemmy01x1/imats/chozoallbgemmy01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmytunnelbg01/imats/chozoemmytunnelbg01_mp_opaquemaps_simple_01.bsmat",
	"actors/props/door_frblack_protoemmy/models/imats/door_frblack_protoemmy_mp_opaquemaps_simple_01.bsmat",
	"actors/props/door_frblack_protoemmy/models/imats/door_frblack_protoemmy_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca133_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca134_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca135_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca136_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca137_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca143_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca144_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca145_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca146_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca147_mp_opaquemaps_simple_46.bsmat",
	"maps/objects/chozoallassetpanel03b/imats/chozoallassetpanel03b_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozoallpipesset01x3/imats/chozoallpipesset01x3_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoalltunnelbg01x1/imats/chozoalltunnelbg01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoalltunnelbg01x3/imats/chozoalltunnelbg01x3_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagemmypath01x1/imats/chozomagemmypath01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagemmypath01x4/imats/chozomagemmypath01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagemmypath01x4/imats/chozomagemmypath01x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozopipesthermal01mcorner/imats/chozopipesthermal01mcorner_pipes.bsmat",
	"actors/props/door_frblack_gen/models/imats/door_frblack_gen_mp_opaquemaps_simple_03.bsmat",
	"cutscenes/0036enteremmyzone/fx/imats/door_frblack_gen_mp_opaquemaps_simple_03.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_mapmodel08_mp_opaquemaps_simple_47.bsmat",
	"maps/objects/cavbugrockcolum01/imats/cavbugrockcolum01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/cavbugrockcolum02/imats/cavbugrockcolum02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/cavbugrockcolum03/imats/cavbugrockcolum03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/cavbugrockcolum04/imats/cavbugrockcolum04_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/caverockplatform05/imats/caverockplatform05_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallassetpanel01/imats/chozoallassetpanel01_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozoallassetpanel02/imats/chozoallassetpanel02_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozoallassetpanel03/imats/chozoallassetpanel03_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozoemmybg01ax4/imats/chozoemmybg01ax4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybg01cx4/imats/chozoemmybg01cx4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybg01cx4/imats/chozoemmybg01cx4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmybg01dx4/imats/chozoemmybg01dx4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybg01dx4/imats/chozoemmybg01dx4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmyplatform01x4/imats/chozoemmyplatform01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopipesthermal01corner/imats/chozopipesthermal01corner_pipes.bsmat",
	"maps/objects/chozoplatformemmy01x4/imats/chozoplatformemmy01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoplatformemmy01x4/imats/chozoplatformemmy01x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozosanccolumn02x3right/imats/chozosanccolumn02x3right_mp_opaquemaps_simple.bsmat",
	"actors/props/cut_54_scorpiusstatue/models/imats/cut_54_scorpiusstatue_mp_opaque_61.bsmat",
	"actors/props/cut_54_scorpiusstatue/models/imats/cut_54_scorpiusstatue_mp_opaque_62.bsmat",
	"maps/objects/chozoallassetbox01/imats/chozoallassetbox01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallscaffold04/imats/chozoallscaffold04_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallscaffold04/imats/chozoallscaffold04_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoallscaffold05/imats/chozoallscaffold05_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallscaffold05/imats/chozoallscaffold05_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoborderemmy02x4/imats/chozoborderemmy02x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopathmag01x1/imats/chozopathmag01x1_mp_opaquemaps_simple_05.bsmat",
	"maps/objects/chozopathmag01x4/imats/chozopathmag01x4_mp_opaquemaps_simple_05.bsmat",
	"maps/objects/chozosanccolumn02x3left/imats/chozosanccolumn02x3left_mp_opaquemaps_simple.bsmat",
	"maps/objects/magnetglovesp01cornerout90b/imats/magnetglovesp01cornerout90b_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part028_s5_mapmodel_03_mp_opaquemaps_simple_034.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part028_s5_mapmodel_04_mp_opaquemaps_simple_034.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part028_s5_mapmodel_24_mp_opaquemaps_simple_034.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part028_s5_mapmodel_25_mp_opaquemaps_simple_034.bsmat",
	"maps/objects/cavwaterrockpath01x4/imats/cavwaterrockpath01x4_mp_opaque_01.bsmat",
	"maps/objects/cavwaterrockpath02x4/imats/cavwaterrockpath02x4_mp_opaque_01.bsmat",
	"maps/objects/chozoallscaffold06/imats/chozoallscaffold06_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozoborderemmyjoint01/imats/chozoborderemmyjoint01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoborderemmyjoint02/imats/chozoborderemmyjoint02_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoborderemmyjoint04/imats/chozoborderemmyjoint04_mp_opaquemaps_simple.bsmat",
	"maps/objects/magnetglovesp01cornerin90b/imats/magnetglovesp01cornerin90b_mp_opaquemaps_simple.bsmat",
	"actors/props/cut_37_wall01/models/imats/cut_37_wall01_mp_opaquemaps_simple_01.bsmat",
	"actors/props/cut_37_wall01/models/imats/cut_37_wall01_mp_opaquemaps_simple_02.bsmat",
	"actors/props/cut_37_wall01/models/imats/cut_37_wall01_mp_opaquemaps_simple_03.bsmat",
	"actors/props/cut_37_wall01/models/imats/cut_37_wall01_mp_opaquemaps_simple_04.bsmat",
	"actors/props/cut_37_wallend01/models/imats/cut_37_wallend01_mp_opaquemaps_simple_01.bsmat",
	"actors/props/cut_37_wallend02/models/imats/cut_37_wallend02_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part008_r6_mapmodel_04_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part008_r6_mapmodel_04_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part015_e6_chozopathemmy01v301_part015path.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca137_mp_opaquemaps_simple_42.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca138_mp_opaquemaps_simple_42.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca139_mp_opaquemaps_simple_42.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca140_mp_opaquemaps_simple_42.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca141_mp_opaquemaps_simple_42.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca142_mp_opaquemaps_simple_42.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_r9_sg_casca147_mp_opaquemaps_simple_42.bsmat",
	"maps/objects/chozoemmybg01bx4/imats/chozoemmybg01bx4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopathemmy01x1b/imats/chozopathemmy01x1b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopipes01clamp01/imats/chozopipes01clamp01_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozopipes01clamp02/imats/chozopipes01clamp02_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/chozopipesthermal01mx1/imats/chozopipesthermal01mx1_pipes.bsmat",
	"maps/objects/chozopipesthermal01mx3/imats/chozopipesthermal01mx3_pipes.bsmat",
	"maps/objects/magnetglovesp01cornerin90/imats/magnetglovesp01cornerin90_mp_opaquemaps_simple.bsmat",
	"maps/objects/savestation001/imats/savestation001_mp_opaquemaps_simple_01.bsmat",
	"system/fx/generic/imats/varia_leftarmenergy_varia_leftarmenergy_varia_leftarmenergy.bsmat",
	"maps/objects/chozoallscaffold02/imats/chozoallscaffold02_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallscaffold03/imats/chozoallscaffold03_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallscaffold07/imats/chozoallscaffold07_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallscaffold08/imats/chozoallscaffold08_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmybg01x1/imats/chozoemmybg01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmypath01v2/imats/chozoemmypath01v2_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmypath01v3/imats/chozoemmypath01v3_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmypath01x4/imats/chozoemmypath01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozofrontpath02x1b/imats/chozofrontpath02x1b_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozofrontpath04x1d/imats/chozofrontpath04x1d_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozopathemmy01v2/imats/chozopathemmy01v2_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathemmy01v2/imats/chozopathemmy01v2_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozopathemmy01v3/imats/chozopathemmy01v3_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathemmy01v3/imats/chozopathemmy01v3_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozopathemmy01x4/imats/chozopathemmy01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathemmy01x4/imats/chozopathemmy01x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozopipesthermal01x1/imats/chozopipesthermal01x1_pipes.bsmat",
	"maps/objects/chozopipesthermal01x3/imats/chozopipesthermal01x3_pipes.bsmat",
	"maps/objects/magnetglovesp01cornerout/imats/magnetglovesp01cornerout_mp_opaquemaps_simple.bsmat",
	"actors/props/door_frblack_gen/models/imats/door_frblack_gen_mp_opaquemaps_simple_01.bsmat",
	"actors/props/door_frblack_gen/models/imats/door_frblack_gen_mp_opaquemaps_simple_02.bsmat",
	"cutscenes/0036enteremmyzone/fx/imats/door_frblack_gen_mp_opaquemaps_simple_01.bsmat",
	"cutscenes/0036enteremmyzone/fx/imats/door_frblack_gen_mp_opaquemaps_simple_02.bsmat",
	"maps/genericimats/chozomatconcreteblue05_generic.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel001_mp_opaquemaps_simple078.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel001_mp_opaquemaps_simple079.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel007_mp_opaquemaps_simple078.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel010_mp_opaquemaps_simple078.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel011_mp_opaquemaps_simple078.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel022_mp_opaquemaps_simple078.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel022_mp_opaquemaps_simple079.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel033_mp_opaquemaps_simple078.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_mapmodel10_part002_cristals.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part011_m1_mapmodel067_mp_opaquemaps_simple073.bsmat",
	"maps/objects/cavartifactorstatue/imats/cavartifactorstatue_mp_opaque_01.bsmat",
	"maps/objects/cavbackgroundrock01/imats/cavbackgroundrock01_mp_opaque_01.bsmat",
	"maps/objects/cavbackgroundrock02/imats/cavbackgroundrock02_mp_opaque_01.bsmat",
	"maps/objects/cavplatformrock04v4/imats/cavplatformrock04v4_mp_opaque_01.bsmat",
	"maps/objects/cavplatformrock04v5/imats/cavplatformrock04v5_mp_opaque_01.bsmat",
	"maps/objects/cavplatformrock04v6/imats/cavplatformrock04v6_mp_opaque_01.bsmat",
	"maps/objects/cavplatformrock04v8/imats/cavplatformrock04v8_mp_opaque_01.bsmat",
	"maps/objects/cavscorpiusbones01/imats/cavscorpiusbones01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/cavscorpiusbones02/imats/cavscorpiusbones02_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/cavscorpiusbones03/imats/cavscorpiusbones03_mp_opaquemaps_simple_03.bsmat",
	"maps/objects/chozobasebgcornerright01/imats/chozobasebgcornerright01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcornerright01/imats/chozobasebgcornerright01_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozofrontpath02x4/imats/chozofrontpath02x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozomagassetn03/imats/chozomagassetn03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozospecialfurnace/imats/chozospecialfurnace_mp_opaque_01.bsmat",
	"actors/props/cut_37_wdrain01/models/imats/cut_37_wdrain01_mp_opaquemaps_simple_05.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel08_mp_opaquemaps_simple078.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_o5_mapmodel08_mp_opaquemaps_simple079.bsmat",
	"maps/objects/chozobasebgcornerleft01/imats/chozobasebgcornerleft01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcornerleft01/imats/chozobasebgcornerleft01_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmycolumn01x1/imats/chozoemmycolumn01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmycolumn01x4/imats/chozoemmycolumn01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozofrontpath01x1a/imats/chozofrontpath01x1a_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozofrontpath01x1b/imats/chozofrontpath01x1b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozofrontpath01x1c/imats/chozofrontpath01x1c_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozofrontpath01x1d/imats/chozofrontpath01x1d_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part011_m1_mapmodel067_mp_opaquemaps_simple070.bsmat",
	"maps/objects/chozoborderemmy01/imats/chozoborderemmy01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoborderemmy02/imats/chozoborderemmy02_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmyplatform01x1/imats/chozoemmyplatform01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozofrontpath01x4/imats/chozofrontpath01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagassetn01/imats/chozomagassetn01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathemmy01x1b/imats/chozopathemmy01x1b_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoshipasset01/imats/chozoshipasset01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoshipasset02/imats/chozoshipasset02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrocklava06/imats/magdigrocklava06_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magnetglovesp01xhalf1/imats/magnetglovesp01xhalf1_mp_opaquemaps_simple.bsmat",
	"actors/props/cut_37_wall01/models/imats/cut_37_wall01_mp_opaquemaps_simple_05.bsmat",
	"maps/genericimats/cavwaterrockpathwet_generic.bsmat",
	"maps/objects/cavcolumncrystal03/imats/cavcolumncrystal03_mp_opaque_01.bsmat",
	"maps/objects/cavpathrockmod01v2/imats/cavpathrockmod01v2_mp_opaque_01.bsmat",
	"maps/objects/cavpathrockmod02v2/imats/cavpathrockmod02v2_mp_opaque_01.bsmat",
	"maps/objects/chozoallwall02corner/imats/chozoallwall02corner_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgmagwallb01/imats/chozobgmagwallb01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgmagwallb02/imats/chozobgmagwallb02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgmagwallb03/imats/chozobgmagwallb03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgmagwallb04/imats/chozobgmagwallb04_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgmagwallb05/imats/chozobgmagwallb05_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgmagwallb06/imats/chozobgmagwallb06_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgmagwallb07/imats/chozobgmagwallb07_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgmagwallb08/imats/chozobgmagwallb08_mp_opaquemaps_simple_01.bsmat",
	"actors/props/cut_37_wallend01/models/imats/cut_37_wallend01_mp_opaquemaps_simple_02.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/trail_cannon_cannontrail.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part008_r6_mapmodel_01_mp_opaquemaps_simple_45.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part008_r6_mapmodel_03_mp_opaquemaps_simple_45.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part008_r6_mapmodel_06_mp_opaquemaps_simple_45.bsmat",
	"maps/objects/cavcolumcrystal01/imats/cavcolumcrystal01_mp_opaque_01.bsmat",
	"maps/objects/cavcolumcrystal02/imats/cavcolumcrystal02_mp_opaque_01.bsmat",
	"maps/objects/cavrockdetail01/imats/cavrockdetail01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmybgcorner02a/imats/chozoemmybgcorner02a_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybgcorner02a/imats/chozoemmybgcorner02a_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmybgcorner02b/imats/chozoemmybgcorner02b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybgcorner02b/imats/chozoemmybgcorner02b_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmybgcorner02c/imats/chozoemmybgcorner02c_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybgcorner02c/imats/chozoemmybgcorner02c_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmypath01endl/imats/chozoemmypath01endl_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmypath01endr/imats/chozoemmypath01endr_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopathemmy01endl/imats/chozopathemmy01endl_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopathmagjoint01/imats/chozopathmagjoint01_mp_opaquemaps_simple.bsmat",
	"maps/objects/magnetglovesp01endl/imats/magnetglovesp01endl_mp_opaquemaps_simple.bsmat",
	"maps/objects/magnetglovesp01endr/imats/magnetglovesp01endr_mp_opaquemaps_simple.bsmat",
	"actors/props/cut_57_statuebroken/models/imats/cavrockbackground07_generic.bsmat",
	"maps/objects/caverockborder01/imats/caverockborder01_mp_opaquemaps_simple.bsmat",
	"maps/objects/caverockborder02/imats/caverockborder02_mp_opaquemaps_simple.bsmat",
	"maps/objects/caverockborder03/imats/caverockborder03_mp_opaquemaps_simple.bsmat",
	"maps/objects/caverockborder04/imats/caverockborder04_mp_opaquemaps_simple.bsmat",
	"maps/objects/cavrockwater01/imats/cavrockwater01_mp_opaque_01.bsmat",
	"maps/objects/chozoallasset04/imats/chozoallasset04_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallasset04/imats/chozoallasset04_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoallasset05/imats/chozoallasset05_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallasset05/imats/chozoallasset05_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoallwall02x2/imats/chozoallwall02x2_mp_opaquemaps_simple01.bsmat",
	"maps/objects/chozoallwall02x2/imats/chozoallwall02x2_mp_opaquemaps_simple03.bsmat",
	"maps/objects/chozoallwall02x4/imats/chozoallwall02x4_mp_opaquemaps_simple01.bsmat",
	"maps/objects/chozoallwall02x4/imats/chozoallwall02x4_mp_opaquemaps_simple02.bsmat",
	"maps/objects/chozoallwall02x4/imats/chozoallwall02x4_mp_opaquemaps_simple03.bsmat",
	"maps/objects/chozoallwall02x4/imats/chozoallwall02x4_mp_opaquemaps_simple04.bsmat",
	"maps/objects/chozobasebgcorner01/imats/chozobasebgcorner01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorner01/imats/chozobasebgcorner01_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobasebgcorner02/imats/chozobasebgcorner02_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobasebgcorner03/imats/chozobasebgcorner03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorner03/imats/chozobasebgcorner03_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobasebgcorner04/imats/chozobasebgcorner04_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorner04/imats/chozobasebgcorner04_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/magnetziplinesp01x1/imats/magnetziplinesp01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magnetziplinesp01x3/imats/magnetziplinesp01x3_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magnetziplinespendl/imats/magnetziplinespendl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magnetziplinespendr/imats/magnetziplinespendr_mp_opaquemaps_simple_01.bsmat",
	"actors/props/box_grapple_cv_001/fx/imats/boxgrapplemesh_noise.bsmat",
	"maps/genericimats/chozomatmetalbrown07_generic.bsmat",
	"maps/objects/cavcolumcrystal04/imats/cavcolumcrystal04_mp_opaque_01.bsmat",
	"maps/objects/chozoallwall03/imats/chozoallwall03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallwall03/imats/chozoallwall03_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoallwall03/imats/chozoallwall03_mp_opaquemaps_simple_03.bsmat",
	"maps/objects/chozocavproto_04b/imats/chozocavproto_04b_mp_opaquemaps_01.bsmat",
	"maps/objects/chozoemmypath01x1/imats/chozoemmypath01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozomagplatform100/imats/chozomagplatform100_mp_opaque_02.bsmat",
	"maps/objects/chozomagplatform200/imats/chozomagplatform200_mp_opaque_02.bsmat",
	"maps/objects/chozomagplatformend/imats/chozomagplatformend_mp_opaque_02.bsmat",
	"maps/objects/chozopathemmy01x1/imats/chozopathemmy01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/magdigrocklava01/imats/magdigrocklava01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magnetglovesp01x1/imats/magnetglovesp01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/magnetglovesp01x2/imats/magnetglovesp01x2_mp_opaquemaps_simple.bsmat",
	"maps/objects/magnetglovesp01x3/imats/magnetglovesp01x3_mp_opaquemaps_simple.bsmat",
	"actors/props/ammorecharge/fx/imats/charge_fx_arcs.bsmat",
	"actors/props/energyrecharge/fx/imats/charge_fx_arcs.bsmat",
	"actors/props/totalrechargestation/fx/imats/charge_fx_arcs.bsmat",
	"maps/objects/cavcolumnrock01/imats/cavcolumnrock01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgpipescorner_01/imats/chozobgpipescorner_01_mp_opaquemaps_simple.bsmat",
	"maps/objects/shipyardrock01/imats/shipyardrock01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/shipyardrock02/imats/shipyardrock02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/shipyardrock03/imats/shipyardrock03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/shipyardrock06/imats/shipyardrock06_mp_opaquemaps_simple_01.bsmat",
	"maps/genericimats/cavrockbackground02_generic.bsmat",
	"maps/genericimats/cavrockbackground03_generic.bsmat",
	"maps/genericimats/cavrockbackground05_generic.bsmat",
	"maps/genericimats/cavrockbackground06_generic.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part005_e4_mapmodel01_mp_opaquemaps_simple_89.bsmat",
	"maps/objects/cavrockcrystal01/imats/cavrockcrystal01_mp_opaque_01.bsmat",
	"maps/objects/chozobasebg01x1/imats/chozobasebg01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebg01x1/imats/chozobasebg01x1_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobasebg01x4/imats/chozobasebg01x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobasebg02x4/imats/chozobasebg02x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebg02x4/imats/chozobasebg02x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobasebg03x4/imats/chozobasebg03x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebg03x4/imats/chozobasebg03x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmybg02x1/imats/chozoemmybg02x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybg02x1/imats/chozoemmybg02x1_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmybg02x4/imats/chozoemmybg02x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybg02x4/imats/chozoemmybg02x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozomagasset01/imats/chozomagasset01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magrockborder02/imats/magrockborder02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magrockborder03/imats/magrockborder03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magrockborder04/imats/magrockborder04_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/cavedigrock01/imats/cavedigrock01_mp_opaquemaps_simple.bsmat",
	"maps/objects/cavedigrock02/imats/cavedigrock02_mp_opaquemaps_simple.bsmat",
	"maps/objects/cavedigrock03/imats/cavedigrock03_mp_opaquemaps_simple.bsmat",
	"maps/objects/cavedigrock04/imats/cavedigrock04_mp_opaquemaps_simple.bsmat",
	"maps/objects/cavrockinit01/imats/cavrockinit01_mp_opaque_simple.bsmat",
	"maps/objects/cavrockinit02/imats/cavrockinit02_mp_opaque_simple.bsmat",
	"maps/objects/chozobasepath02x1/imats/chozobasepath02x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopathemmy02bgcorl/imats/chozopathemmy02bgcorl_mp_opaque_01.bsmat",
	"maps/objects/chozopathemmy02bgcorr/imats/chozopathemmy02bgcorr_mp_opaque_01.bsmat",
	"maps/objects/chozopathemmy02x4/imats/chozopathemmy02x4_mp_opaque_01.bsmat",
	"maps/genericimats/lavafrontsolid01_generic.bsmat",
	"maps/genericimats/lavasolid01_generic.bsmat",
	"maps/objects/baselabprop01x03/imats/baselabprop01x03_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozocavproto_03/imats/chozocavproto_03_mp_opaque_02.bsmat",
	"actors/props/doorshieldsupermissile/fx/imats/shieldmissile_shieldfx.bsmat",
	"maps/genericimats/chozometalsimmetry_generic.bsmat",
	"maps/objects/cavpathrock01v2/imats/cavpathrock01v2_mp_opaque_01.bsmat",
	"maps/objects/cavpathrock01v3/imats/cavpathrock01v3_mp_opaque_01.bsmat",
	"maps/objects/cavpathrock01v4/imats/cavpathrock01v4_mp_opaque_01.bsmat",
	"maps/objects/cavpathrock01v5/imats/cavpathrock01v5_mp_opaque_01.bsmat",
	"maps/objects/cavpathrock03v2/imats/cavpathrock03v2_mp_opaque_01.bsmat",
	"maps/objects/cavpathrock03v3/imats/cavpathrock03v3_mp_opaque_01.bsmat",
	"maps/objects/cavrockpillar01/imats/cavrockpillar01_mp_opaque_01.bsmat",
	"maps/objects/chozopathemmy02bgx1/imats/chozopathemmy02bgx1_mp_opaque_01.bsmat",
	"maps/objects/chozopathemmy02endl/imats/chozopathemmy02endl_mp_opaque_01.bsmat",
	"maps/objects/chozopathemmy02endr/imats/chozopathemmy02endr_mp_opaque_01.bsmat",
	"maps/objects/magrockborder01/imats/magrockborder01_mp_opaquemaps_simple.bsmat",
	"maps/genericimats/bubblesaqua01_generic.bsmat",
	"maps/objects/caverockborder05/imats/caverockborder05_mp_opaque_01.bsmat",
	"maps/objects/chozobgpipes01x1/imats/chozobgpipes01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgpipes01x4/imats/chozobgpipes01x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/baselabprop01/imats/baselabprop01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopathemmy02x1/imats/chozopathemmy02x1_mp_opaque_01.bsmat",
	"maps/objects/maproom001/imats/maproom001_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/cavrockwater02/imats/cavrockwater02_mp_opaque_01.bsmat",
	"maps/objects/cavwaterrock01/imats/cavwaterrock01_mp_opaque_01.bsmat",
	"maps/objects/cavwaterrock02/imats/cavwaterrock02_mp_opaque_01.bsmat",
	"maps/objects/chozobgpipes02/imats/chozobgpipes02_mp_opaquemaps_simple.bsmat",
	"actors/props/gobblerweb/models/imats/gobblerweb_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagasset03/imats/chozomagasset03_mp_opaque_01.bsmat",
	"maps/objects/chozomagasset04/imats/chozomagasset04_mp_opaque_01.bsmat",
	"maps/objects/chozomagasset05/imats/chozomagasset05_mp_opaque_01.bsmat",
	"maps/objects/chozomagasset06/imats/chozomagasset06_mp_opaque_01.bsmat",
	"actors/props/doorshieldmissile/fx/imats/shieldmissile_shieldfx.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part012_e7_tunel_00_glasscave.bsmat",
	"maps/objects/chozocavproto_07/imats/chozocavproto_07_mp_opaque_01.bsmat",
	"maps/objects/chozogrid02/imats/chozogrid02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrock02/imats/magdigrock02_mp_opaquemaps_simple.bsmat",
	"actors/props/doorwidebeam/fx/imats/shieldwidefx_shieldfx.bsmat",
	"maps/fx/lightningstroke/imats/lightningstroke_material.bsmat",
	"maps/genericimats/chozosteelplates_generic.bsmat",
	"maps/genericimats/rockbackground01_generic.bsmat",
	"maps/objects/cavpathrock01/imats/cavpathrock01_mp_opaque_01.bsmat",
	"maps/objects/cavpathrock02/imats/cavpathrock02_mp_opaque_01.bsmat",
	"maps/objects/cavpathrock03/imats/cavpathrock03_mp_opaque_01.bsmat",
	"maps/objects/chozobgemmy01/imats/chozobgemmy01_mp_opaque_01.bsmat",
	"maps/objects/magpathrock01/imats/magpathrock01_mp_opaque_01.bsmat",
	"maps/genericimats/concretegreen01_generic.bsmat",
	"maps/objects/cavcrystal01/imats/cavcrystal01_mp_opaque_01.bsmat",
	"maps/objects/cavcrystal03/imats/cavcrystal03_mp_opaque_01.bsmat",
	"maps/objects/cavcrystal04/imats/cavcrystal04_mp_opaque_01.bsmat",
	"maps/objects/cavcrystal05/imats/cavcrystal05_mp_opaque_01.bsmat",
	"maps/objects/cavcrystal06/imats/cavcrystal06_mp_opaque_01.bsmat",
	"maps/objects/cavcrystal07/imats/cavcrystal07_mp_opaque_01.bsmat",
	"actors/props/elevator/fx/imats/elevator_glow_elevatorglow.bsmat",
	"maps/objects/cavrock06/imats/cavrock06_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_m5_mapmodel_070_part010ice.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_m5_mapmodel_071_part010ice.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_m5_mapmodel_073_part010ice.bsmat",
	"maps/objects/chozoemmyborderwalljoint01/imats/chozoemmyborderwalljoint01_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_px_cooldownzip_part010ice.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_s6_mapmodel_01_part010ice.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part012_s8_cooldown_00_part013ice.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part012_s8_cooldown_01_part013ice.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part013_px_cooldownzip_part010ice.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part027_px_cooldown_00_part013ice.bsmat",
	"maps/objects/caverock01/imats/caverock01_mp_opaque_01.bsmat",
	"maps/objects/caverock02/imats/caverock02_mp_opaque_01.bsmat",
	"maps/objects/caverock03/imats/caverock03_mp_opaque_01.bsmat",
	"actors/props/elevator/fx/imats/chains_glow_chainglow.bsmat",
	"system/fx/generic/imats/varia_cannon_smallcover_cover.bsmat",
	"maps/objects/cavpilar01/imats/cavpilar01_mp_opaque_01.bsmat",
	"actors/props/samuship_int/models/imats/samusship_int_window.bsmat",
	"maps/genericimats/chozodecal06_generic.bsmat",
	"maps/genericimats/mudmatcave07_generic.bsmat",
	"maps/genericimats/mudmatcave09_generic.bsmat",
	"maps/objects/cavrock04/imats/cavrock04_mp_opaque_01.bsmat",
	"maps/objects/cavrock05/imats/cavrock05_mp_opaque_01.bsmat",
	"maps/objects/magrock01/imats/magrock01_mp_opaque_01.bsmat",
	"maps/objects/chozoemmyborderwall02/imats/chozoemmyborderwall02_mp_opaquemaps_simple_01.bsmat",
	"actors/props/door_frblack_protoemmy/models/imats/door_frblack_protoemmy_mp_blackdoorfr_fw_2.bsmat",
	"maps/fx/cloudlightning/imats/cloudquad00_material.bsmat",
	"maps/genericimats/sanddunes01_generic.bsmat",
	"maps/objects/cavegg01/imats/cavegg01_mp_opaque_01.bsmat",
	"maps/objects/cavegg02/imats/cavegg02_mp_opaque_01.bsmat",
	"maps/objects/cavegg03/imats/cavegg03_mp_opaque_01.bsmat",
	"cutscenes/0055scorpiusphase2/fx/imats/fromocitemtoinvi_ocitemtoinvi.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part019_n6_plane_part019_n6.bsmat",
	"actors/props/zipline_frozen/models/imats/zipline_frozen_part010ice.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part013_px_ice_part013ice.bsmat",
	"maps/genericimats/sandbase01_generic.bsmat",
	"actors/props/door_frblack_gen/models/imats/door_frblack_gen_mp_blackdoorfr_fw_2.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/trails_energy_trail.bsmat",
	"cutscenes/0036enteremmyzone/fx/imats/door_frblack_gen_mp_blackdoorfr_fw_2.bsmat",
	"maps/genericimats/treemat01_generic.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/trails_energy_fume.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/absortion_cu_handabsortion.bsmat",
	"actors/props/breakablecave016/models/imats/breakablecave016_mp_opaquemaps_simple_nonm_dissolve_1.bsmat",
	"maps/objects/cavcrystal08/imats/cavcrystal08_mp_opaquemaps_simple_nonm.bsmat",
	"maps/objects/cavcrystal09/imats/cavcrystal09_mp_opaquemaps_simple_nonm.bsmat",
	"maps/genericimats/watersolid_generic.bsmat",
	"actors/props/db_dif_cv_001/models/imats/db_dif_cv_001_mp_opaquemaps_simple_nonm_dissolve_1.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_mapmodel_09_watersolid.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_m5_mapmodel_039_watersolid.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_m5_mapmodel_042_watersolid.bsmat",
	"maps/objects/caverockborder07/imats/caverockborder07_mp_opaque_01.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_startrays_cannon_body.bsmat",
	"actors/props/breakablecave016/models/imats/breakablecave016_mp_opaquemaps_simple_nonm_dissolve_3.bsmat",
	"actors/props/breakablecave016/models/imats/breakablecave016_mp_opaquemaps_simple_nonm_dissolve_4.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_rays_radial_fast.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_rays_radial_rays.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_startrays_center.bsmat",
	"actors/props/db_dif_cv_001/models/imats/db_dif_cv_001_mp_opaquemaps_simple_nonm_dissolve_3.bsmat",
	"maps/genericimats/magnetmat02_generic.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_rays_wide_rays.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_startrays_body.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_startrays_rays.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_rays_end_rays.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/plasmabeam_chargedprojectile_projectile_rays.bsmat",
	"actors/items/drop_life_cut/models/imats/drop_life_cut_drop_lfe_cut.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/aura_rays_rays.bsmat",
	"maps/genericimats/breakableorganic2_generic.bsmat",
	"maps/genericimats/breakableorganic_generic.bsmat",
	"maps/genericimats/magnetmat01_generic.bsmat",
	"system/fx/generic/imats/varia_shoulderrays_var_raysfeet.bsmat",
	"system/fx/generic/imats/varia_feetrays_right_raysfeet.bsmat",
	"cutscenes/0001gameintro_fight/fx/imats/metroidnization_fresnel.bsmat",
	"system/fx/generic/imats/varia_shoulderrays_raysfeet.bsmat",
	"system/fx/generic/imats/varia_bodyrays_raysfeet.bsmat",
	"system/fx/generic/imats/varia_feetrays_raysfeet.bsmat",
	"maps/genericimats/waterfallcave01_generic.bsmat",
	"maps/genericimats/waterfallcave02_generic.bsmat",
	"maps/genericimats/waterfallcave03_generic.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/rayscannon_048_rayscannon.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/rays_cube_rayscube.bsmat",
	"actors/props/breakablecave016/models/imats/breakablecave016_cascamat.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/rayscannon_rayscannon.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/rayscannon_init_rays.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part012_px_cooldownhot_p12hot.bsmat",
	"cutscenes/0053genericcupowerobtention/fx/imats/rays_cannon_rays.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/flames_ic_centralray.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/flames_ic_lateralray.bsmat",
	"maps/genericimats/chozomatmetalwhite02_generic.bsmat",
	"maps/genericimats/chozomatmetalwhite03_generic.bsmat",
	"actors/props/platformcavewaterb/models/imats/platformcavewaterb_watermask.bsmat",
	"actors/props/watercave08a/models/imats/watercave08a_watermask.bsmat",
	"maps/objects/fxwaterfallcave01/imats/fxwaterfallcave01_material.bsmat",
	"maps/objects/chozoemmywallcorner01x1/imats/chozoemmywallcorner01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmywallcorner02x1/imats/chozoemmywallcorner02x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmywallcorner01/imats/chozoemmywallcorner01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmywallcorner02/imats/chozoemmywallcorner02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmywallcorner03/imats/chozoemmywallcorner03_mp_opaquemaps_simple_01.bsmat",
	"maps/genericimats/chozomatconcretepattern02_generic.bsmat",
	"maps/genericimats/chozomatconcretepattern04_generic.bsmat",
	"maps/genericimats/chozomatpaintedmetalred02_generic.bsmat",
	"maps/genericimats/chozomatconcretepurple01_generic.bsmat",
	"maps/objects/chozoemmywall01x1/imats/chozoemmywall01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmywall01x4/imats/chozoemmywall01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmywall02x1/imats/chozoemmywall02x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmywall02x4/imats/chozoemmywall02x4_mp_opaquemaps_simple_01.bsmat",
	"maps/fx/emmyzoneletters00/fx/imats/emmyzoneletters00_material.bsmat",
	"maps/genericimats/chozomatconcretegreen01_generic.bsmat",
	"maps/genericimats/chozomatpaintedyellow02_generic.bsmat",
	"maps/genericimats/chozomatconcretebase01_generic.bsmat",
	"maps/genericimats/chozomatconcretebase02_generic.bsmat",
	"maps/genericimats/chozomatconcretebase03_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue01_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue02_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue03_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue04_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue06_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue07_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue08_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue10_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue13_generic.bsmat",
	"maps/genericimats/chozomatconcreteblue14_generic.bsmat",
	"maps/genericimats/chozomatconcretegray01_generic.bsmat",
	"maps/genericimats/chozomatconcretegray02_generic.bsmat",
	"maps/genericimats/chozomatconcretegray03_generic.bsmat",
	"maps/genericimats/chozomatconcretegray04_generic.bsmat",
	"maps/genericimats/chozomatconcretegray05_generic.bsmat",
	"maps/genericimats/chozomatconcretegray06_generic.bsmat",
	"maps/genericimats/chozomatconcretegray07_generic.bsmat",
	"maps/genericimats/chozomatmetalyellow02b_generic.bsmat",
	"maps/objects/fxpouringwaterx4/imats/fxpouringwaterx4_material.bsmat",
	"maps/genericimats/chozomatmetalyellow02_generic.bsmat",
	"maps/genericimats/chozomatmetalyellow03_generic.bsmat",
	"maps/genericimats/chozomatmetalyellow04_generic.bsmat",
	"actors/props/platformcavewaterb/models/imats/platformcavewaterb_glass.bsmat",
	"maps/genericimats/chozomatmetalblack01_generic.bsmat",
	"maps/genericimats/chozomatmetalbrown01_generic.bsmat",
	"maps/genericimats/chozomatmetalbrown02_generic.bsmat",
	"maps/genericimats/chozomatmetalbrown03_generic.bsmat",
	"maps/genericimats/chozomatmetalbrown04_generic.bsmat",
	"maps/genericimats/chozomatmetalbrown05_generic.bsmat",
	"maps/genericimats/chozomatmetalbrown08_generic.bsmat",
	"maps/genericimats/chozomatmetalbrown09_generic.bsmat",
	"maps/genericimats/chozomatmetalgreen01_generic.bsmat",
	"maps/genericimats/chozomatmetalgreen02_generic.bsmat",
	"maps/genericimats/chozomatmetalgreen03_generic.bsmat",
	"maps/genericimats/chozomatmetalgreen07_generic.bsmat",
	"maps/genericimats/chozomatmetalwhite01_generic.bsmat",
	"maps/genericimats/chozomatmetalwhite04_generic.bsmat",
	"maps/genericimats/chozomatmetalwhite05_generic.bsmat",
	"maps/genericimats/chozomatmetalwhite06_generic.bsmat",
	"maps/genericimats/chozomatcublue01_generic.bsmat",
	"maps/genericimats/chozomatcublue06_generic.bsmat",
	"maps/genericimats/chozomatflatblack01_generic.bsmat",
	"maps/genericimats/chozomatflatblack02_generic.bsmat",
	"maps/genericimats/chozomatflatblack03_generic.bsmat",
	"maps/genericimats/chozomatflatblack04_generic.bsmat",
	"maps/genericimats/chozomatmetalblue02_generic.bsmat",
	"maps/genericimats/chozomatmetalblue03_generic.bsmat",
	"maps/genericimats/chozomatmetalblue04_generic.bsmat",
	"maps/genericimats/chozomatmetalblue05_generic.bsmat",
	"maps/genericimats/chozomatmetalblue06_generic.bsmat",
	"maps/genericimats/chozomatmetalblue09_generic.bsmat",
	"maps/genericimats/chozomatmetalblue11_generic.bsmat",
	"maps/genericimats/chozomatmetalgray01_generic.bsmat",
	"maps/genericimats/chozomatmetalgray02_generic.bsmat",
	"maps/genericimats/chozomatmetalgray03_generic.bsmat",
	"maps/genericimats/chozomatmetalgray04_generic.bsmat",
	"maps/genericimats/chozomatmetalgray05_generic.bsmat",
	"maps/genericimats/chozomatmetalgray06_generic.bsmat",
	"maps/genericimats/chozomatmetalgray08_generic.bsmat",
	"maps/genericimats/chozomatmetalgray09_generic.bsmat",
	"maps/genericimats/chozomatmetalgray10_generic.bsmat",
	"maps/genericimats/chozomatmetalgray11_generic.bsmat",
	"maps/genericimats/chozomatmetalgray13_generic.bsmat",
	"maps/genericimats/chozomatmetalgray15_generic.bsmat",
	"maps/genericimats/chozomatmetalgray16_generic.bsmat",
	"maps/genericimats/chozomatmetalgrey03_generic.bsmat",
	"maps/genericimats/chozomatcircuits01_generic.bsmat",
	"maps/genericimats/chozomatflatblue01_generic.bsmat",
	"maps/genericimats/chozomatflatgray01_generic.bsmat",
	"maps/genericimats/chozomatmetalred02_generic.bsmat",
	"maps/genericimats/chozomatmetalred03_generic.bsmat",
	"maps/genericimats/chozomatmetalred05_generic.bsmat",
	"maps/genericimats/chozomatpipes01_generic.bsmat",
	"maps/genericimats/chozomatpipes02_generic.bsmat",
	"maps/genericimats/chozomatpipes03_generic.bsmat",
	"maps/genericimats/chozomatpipes05_generic.bsmat",
	"maps/genericimats/chozomatpipes09_generic.bsmat",
	"maps/genericimats/chozomatpipes10_generic.bsmat",
	"maps/genericimats/chozomatpipes11_generic.bsmat",
	"maps/genericimats/chozomatpipes12_generic.bsmat",
	"maps/genericimats/chozomatpipes13_generic.bsmat",
	"maps/genericimats/waterfrontsolid_generic.bsmat",
	"maps/genericimats/chozomatmetalred01_generic.bsmat",
	"maps/objects/cavewater00/imats/cavewater00_drops.bsmat",
	"maps/objects/cavewater01/imats/cavewater01_drops.bsmat",
	"actors/items/item_energyfragment/models/imats/item_energyfragment_glow.bsmat",
	"actors/items/item_energyfragment/models/imats/item_energyfragment_inner.bsmat",
	"actors/items/powerup_chargebeam/models/imats/powerup_chargebeam_mp_glass_01.bsmat",
	"actors/props/samus_ship_b/models/imats/samus_ship_b_mat_baseenginepropulsion.bsmat",
	"actors/props/doorcentralunit/fx/imats/fracture_explosion_mat.bsmat",
	"maps/genericimats/selfilumwhite_generic.bsmat",
	"actors/props/cave_elevator/models/imats/caveelevator_cristales.bsmat",
	"actors/props/samus_ship_b/models/imats/samus_ship_b_window.bsmat",
	"maps/genericimats/levelemmy_generic.bsmat",
	"maps/objects/cavewater00/imats/cavewater00_water.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_o2_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_o2_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_o2_lightshaft03_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_o2_lightshaft04_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_o2_lightshaft05_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part007_o1_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part007_o1_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_o1_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_o1_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part021_o1_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part021_o1_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o1_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o1_lightshaft02_aquatrench.bsmat",
	"cutscenes/0057scorpiusdeath/fx/imats/scorpiusdissolveouter_ball.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part011_m1_lshaft01_lightsfinal.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part011_m1_lshaft02_lightsfinal.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part011_m1_lshaft05_lightsfinal.bsmat",
	"cutscenes/0057scorpiusdeath/fx/imats/scorpiusdissolve_ball.bsmat",
	"cutscenes/0057scorpiusdeath/fx/imats/scorpiusdissolveouter.bsmat",
	"cutscenes/0057scorpiusdeath/fx/imats/scorpiusdissolve.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/ship_trail_2_material.bsmat",
	"actors/props/ev_entercu_cv_001/models/imats/ev_entercu_cv_001_mp_opaque_constant_selfilum01.bsmat",
	"cutscenes/0001gameintro_space/fx/imats/ship_trail_material.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part012_e7_mattepaintrocks01_mattepaintingbaselab003smoke01.bsmat",
	"cutscenes/0054scorpiuspresentation/fx/imats/scorpiusscream_distortion_scorpiusscream_distortion.bsmat",
	"actors/characters/scorpius/fx/imats/trail_grab_grabtrail.bsmat",
	"actors/characters/scorpius/fx/imats/trail_ballprick_ballpricktrail.bsmat",
	"actors/props/samuship_int/models/imats/console_consolecdetails.bsmat",
	"actors/props/samuship_int/models/imats/console_consolebgraphs.bsmat",
	"maps/genericimats/vertexmetalfw_generic.bsmat",
	"actors/props/samuship_int/models/imats/console_consoleabase.bsmat",
	"actors/props/samuship_int/models/imats/console_consolebbase.bsmat",
	"actors/characters/scorpius/fx/imats/trail_tailsmash_trailsmash.bsmat",
	"maps/objects/fxfiretornado01/imats/tornado_tornadomat.bsmat",
	"actors/characters/scorpius/fx/imats/trail_whiplash_whiplash.bsmat",
	"maps/fx/magmaheat/imats/magmaheatplane01_distortion.bsmat",
	"actors/props/fx_heat_door/fx/imats/distortionplane_distortion.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part012_e7_mattepaintbackground01_part012_mattepaintbackgorund01.bsmat",
	"actors/characters/scorpius/fx/imats/damage.bsmat",
	"actors/props/samuship_int/models/imats/console_consoleahud.bsmat",
	"actors/props/fx_heat_tunnel/fx/imats/distortion_distortion.bsmat",
	"actors/props/samuship_int/models/imats/console_consolecbase.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_s6_mattepaint01_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_matte02_part010_mattepaintbackgorund01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part012_e7_mattepaintrocks01_part012_mattepaintrocks01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part010_jg9_matte01_part010_mattepaintrocks01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part009_p_lightcut_cutlight.bsmat",
	"maps/genericimats/chozomatconcreteblue01fwibl_generic.bsmat",
	"maps/genericimats/selfilumquarentine_generic.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_mapmodel14_mp_vtbackground_75.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_mapmodel18_mp_vtbackground_73.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_mapmodel18_mp_vtbackground_74.bsmat",
	"maps/genericimats/selfilumexposed01_generic.bsmat",
	"maps/genericimats/selfilumexposed02_generic.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part004_o6_matte_mp_vtbackground_73.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part004_o6_matte_mp_vtbackground_74.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part004_o6_matte_mp_vtbackground_75.bsmat",
	"maps/objects/communicationroombgcam/imats/communicationroombgcam_crbg01.bsmat",
	"actors/props/samuship_int/models/imats/samusship_int_selfilumred.bsmat",
	"maps/genericimats/selfilumchozo01_generic.bsmat",
	"maps/genericimats/selfilumgreen01_generic.bsmat",
	"maps/genericimats/selfilumwhite01_generic.bsmat",
	"maps/genericimats/selfilumwhiteap_generic.bsmat",
	"maps/objects/communicationroombg/imats/communicationroombg_crbg01.bsmat",
	"cutscenes/0057scorpiusdeath/fx/imats/handfresnel_scorpius.bsmat",
	"maps/genericimats/selfilumcyan01_generic.bsmat",
	"maps/genericimats/chozomatpipes02fwibl_generic.bsmat",
	"maps/genericimats/selfilumrails_generic.bsmat",
	"maps/genericimats/selfilumred01_generic.bsmat",
	"actors/props/planetzdr_background/models/imats/planetzdr_background_background.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samusfacial_eyelash.bsmat",
	"maps/genericimats/chozomatconcreteblue01fw_generic.bsmat",
	"maps/objects/lshaftlamp01/imats/lshaftlamp01_lamp.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part002_s5_mapmodel05_mp_background_fw_091.bsmat",
	"maps/genericimats/chozomatconcretepattern04fw_generic.bsmat",
	"actors/props/cutmodel49wall01/models/imats/cutmodel49wall01_mp_background_fw_035.bsmat",
	"maps/fx/cooldownevent/imats/snowparticles01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part001_m4_mapmodel042_mp_blend_88.bsmat",
	"maps/objects/communicationroombgcam/imats/communicationroombgcam_crbg07.bsmat",
	"maps/objects/magmaparticles02/imats/magmaparticles02.bsmat",
	"maps/objects/communicationroombg/imats/communicationroombg_crbg07.bsmat",
	"maps/genericimats/leavemat02_generic.bsmat",
	"maps/objects/lshaftlamp02/imats/lshaftlamp02_mp_blend_01.bsmat",
	"actors/characters/samus/fx/imats/animfresnel.bsmat",
	"maps/objects/rain01/imats/rain01_mp_blend_01.bsmat",
	"maps/objects/magmaparticles01/imats/magmaparticles01.bsmat",
	"maps/objects/snowparticles01/imats/snowparticles01.bsmat",
	"actors/props/maproom/fx/imats/sonar_sphere_explosionsonar.bsmat",
	"actors/props/accesspoint/models/imats/accesspoint_mp_opaqueconstantcolor.bsmat",
	"actors/props/doorcentralunit/fx/imats/lampfresnel_lampfresnel.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part025_jp1_planereflect_01_maproom_cave025_01.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part023_o9_planereflection_cavepart023plane01.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/absortionbody_fresnel.bsmat",
	"actors/props/elevator/models/imats/elevator_mp_opaqueconstantcolor.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part003_p0_reflection_part003_p0_reflection.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part014_p3_reflection_part014_p3_reflection.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part019_n6_planereflection003_part19_floor2.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part006_n1_planereflection_part006_floor.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part019_n6_planereflection001_p19_floor2.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part024_n1_planereflection_part024_floor.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part029_n1_planereflection_part029_floor.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part030_n1_planereflection_part030_floor.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part019_n6_planereflection_part19_floor.bsmat",
	"actors/items/item_missiletankplus/models/imats/item_missiletankplus_mat01.bsmat",
	"actors/props/maproom/fx/imats/ring_sphere_row.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part019_n6_planereflection002_p19_wall.bsmat",
	"actors/characters/chozocommander/models/imats/chozocommander_emisivo.bsmat",
	"actors/items/item_powerbombtank/models/imats/item_powerbombtank_mat01.bsmat",
	"actors/items/item_missiletank/models/imats/item_missiletank_mat01.bsmat",
	"maps/fx/aquabubbles/imats/aquabubbles02_dummymat.bsmat",
	"actors/fx/flickeringlight01/fx/imats/flickeringselfilumwhite01_generic.bsmat",
	"actors/props/savestation/models/imats/savestation_emisive.bsmat",
	"maps/levels/c10_samus/s010_cave/models/imats/part031_a3_floorreflect_floor01.bsmat",
	"maps/genericimats/blackdoorfr_generic.bsmat",
	"maps/genericimats/vignette_generic.bsmat",
	"maps/genericimats/vignettesolid_generic.bsmat",
	"actors/characters/chozocommanderx/fx/imats/materia_x.bsmat",
	"actors/characters/chozowarriorxnormal/models/imats/chozowarriorxnormal_tentacles.bsmat",
	"actors/characters/chozowarriornormal/models/imats/chozowarriornormal_shield.bsmat",
	"actors/characters/chozowarriornormal/models/imats/chozowarriornormal_spear.bsmat",
	"actors/characters/chozowarriorxnormal/models/imats/chozowarriorxnormal_body.bsmat",
	"actors/characters/chozowarrior/fx/imats/shieldbreak_material.bsmat",
	"actors/characters/chozowarriorxnormal/models/imats/chozowarriorxnormal_body_02.bsmat",
	"actors/characters/chozowarriornormal/models/imats/chozowarriornormal_body_02.bsmat",
	"actors/characters/chozowarriornormal/models/imats/chozowarriornormal_body.bsmat",
	"actors/characters/chozowarriorxnormal/models/imats/chozowarriorxnormal_tentaclesaux.bsmat",
	"actors/characters/chozowarriorx/fx/imats/mudwave01fx_mudwave01fx.bsmat",
	"actors/characters/chozowarriorx/fx/imats/mudwave02fx_mudwave02fx.bsmat",
	"actors/characters/chozowarriorx/fx/imats/mudtrail_chozomudtrail.bsmat",
	"actors/characters/chozowarriorx/fx/imats/mudbeamsplash01fx_mudbeamsplash01fx.bsmat",
	"actors/characters/chozowarriorx/fx/imats/mudbeam02fx_mudbeam02fx.bsmat",
	"actors/characters/chozowarriorx/fx/imats/spike_start_energy.bsmat",
	"actors/characters/takumaku/fx/imats/chargemesh_mp_fxmeshmtl00_chargedash.bsmat",
	"actors/characters/takumaku/fx/imats/chargemesh_mp_fxmeshmtl00_border.bsmat",
	"actors/characters/chozowarrior/fx/imats/lightningshield_lghtngmat.bsmat",
	"actors/characters/chozowarrior/fx/imats/lightningchozo_lghtngmat.bsmat",
	"actors/characters/chozowarrior/fx/imats/wallattack_trail_01.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_start_new_front_right_trailsinitfront_right.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_end_new_front_right_trailendnewfront_right.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_start_new_back_right_trailstartback_right.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_end_new_back_right_trailendnewback_right.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_start_new_front_trail_start_attack_back.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_start_new_back_trail_start_attack_back.bsmat",
	"actors/characters/chozowarriorx/fx/imats/preptrail02_grab_back_frontrailprep02_grab.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_end_new_front_newtrail_end_front.bsmat",
	"actors/characters/chozowarriorx/fx/imats/trailflip_front_right_trailflip_front.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_end_new_back_newtrail_end_back.bsmat",
	"actors/characters/chozowarriorx/fx/imats/trailflip_back_right_trailflip_back.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_attack_end_01_trail_attack_end_01.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_attack_end_02_trail_attack_end_02.bsmat",
	"actors/characters/chozowarriorx/fx/imats/preptrail02_grab_trailprep02_grab.bsmat",
	"actors/characters/chozowarriorx/fx/imats/2impact_trail_2impact_grab_trail.bsmat",
	"actors/characters/chozowarriorx/fx/imats/backtrail_prep01_backtrail_prep01.bsmat",
	"actors/characters/chozowarriorx/fx/imats/fronttrail_prep01_preptrail_front01.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_attack_right_trail_attack_right.bsmat",
	"actors/characters/chozowarriorx/fx/imats/trailflip_front_trailflip_front.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_attack_02_trail_attack_right.bsmat",
	"actors/characters/chozowarriorx/fx/imats/trailflip_back_trailflip_back.bsmat",
	"actors/characters/chozowarriorx/fx/imats/trailspike_left_trailspike_left.bsmat",
	"actors/characters/chozowarrior/fx/imats/vertical_trail_vertcal_trail.bsmat",
	"actors/characters/chozowarrior/fx/imats/trail_verticalatk.bsmat",
	"actors/characters/chozowarrior/fx/imats/chozotrail_trail.bsmat",
	"actors/characters/chozowarrior/fx/damageshield.bsmat",
	"actors/characters/chozozombiex/models/imats/chozozombiex_body.bsmat",
	"actors/characters/sunnap/models/imats/sunnap_material.bsmat",
	"actors/characters/hecathon/models/imats/hecathon_mp_opaque_01.bsmat",
	"actors/characters/chozozombiex/fx/imats/runattackmud01_material.bsmat",
	"actors/characters/chozozombiex/fx/imats/attackmud01_material.bsmat",
	"actors/characters/chozozombiex/fx/imats/turnmud01_material.bsmat",
	"actors/characters/chozozombiex/fx/imats/walkmud01_material.bsmat",
	"actors/characters/obsydomithon/models/imats/obsydomithon_mp_opaque_01.bsmat",
	"actors/characters/iceflea/fx/imats/iceback_material.bsmat",
	"actors/characters/iceflea/fx/imats/ice_material.bsmat",
	"actors/characters/caterzilla/models/imats/caterzilla_caterzilla.bsmat",
	"actors/characters/iceflea/fx/imats/mist_explosion.bsmat",
	"actors/characters/chozozombiex/models/imats/chozozombiex_armor.bsmat",
	"actors/characters/nailugger/models/imats/nailugger_material.bsmat",
	"actors/characters/spitclawk/models/imats/spitclawk_body.bsmat",
	"actors/characters/infester/models/imats/infester_infester.bsmat",
	"actors/characters/iceflea/fx/imats/ice_break_break.bsmat",
	"actors/characters/bigkranx/models/imats/bigkranx_body.bsmat",
	"actors/characters/rodomithonx/models/imats/rodomithonx_mp_opaque_01.bsmat",
	"actors/characters/warlotus/models/imats/warlotus_ice.bsmat",
	"actors/characters/klaida/models/imats/klaida_klaida.bsmat",
	"actors/characters/autclast/fx/imats/death_hammer.bsmat",
	"actors/characters/goliath/models/imats/goliath_mp_opaque_01.bsmat",
	"actors/characters/goliath/models/imats/goliath_mp_opaque_02.bsmat",
	"actors/characters/poisonfly/models/imats/poisonfly_mp_opaque_01.bsmat",
	"actors/characters/rockdiver/models/imats/rockdiver_mp_opaque_01.bsmat",
	"actors/characters/iceflea/models/imats/iceflea_mp_opaque_01.bsmat",
	"actors/characters/kreep/models/imats/kreep_material.bsmat",
	"actors/characters/takumaku/models/imats/takumaku_mp_opaque_01.bsmat",
	"actors/characters/dropter/models/imats/dropter_mp_opaque_01.bsmat",
	"actors/characters/warlotus/models/imats/warlotus_body.bsmat",
	"actors/characters/gobbler/models/imats/gobbler_test_body.bsmat",
	"actors/characters/autool/models/imats/autool_mp_opaque_01.bsmat",
	"actors/characters/chozozombiex/fx/imats/gridmud01_gridmud.bsmat",
	"actors/props/ice_cube/models/imats/ice_cube_material.bsmat",
	"actors/weapons/infesterball/models/imats/infesterball_ball.bsmat",
	"actors/characters/autclast/models/imats/autclast_hammer.bsmat",
	"actors/characters/autclast/models/imats/autclast_main.bsmat",
	"actors/characters/dizzeansprite/models/imats/dizzeansprite.bsmat",
	"actors/characters/obsydomithon/fx/imats/obsydomithon_mp_rocksgravitational.bsmat",
	"actors/characters/obsydomithon/fx/imats/obsydomithon_mp_dustgravitational.bsmat",
	"actors/characters/slugger/fx/imats/sluggerball_acid_tail.bsmat",
	"actors/weapons/vulkranmagmaball/fx/imats/magmaball_magma_tail.bsmat",
	"actors/characters/slugger/fx/imats/sluggerball_acid.bsmat",
	"actors/characters/slugger/fx/imats/sluggerball_ball.bsmat",
	"actors/weapons/vulkranmagmaball/fx/imats/magmaball_magma.bsmat",
	"actors/characters/spittail/fx/imats/shockwave00_material.bsmat",
	"actors/characters/obsydomithon/fx/imats/obsydomithon_mp_gasleak.bsmat",
	"actors/weapons/nailongthorn/models/imats/nailongthorn_onlaunch_trail_smoke.bsmat",
	"actors/characters/nailugger/fx/imats/trails_smoke_trailsmoke.bsmat",
	"actors/characters/rinka/fx/imats/rinka_mp_rinkasphere.bsmat",
	"actors/characters/rinka/fx/imats/rinka_mp_rinkatrail.bsmat",
	"actors/characters/sabotoru/fx/imats/bubbles_mpbubblesmat.bsmat",
	"actors/characters/poisonfly/fx/imats/poisonflyconemesh_energy.bsmat",
	"actors/characters/autclast/fx/imats/rays_mp_lightningmtl00_rays02.bsmat",
	"actors/characters/autclast/fx/imats/rays_mp_lightningmtl00_rays03.bsmat",
	"actors/characters/autclast/fx/imats/rays_mp_lightningmtl00_rays04.bsmat",
	"actors/characters/autclast/fx/imats/rays_mp_lightningmtl00_rays.bsmat",
	"actors/characters/goliath/fx/imats/displacement_nonmelee_displacement_nonmelee.bsmat",
	"actors/characters/goliath/fx/imats/nonmeleerays_nonmeleerays.bsmat",
	"actors/characters/rodomithonx/fx/imats/rodomithonx_mp_fireoverwall.bsmat",
	"actors/characters/bigfist/fx/imats/trail4m_mp_fxtrail.bsmat",
	"actors/characters/bigfist/fx/imats/trail5m_mp_fxtrail.bsmat",
	"actors/characters/bigfist/fx/imats/trail6m_mp_fxtrail.bsmat",
	"actors/characters/goliath/fx/imats/trail_mp_fxtrail.bsmat",
	"actors/characters/hecathon/fx/imats/cone_material.bsmat",
	"actors/characters/obsydomithon/fx/imats/obsydomithon_mp_fireoverwall.bsmat",
	"actors/characters/goliath/fx/imats/surfaceanimfresnel.bsmat",
	"actors/characters/rinka/models/imats/rinka_mp_rinkasolid.bsmat",
	"actors/characters/autool/fx/imats/autooldamagefx_autooldamagefx.bsmat",
	"actors/characters/autclast/fx/imats/autclastdamage_autclast.bsmat",
	"actors/characters/superquetzoa/fx/imats/rayshieldglow_superquetzoa.bsmat",
	"actors/characters/iceflea/fx/imats/explosion_fresnel.bsmat",
	"actors/characters/emmy/fx/imats/speedbooster_cover_energy.bsmat",
	"actors/characters/emmy/fx/imats/speedbooster_cover_air.bsmat",
	"actors/characters/emmyforest/fx/imats/energy_absortion_energyemmy_forest.bsmat",
	"actors/characters/emmymagma/fx/imats/energy_absortion_energyemmy_magma.bsmat",
	"actors/characters/emmysanc/fx/imats/energy_absortion_energyemmy_sanc.bsmat",
	"actors/characters/emmylab/fx/imats/energy_absortion_energyemmy_lab.bsmat",
	"actors/characters/emmycave/fx/imats/energy_absortion_energyemmy.bsmat",
	"actors/weapons/emmywave/fx/imats/waves_energyfuxia.bsmat",
	"actors/weapons/emmywave/fx/imats/waveswall_energyred.bsmat",
	"actors/weapons/emmywave/fx/imats/waves_whitewaves.bsmat",
	"actors/weapons/emmywave/fx/imats/waveswall_whitewaves.bsmat",
	"actors/weapons/emmywave/fx/imats/waves_energy.bsmat",
	"actors/weapons/emmywave/fx/imats/waveswall_energy.bsmat",
	"actors/characters/emmy/models/imats/pulse_material.bsmat",
	"actors/characters/emmy/fx/imats/conepatrolsearch_material.bsmat",
	"actors/characters/emmy/fx/imats/coneice_material.bsmat",
	"actors/characters/emmy/fx/imats/dissolve_cubes_emmy_material.bsmat",
	"actors/characters/emmy/fx/imats/emmyglass_protoglass.bsmat",
	"actors/characters/emmy/models/imats/pulse_bg_material.bsmat",
	"actors/characters/emmy/fx/imats/dissolvedeath_internal_emmy.bsmat",
	"actors/characters/emmy/fx/imats/dissolvedeath_emmy.bsmat",
	"actors/characters/emmycave/fx/imats/animfresnel_armor.bsmat",
	"actors/characters/emmy/fx/imats/protectorfresnel_protfresnel.bsmat",
	"actors/characters/emmy/fx/imats/eyefresnel_eyetint.bsmat",
	"actors/weapons/emmywave/fx/imats/waves_waves.bsmat",
	"actors/weapons/emmywave/fx/imats/waveswall_waves.bsmat",
	"actors/characters/cucannon/models/imats/cucannon_mat01.bsmat",
	"actors/characters/cucannon/fx/imats/charge_energy_energy.bsmat",
	"actors/weapons/cucannonbeam/fx/imats/cucannonbeam_projectile_front.bsmat",
	"actors/weapons/cucannonbeam/fx/imats/cucannonbeam_projectile_tail.bsmat",
	"actors/characters/cucannon/models/imats/cucannon_mat02.bsmat",
	"actors/weapons/scorpiuspoisonousspit/models/imats/scorpiuspoisonousspit_material.bsmat",
	"actors/characters/scorpius/fx/imats/wallhit_impactshaft_wallhit_impactflash_interior.bsmat",
	"actors/characters/scorpius/fx/imats/wallhit_impactshaft_wallhit_impactshaft.bsmat",
	"actors/characters/scorpius/fx/imats/wallhit_fastflash_wallhit_fastflash.bsmat",
	"actors/characters/scorpius/fx/imats/wall_energy_wallhit_energy.bsmat",
	"actors/characters/scorpius/fx/imats/gas_mouth_poisonousgas_mouth_mask.bsmat",
	"actors/characters/scorpius/fx/imats/wallhit_mesh_dashshot_wallhit_mesh.bsmat",
	"actors/characters/scorpius/fx/imats/wallhit_decal_wallhit_decal.bsmat",
	"actors/weapons/scorpiuspoisonousspit/fx/imats/tailballspit_tailballspit.bsmat",
	"actors/characters/emmymagma/models/imats/emmymagma_white_body.bsmat",
	"actors/characters/emmymagma/models/imats/emmymagma_black.bsmat",
	"actors/characters/emmymagma/models/imats/emmymagma_white_head.bsmat",
	"maps/genericimats/lava_kraid_death.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_l01_arm.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_l02_arm.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_r01_arm.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_r02_arm.bsmat",
	"actors/spawnpoints/spawnpointcaterzilla/models/imats/spawnpointcaterzillawall_material.bsmat",
	"maps/fx/steamdevices/imats/steamdevices_column02_red_material01.bsmat",
	"actors/props/mblauncher_launcher_gen_001/models/imats/mblauncher_launcher_gen_001_mat01.bsmat",
	"maps/fx/dustdebris/fx/imats/dustdebris00_fast_material.bsmat",
	"maps/fx/dustdebris/fx/imats/dustdebris00_material.bsmat",
	"maps/fx/lavaplanes/imats/lavaplanes00_material.bsmat",
	"actors/props/mblauncher_exit_gen_001/models/imats/mblauncher_exit_gen_001_mat01.bsmat",
	"actors/props/mblauncher_exit_kraid/models/imats/mblauncher_exit_kraid_mat01.bsmat",
	"actors/props/weightactivatedplatform_train/models/imats/platform_wagontrailplatfom_material01.bsmat",
	"actors/props/weightactivatedplatform_train/models/imats/platform_wagontrailplatfom_material02.bsmat",
	"actors/characters/emmymagma/models/imats/emmymagma_black_eye.bsmat",
	"cutscenes/0078cooldownpresentation/fx/imats/samus_splashenter_material.bsmat",
	"actors/props/shootactivatoroff/models/imats/shootactivatoroff_mat01.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_body.bsmat",
	"actors/props/emmyvalve_reg_gen_001/models/imats/emmyvalve_reg_gen_001_material01.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_head.bsmat",
	"actors/props/fusiblebox_broken/models/imats/fusiblebox_broken_.bsmat",
	"actors/props/shootactivatoroff/models/imats/shootactivatoroff_mat02.bsmat",
	"actors/props/wagontrain/models/imats/wagontrain_material02.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_arms.bsmat",
	"actors/events/mapev_magma_crab/models/imats/mapev_magma_crab_mp_opaque_01.bsmat",
	"actors/props/pistonmag01/models/imats/pistonmag01_mat02.bsmat",
	"actors/characters/emmymagma/models/imats/emmymagma_eye_decal.bsmat",
	"actors/props/pistonmag01/models/imats/pistonmag01_mat01.bsmat",
	"actors/props/fusiblebox/models/imats/fusiblebox_fusible.bsmat",
	"maps/genericimats/lavawaterfall02_generic.bsmat",
	"actors/characters/kraid/models/imats/kraid_eyes.bsmat",
	"cutscenes/0061kraiddeath/fx/imats/lava_explosion00_anim_material.bsmat",
	"cutscenes/0061kraiddeath/fx/imats/lava_explosion01_anim_material.bsmat",
	"cutscenes/0061kraiddeath/fx/imats/lava_explosion02_anim_material.bsmat",
	"maps/fx/lavasplashes/imats/lava_explosion02_anim_material.bsmat",
	"maps/objects/chozostationwagonbgmagma/imats/chozostationwagonbgmagma_mp_opaque_24.bsmat",
	"maps/objects/chozostationwagonbgmagma/imats/chozostationwagonbgmagma_mp_opaque_25.bsmat",
	"maps/genericimats/chozomatcircuits04_generic.bsmat",
	"actors/items/powerup_diffusionbeam/models/imats/powerup_diffusionbeam_autoilum.bsmat",
	"actors/props/fan_cooldown/models/imats/fan_cooldown_mat01.bsmat",
	"actors/props/kraidspike_cntk/models/imats/kraidspike_cntk_barriga.bsmat",
	"actors/props/ev_kraid_spike/models/imats/ev_kraid_spike_barriga.bsmat",
	"maps/fx/lavadrops/imats/lava_drops05_anim_material.bsmat",
	"maps/fx/lavadrops/imats/lava_drops06_anim_material.bsmat",
	"maps/fx/lavadrops/imats/lava_drops07_anim_material.bsmat",
	"actors/props/db_reg_mg_019/models/imats/db_reg_mg_019_mp_opaquemaps_simple_02.bsmat",
	"actors/props/db_reg_mg_020/models/imats/db_reg_mg_020_mp_opaquemaps_simple_04.bsmat",
	"actors/props/db_reg_mg_019/models/imats/db_reg_mg_019_cascamat02.bsmat",
	"maps/genericimats/chozodecal04_generic.bsmat",
	"maps/objects/magkraidheadcorridor01/imats/magkraidheadcorridor01_mp_opaque_01.bsmat",
	"maps/objects/magkraidheadcorridor02/imats/magkraidheadcorridor02_mp_opaque_01.bsmat",
	"maps/objects/magmeltrockplatform01/imats/magmeltrockplatform01_mp_opaque_01.bsmat",
	"actors/characters/core_x/models/imats/core_x_mat03.bsmat",
	"maps/objects/magdigrockplatform01/imats/magdigrockplatform01_mp_opaque_01.bsmat",
	"maps/objects/magfrontpatch01/imats/magfrontpatch01_mp_opaque_01.bsmat",
	"maps/objects/magfrontpatch02/imats/magfrontpatch02_mp_opaque_01.bsmat",
	"maps/fx/chozonumbers/fx/imats/hologramletters_hologram_number_yellow_seven.bsmat",
	"maps/objects/chozomagassetn_05/imats/chozomagassetn_05_mp_opaque_01.bsmat",
	"maps/fx/chozonumbers/fx/imats/hologramletters_hologram_number_yellow_five.bsmat",
	"maps/fx/chozonumbers/fx/imats/hologramletters_hologram_number_red_seven.bsmat",
	"maps/objects/magdigrockwall01/imats/magdigrockwall01_mp_opaque_01.bsmat",
	"maps/objects/magdigrockwall02/imats/magdigrockwall02_mp_opaque_01.bsmat",
	"maps/objects/magdigrockwall03/imats/magdigrockwall03_mp_opaque_01.bsmat",
	"maps/fx/chozonumbers/fx/imats/hologramletters_hologram_number_red_five.bsmat",
	"maps/objects/gravitysuit_chozo/imats/gravitysuit_chozo_body.bsmat",
	"maps/objects/chozoallmecharm01_a/imats/chozoallmecharm01_a_mp_opaque_01.bsmat",
	"maps/objects/chozoallmecharm01_b/imats/chozoallmecharm01_b_mp_opaque_01.bsmat",
	"maps/objects/magdigrockbg01/imats/magdigrockbg01_mp_opaque_01.bsmat",
	"maps/objects/magvulkraneggs01/imats/magvulkraneggs01_mp_opaque_01.bsmat",
	"maps/objects/magdigrock03/imats/magdigrock03_mp_opaque_01.bsmat",
	"maps/objects/magvulkraneggs/imats/magvulkraneggs_mp_opaque_01.bsmat",
	"actors/props/shootactivatormag01/models/imats/shootactivatormag01_mat01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables09sg_casca111_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables10sg_casca104_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables11sg_casca110_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables12sg_casca105_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables13sg_casca109_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables14sg_casca106_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables16sg_casca125_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables17sg_casca128_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables18sg_casca127_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables19sg_casca129_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables20sg_casca126_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables21sg_casca130_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables22sg_casca124_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables23sg_casca131_mp_opaque_107.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca13_mp_opaquemaps_03.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca14_mp_opaquemaps_03.bsmat",
	"actors/characters/core_x/models/imats/core_x_mat01.bsmat",
	"maps/objects/chozomagassetrobotr01a/imats/chozomagassetrobotr01a_material.bsmat",
	"maps/objects/chozomagassetrobotr02a/imats/chozomagassetrobotr02a_material.bsmat",
	"maps/objects/chozobgmagwall06joint/imats/chozobgmagwall06joint_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqbggate01/imats/chozoaqbggate01_mp_opaque_01.bsmat",
	"maps/objects/chozoallbggen02x1/imats/chozoallbggen02x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallbggen02x4/imats/chozoallbggen02x4_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel05_mp_opaquemaps_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part027_n2_mapmodel04_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part027_n2_mapmodel05_mp_opaquemaps_simple.bsmat",
	"cutscenes/0061kraiddeath/fx/imats/impact_decal_claws.bsmat",
	"actors/characters/kraid/models/imats/kraid_barriga.bsmat",
	"cutscenes/0061kraiddeath/fx/imats/kraid_decal_claws.bsmat",
	"actors/characters/kraid/models/imats/kraid_cabeza.bsmat",
	"actors/characters/kraid/models/imats/kraid_cuerpo.bsmat",
	"maps/fx/ashparticles/imats/ashparticles00_material.bsmat",
	"maps/fx/ashparticles/imats/ashparticles01_material.bsmat",
	"maps/genericimats/lavamat03_generic.bsmat",
	"maps/genericimats/lavamat04_generic.bsmat",
	"maps/objects/chozostationwagon01low/imats/chozostationwagon01low_mp_opaquemaps_simple_nonm_01.bsmat",
	"maps/objects/chozostationwagon01low/imats/chozostationwagon01low_mp_opaquemaps_simple_nonm_02.bsmat",
	"actors/props/breakablemag001/models/imats/breakablemag001_mp_opaquemaps_simple_dissolve_10.bsmat",
	"actors/props/breakablemag001/models/imats/breakablemag001_mp_opaquemaps_simple_dissolve_12.bsmat",
	"actors/props/breakablemag001/models/imats/breakablemag001_mp_opaquemaps_simple_dissolve_13.bsmat",
	"actors/props/db_dside_mg_001b/models/imats/db_dside_mg_001b_mp_opaquemaps_simple_17.bsmat",
	"actors/props/db_dside_mg_002b/models/imats/db_dside_mg_002b_mp_opaquemaps_simple_17.bsmat",
	"actors/props/db_dside_mg_003b/models/imats/db_dside_mg_003b_mp_opaquemaps_simple_17.bsmat",
	"actors/props/db_hdoor_mg_002b/models/imats/db_hdoor_mg_002b_mp_opaquemaps_simple_17.bsmat",
	"actors/props/breakablemag010/models/imats/breakablemag010_mp_opaquemaps_simple_17.bsmat",
	"actors/props/breakablemag012/models/imats/breakablemag012_mp_opaquemaps_simple_17.bsmat",
	"actors/props/db_hdoor_mg_002/models/imats/db_hdoor_mg_002_mp_opaquemaps_simple_17.bsmat",
	"actors/props/breakablemag007/models/imats/breakablemag007_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/breakablemag008/models/imats/breakablemag008_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/breakablemag013/models/imats/breakablemag013_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/breakablemag013/models/imats/breakablemag013_mp_opaquemaps_simple_dissolve_04.bsmat",
	"actors/props/db_dif_mg_002/models/imats/db_dif_mg_002_mp_opaquemaps_simple_dissolve_57.bsmat",
	"actors/props/db_dif_mg_001/models/imats/db_dif_mg_001_mp_opaquemaps_simple_17.bsmat",
	"actors/props/db_reg_mg_018/models/imats/db_reg_mg_018_mp_opaquemaps_simple_17.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/plasmabeam_chargedfull_mp_fxmeshmtl00_border.bsmat",
	"actors/props/cut_cooldownboss_machine/models/imats/cut_cooldownboss_machine_slime.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/plasmabeam_chargedfull_mp_fxmeshmtl00_inner.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/plasmabeam_chargedfull_projectile_particles.bsmat",
	"actors/props/breakablemag002/models/imats/breakablemag002_mp_opaquemaps_simple_2.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/plasmabeam_chargedfull_mp_fxmeshmtl00_fire.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/plasmabeam_chargedfull_mp_fxmeshmtl00_tail.bsmat",
	"actors/props/db_hdoor_mg_001/models/imats/db_hdoor_mg_001_mp_opaquemaps_simple_21.bsmat",
	"actors/props/breakablemag001/models/imats/breakablemag001_mp_opaquemaps_simple_dissolve_04.bsmat",
	"actors/props/db_reg_mg_016/models/imats/db_reg_mg_016_mp_opaquemaps_simple_16.bsmat",
	"actors/props/breakablemag002/models/imats/breakablemag002_mp_opaquemaps_simple_01.bsmat",
	"maps/genericimats/thermalstate02_generic.bsmat",
	"maps/genericimats/thermalstate03_generic.bsmat",
	"maps/genericimats/thermalstate04_generic.bsmat",
	"maps/genericimats/thermalstate05_generic.bsmat",
	"maps/genericimats/thermalstate06_generic.bsmat",
	"maps/genericimats/thermalstate07_generic.bsmat",
	"actors/props/breakablemag009/models/imats/breakablemag009_mp_opaquemaps_simple_21.bsmat",
	"actors/props/breakablemag012/models/imats/breakablemag012_mp_opaquemaps_simple_20.bsmat",
	"actors/props/db_hdoor_mg_001/models/imats/db_hdoor_mg_001_mp_opaquemaps_simple_22.bsmat",
	"actors/props/db_dside_mg_001b/models/imats/db_dside_mg_001b_mp_opaquemaps_simple_16.bsmat",
	"actors/props/db_dside_mg_002b/models/imats/db_dside_mg_002b_mp_opaquemaps_simple_16.bsmat",
	"actors/props/db_dside_mg_003b/models/imats/db_dside_mg_003b_mp_opaquemaps_simple_16.bsmat",
	"actors/props/db_hdoor_mg_002b/models/imats/db_hdoor_mg_002b_mp_opaquemaps_simple_16.bsmat",
	"actors/props/breakablemag004/models/imats/breakablemag004_mp_opaquemaps_simple_16.bsmat",
	"actors/props/breakablemag009/models/imats/breakablemag009_mp_opaquemaps_simple_16.bsmat",
	"actors/props/breakablemag010/models/imats/breakablemag010_mp_opaquemaps_simple_16.bsmat",
	"actors/props/breakablemag012/models/imats/breakablemag012_mp_opaquemaps_simple_15.bsmat",
	"actors/props/breakablemag012/models/imats/breakablemag012_mp_opaquemaps_simple_16.bsmat",
	"actors/props/breakablemag014/models/imats/breakablemag014_mp_opaquemaps_simple_16.bsmat",
	"actors/props/db_dif_mg_001/models/imats/db_dif_mg_001_mp_opaquemaps_simple_20.bsmat",
	"actors/props/db_dside_mg_002/models/imats/db_dside_mg_002_mp_opaquemaps_simple_16.bsmat",
	"actors/props/db_hdoor_mg_001/models/imats/db_hdoor_mg_001_mp_opaquemaps_simple_15.bsmat",
	"actors/props/db_hdoor_mg_001/models/imats/db_hdoor_mg_001_mp_opaquemaps_simple_16.bsmat",
	"actors/props/db_hdoor_mg_002/models/imats/db_hdoor_mg_002_mp_opaquemaps_simple_16.bsmat",
	"actors/props/breakablemag003/models/imats/breakablemag003_mp_opaquemaps_simple_100.bsmat",
	"actors/props/breakablemag005/models/imats/breakablemag005_mp_opaquemaps_simple_100.bsmat",
	"actors/props/breakablemag005/models/imats/breakablemag005_mp_opaquemaps_simple_99.bsmat",
	"actors/props/db_dif_mg_001/models/imats/db_dif_mg_001_mp_opaquemaps_simple_16.bsmat",
	"actors/props/db_reg_mg_018/models/imats/db_reg_mg_018_mp_opaquemaps_simple_15.bsmat",
	"actors/props/db_reg_mg_018/models/imats/db_reg_mg_018_mp_opaquemaps_simple_16.bsmat",
	"actors/props/db_reg_mg_020/models/imats/db_reg_mg_020_mp_opaquemaps_simple_05.bsmat",
	"actors/props/breakablemag002/models/imats/breakablemag002_mp_opaquemaps_simple_1.bsmat",
	"actors/props/cut_cooldownboss_machine/models/imats/cut_cooldownboss_machine_slimenolight.bsmat",
	"actors/props/db_dside_mg_001b/models/imats/db_dside_mg_001b_mp_opaquemaps_simple_18.bsmat",
	"actors/props/db_hdoor_mg_002b/models/imats/db_hdoor_mg_002b_mp_opaquemaps_simple_18.bsmat",
	"actors/props/breakablemag004/models/imats/breakablemag004_mp_opaquemaps_simple_18.bsmat",
	"actors/props/breakablemag009/models/imats/breakablemag009_mp_opaquemaps_simple_18.bsmat",
	"actors/props/breakablemag010/models/imats/breakablemag010_mp_opaquemaps_simple_18.bsmat",
	"actors/props/breakablemag012/models/imats/breakablemag012_mp_opaquemaps_simple_18.bsmat",
	"actors/props/breakablemag014/models/imats/breakablemag014_mp_opaquemaps_simple_18.bsmat",
	"actors/props/db_dside_mg_002/models/imats/db_dside_mg_002_mp_opaquemaps_simple_18.bsmat",
	"actors/props/db_hdoor_mg_001/models/imats/db_hdoor_mg_001_mp_opaquemaps_simple_18.bsmat",
	"actors/props/db_hdoor_mg_002/models/imats/db_hdoor_mg_002_mp_opaquemaps_simple_18.bsmat",
	"actors/props/breakablemag001/models/imats/breakablemag001_cascamat01.bsmat",
	"actors/props/db_dif_mg_001/models/imats/db_dif_mg_001_mp_opaquemaps_simple_18.bsmat",
	"actors/props/db_reg_mg_018/models/imats/db_reg_mg_018_mp_opaquemaps_simple_18.bsmat",
	"actors/props/db_reg_mg_020/models/imats/db_reg_mg_020_mp_opaquemaps_simple_01.bsmat",
	"actors/props/breakablemag007/models/imats/breakablemag007_cascamat01.bsmat",
	"actors/props/breakablemag007/models/imats/breakablemag007_cascamat02.bsmat",
	"actors/props/breakablemag008/models/imats/breakablemag008_cascamat01.bsmat",
	"actors/props/breakablemag008/models/imats/breakablemag008_cascamat02.bsmat",
	"actors/props/db_dside_mg_001b/models/imats/db_dside_mg_001b_mp_opaquemaps_simple_14.bsmat",
	"actors/props/db_dside_mg_002b/models/imats/db_dside_mg_002b_mp_opaquemaps_simple_14.bsmat",
	"actors/props/db_dside_mg_002b/models/imats/db_dside_mg_002b_mp_opaquemaps_simple_19.bsmat",
	"actors/props/db_dside_mg_003b/models/imats/db_dside_mg_003b_mp_opaquemaps_simple_14.bsmat",
	"actors/props/db_dside_mg_003b/models/imats/db_dside_mg_003b_mp_opaquemaps_simple_19.bsmat",
	"actors/props/db_dside_mg_001/models/imats/db_dside_mg_001_mp_opaquemaps_simple_14.bsmat",
	"actors/props/db_dside_mg_001/models/imats/db_dside_mg_001_mp_opaquemaps_simple_19.bsmat",
	"actors/props/db_dside_mg_002/models/imats/db_dside_mg_002_mp_opaquemaps_simple_14.bsmat",
	"actors/props/db_dside_mg_002/models/imats/db_dside_mg_002_mp_opaquemaps_simple_19.bsmat",
	"actors/props/db_dside_mg_003/models/imats/db_dside_mg_003_mp_opaquemaps_simple_14.bsmat",
	"actors/props/db_dside_mg_003/models/imats/db_dside_mg_003_mp_opaquemaps_simple_16.bsmat",
	"actors/props/db_dside_mg_003/models/imats/db_dside_mg_003_mp_opaquemaps_simple_18.bsmat",
	"actors/props/db_dside_mg_003/models/imats/db_dside_mg_003_mp_opaquemaps_simple_19.bsmat",
	"actors/props/db_reg_mg_019/models/imats/db_reg_mg_019_mp_opaquemaps_simple_01.bsmat",
	"actors/props/db_reg_mg_020/models/imats/db_reg_mg_020_mp_opaquemaps_simple_02.bsmat",
	"actors/props/db_reg_mg_020/models/imats/db_reg_mg_020_mp_opaquemaps_simple_03.bsmat",
	"actors/props/fan_cooldown/models/imats/fan_cooldown_mud_02_mud02.bsmat",
	"actors/props/fan_cooldown/models/imats/fan_cooldown_mud_fanmud01.bsmat",
	"actors/props/breakablemag013/models/imats/breakablemag013_cascamat.bsmat",
	"actors/props/db_reg_mg_016/models/imats/db_reg_mg_016_cascamat.bsmat",
	"actors/props/db_reg_mg_016/models/imats/db_reg_mg_016_mp_opaquemaps_simple_14.bsmat",
	"actors/props/db_reg_mg_016/models/imats/db_reg_mg_016_mp_opaquemaps_simple_15.bsmat",
	"actors/props/breakablemag009/models/imats/breakablemag009_cascamat.bsmat",
	"actors/props/breakablemag012/models/imats/breakablemag012_cascamat.bsmat",
	"actors/props/db_dside_mg_001b/models/imats/db_dside_mg_001b_cascamat.bsmat",
	"actors/props/db_hdoor_mg_002b/models/imats/db_hdoor_mg_002b_cascamat.bsmat",
	"actors/props/breakablemag010/models/imats/breakablemag010_cascamat.bsmat",
	"actors/props/db_dif_mg_001/models/imats/db_dif_mg_001_cascamat01.bsmat",
	"actors/props/db_dside_mg_002/models/imats/db_dside_mg_002_cascamat.bsmat",
	"actors/props/db_dside_mg_003/models/imats/db_dside_mg_003_cascamat.bsmat",
	"actors/props/db_hdoor_mg_001/models/imats/db_hdoor_mg_001_cascamat.bsmat",
	"actors/props/breakablemag005/models/imats/breakablemag005_cascamat.bsmat",
	"actors/props/breakablemag004/models/imats/breakablemag004_cascamat.bsmat",
	"actors/props/breakablemag014/models/imats/breakablemag014_cascamat.bsmat",
	"actors/props/db_hdoor_mg_002/models/imats/db_hdoor_mg_002_cascamat.bsmat",
	"actors/props/db_dside_mg_003b/models/imats/db_dside_mg_003b_cascamat01.bsmat",
	"actors/props/db_reg_mg_018/models/imats/db_reg_mg_018_cascamat.bsmat",
	"actors/props/db_reg_mg_019/models/imats/db_reg_mg_019_cascamat01.bsmat",
	"actors/props/db_reg_mg_020/models/imats/db_reg_mg_020_cascamat.bsmat",
	"actors/props/db_dside_mg_002b/models/imats/db_dside_mg_002b_cascamat.bsmat",
	"actors/props/db_dside_mg_001/models/imats/db_dside_mg_001_cascamat.bsmat",
	"actors/props/breakablemag007/models/imats/breakablemag007_mp_opaquemaps_simple_dissolve_02.bsmat",
	"actors/props/breakablemag008/models/imats/breakablemag008_mp_opaquemaps_simple_dissolve_02.bsmat",
	"actors/props/db_dif_mg_002/models/imats/db_dif_mg_002_mp_opaquemaps_simple_dissolve_82.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/magmabasecylinder_magmabasecylinder.bsmat",
	"actors/items/powerup_diffusionbeam/models/imats/powerup_diffusionbeam_mp_opaque_01.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/magmabasecylinder_magmainharder.bsmat",
	"actors/props/fusiblebox/models/imats/fusiblebox_mud.bsmat",
	"actors/props/fan_reg/fx/imats/hurricane_hurricanecenter.bsmat",
	"actors/props/fan_reg/fx/imats/wind_cutscene_wind.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/magma_center_magma_center.bsmat",
	"maps/objects/chozomagassetduct02/imats/chozomagassetduct02_mp_opaquemaps_simple.bsmat",
	"actors/props/weightactivatedplatform_train/fx/imats/shaft_train_shaft_glow.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/magmabasecylinder_inner.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/magmalaserfakeglow_fakeglowlaser.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_breakablessg_casca72000_mp_opaquemaps_simple_25.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_breakablessg_casca72001_mp_opaquemaps_simple_25.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_breakablessg_casca72002_mp_opaquemaps_simple_25.bsmat",
	"actors/props/weightactivatedplatform_train/fx/imats/shaft_train_material.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/firefusible_firefusible.bsmat",
	"actors/props/box_magnet_mg_003/models/imats/box_magnet_mg_003_material.bsmat",
	"actors/props/wagontrain/fx/imats/forcefield_forcefield.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables04sg_casca001sg_casca002sg_casca003_mp_opaquemaps_simple_34.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel15_mp_opaquemaps_simple_41.bsmat",
	"actors/props/fan_reg/fx/imats/wind_wind.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_mapmodel06_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_mapmodel06_mp_opaquemaps_simple_25.bsmat",
	"actors/props/box_magnet_mg_01/models/imats/box_magnet_mg_01_platform.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables02sg_casca005sg_casca006_mp_opaquemaps_simple_34.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca008sg_casca69002_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca009sg_casca69001_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca010sg_casca69000_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca011sg_casca69005_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca012sg_casca69003_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca013sg_casca69004_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca014sg_casca68002_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca015sg_casca68003_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca016sg_casca68000_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca017sg_casca68001_mp_opaquemaps_simple_001.bsmat",
	"actors/characters/kraid/models/imats/kraid_hardsurface.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables04sg_casca001sg_casca002sg_casca003_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca00_mp_opaquemaps_simple_036.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca01_mp_opaquemaps_simple_036.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca02_mp_opaquemaps_simple_036.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca03_mp_opaquemaps_simple_036.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables24sg_casca171_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables25sg_casca164_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables26sg_casca169_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables27sg_casca168_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables28sg_casca165_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables29sg_casca170_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables30sg_casca166_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables31sg_casca023_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables32sg_casca024_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables33sg_casca020_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables34sg_casca021_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables35sg_casca022_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables04sg_casca001sg_casca002sg_casca003_mp_opaquemaps_simple_33.bsmat",
	"actors/characters/core_x/models/imats/core_x_mat02.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables02sg_casca130sg_casca124_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables04sg_casca129sg_casca126_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables06sg_casca128sg_casca127_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables10sg_casca131sg_casca125_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables01sg_casca003_mp_opaquemaps_simple_34.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables03sg_casca004_mp_opaquemaps_simple_34.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables05sg_casca001_mp_opaquemaps_simple_34.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables06sg_casca005_mp_opaquemaps_simple_34.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca10_mp_opaquemaps_simple_102.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca11_mp_opaquemaps_simple_102.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables02sg_casca130sg_casca124_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables04sg_casca129sg_casca126_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables06sg_casca128sg_casca127_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables10sg_casca131sg_casca125_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables02sg_casca005sg_casca006_mp_opaquemaps_simple_32.bsmat",
	"maps/objects/magdigrockplatformlava01/imats/magdigrockplatformlava01_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_e3_breakables01sg_casca007_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables02sg_casca005sg_casca006_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca00_mp_opaquemaps_simple_035.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca01_mp_opaquemaps_simple_035.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca02_mp_opaquemaps_simple_035.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca03_mp_opaquemaps_simple_035.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca10_mp_opaquemaps_simple_001.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca11_mp_opaquemaps_simple_001.bsmat",
	"actors/props/wagontrain/models/imats/wagontrain_exterior.bsmat",
	"actors/props/wagontrain/models/imats/wagontrain_interior.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca50_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca51_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_x1_mapmodel03_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel17_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel20_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables01sg_casca175_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables07sg_casca174_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables09sg_casca173_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables11sg_casca176_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part25_x2_mapmodel14_mp_opaquemaps_simple_93.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca37_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca38_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca04_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca05_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca06_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca07_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca08_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca09_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_breakables00sg_casca12_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables00sg_casca131_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables01sg_casca175_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables03sg_casca130_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables05sg_casca129_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables07sg_casca174_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables08sg_casca128_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables09sg_casca173_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables11sg_casca176_mp_opaquemaps_simple_18.bsmat",
	"maps/objects/chozoalltunnelborder01x4a/imats/chozoalltunnelborder01x4a_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoalltunnelborder01x4b/imats/chozoalltunnelborder01x4b_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca36_mp_opaquemaps_simple_22.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca37_mp_opaquemaps_simple_22.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca38_mp_opaquemaps_simple_22.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca39_mp_opaquemaps_simple_22.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca40_mp_opaquemaps_simple_22.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca41_mp_opaquemaps_simple_22.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable16sg_casca18006_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable17sg_casca18007_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable18sg_casca18008_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable19sg_casca18009_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable20sg_casca18010_mp_opaquemaps_simple_23.bsmat",
	"maps/objects/chozoalltunnelborder01x1/imats/chozoalltunnelborder01x1_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable01sg_casca146_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable02sg_casca147_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable03sg_casca148_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable04sg_casca149_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable05sg_casca150_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_breakable06sg_casca145_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_x1_breakable_02_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_x1_breakable_03_mp_opaquemaps_simple_38.bsmat",
	"maps/objects/chozoemmybg01cornice2x4/imats/chozoemmybg01cornice2x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmybg01corniceint/imats/chozoemmybg01corniceint_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmytunnelbg01corner/imats/chozoemmytunnelbg01corner_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagmechanicarm01/imats/chozomagmechanicarm01_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables00sg_casca131_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables01sg_casca175_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables03sg_casca130_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables05sg_casca129_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables07sg_casca174_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables08sg_casca128_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables09sg_casca173_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_breakables11sg_casca176_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables09sg_casca111_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables10sg_casca104_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables11sg_casca110_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables12sg_casca105_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables13sg_casca109_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables14sg_casca106_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables16sg_casca125_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables17sg_casca128_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables18sg_casca127_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables19sg_casca129_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables20sg_casca126_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables21sg_casca130_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables22sg_casca124_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_breakables23sg_casca131_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables01sg_casca003_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables03sg_casca004_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables05sg_casca001_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables06sg_casca005_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca36_mp_opaquemaps_simple_21.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca37_mp_opaquemaps_simple_21.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca38_mp_opaquemaps_simple_21.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca39_mp_opaquemaps_simple_21.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca40_mp_opaquemaps_simple_21.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_breakables00sg_casca41_mp_opaquemaps_simple_21.bsmat",
	"maps/objects/chozoallbgemmy01dx4/imats/chozoallbgemmy01dx4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallbgemmy01dx4/imats/chozoallbgemmy01dx4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozopipesthermal02cornerinvert/imats/chozopipesthermal02cornerinvert_pipes.bsmat",
	"maps/objects/chozopipesthermal03cornerinvert/imats/chozopipesthermal03cornerinvert_pipes.bsmat",
	"maps/objects/chozopipesthermal04cornerinvert/imats/chozopipesthermal04cornerinvert_pipes.bsmat",
	"maps/objects/chozopipesthermal06cornerinvert/imats/chozopipesthermal06cornerinvert_pipes.bsmat",
	"maps/objects/chozopipesthermal07cornerinvert/imats/chozopipesthermal07cornerinvert_pipes.bsmat",
	"maps/objects/chozoaqatrezzorot01_a/imats/chozoaqatrezzorot01_a_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoemmytunnelbg01x1l/imats/chozoemmytunnelbg01x1l_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmytunnelbg01x1r/imats/chozoemmytunnelbg01x1r_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrockwalllava01/imats/magdigrockwalllava01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrockwalllava02/imats/magdigrockwalllava02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrockwalllava03/imats/magdigrockwalllava03_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_breakables01sg_casca003_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel17_mp_opaquemaps_simple_31.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part010_r7_mapmodel10_mp_opaquemaps_simple_52.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel16_mp_opaquemaps_simple_28.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_x1_breakable_06_mp_opaquemaps_simple_39.bsmat",
	"maps/objects/chozoalltunnelbg01_ta/imats/chozoalltunnelbg01_ta_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoalltunnelbg01_tb/imats/chozoalltunnelbg01_tb_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part001_r12_mapmodel12_mp_opaquemaps_simple_21.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_s3_mapmodel_04_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part25_x2_mapmodel07_mp_opaquemaps_simple_31.bsmat",
	"maps/objects/chozoemmytunnelbg01t/imats/chozoemmytunnelbg01t_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel14_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel14_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_mapmodel09_mp_opaquemaps_simple_04.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel23_mp_opaquemaps_simple_04.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_x1_mapmodel54_mp_opaquemaps_simple_39.bsmat",
	"maps/objects/chozoemmybg01tur2/imats/chozoemmybg01tur2_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoemmybg01tur2/imats/chozoemmybg01tur2_mp_opaquemaps_simple_03.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel13_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_mapmodel07_mp_opaquemaps_simple_23.bsmat",
	"maps/objects/chozopipesthermal02corner/imats/chozopipesthermal02corner_pipes.bsmat",
	"maps/objects/chozopipesthermal03corner/imats/chozopipesthermal03corner_pipes.bsmat",
	"maps/objects/chozopipesthermal04corner/imats/chozopipesthermal04corner_pipes.bsmat",
	"maps/objects/chozopipesthermal05corner/imats/chozopipesthermal05corner_pipes.bsmat",
	"maps/objects/chozopipesthermal07corner/imats/chozopipesthermal07corner_pipes.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_s3_mapmodel_04_mp_opaquemaps_simple_23.bsmat",
	"maps/objects/chozomagassetrobot01a/imats/chozomagassetrobot01a_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozomagassetrobot01b/imats/chozomagassetrobot01b_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozomagassetrobot02a/imats/chozomagassetrobot02a_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozomagassetrobot02b/imats/chozomagassetrobot02b_mp_opaquemaps_simple.bsmat",
	"maps/objects/magdigrockbglava01/imats/magdigrockbglava01_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_s3_mapmodel_03_mp_opaquemaps_simple_100.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel11_mp_opaquemaps_simple_15.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel11_mp_opaquemaps_simple_16.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel13_mp_opaquemaps_simple_22.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_x1_mapmodel02_mp_opaquemaps_simple_16.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_mapmodel06_mp_opaquemaps_simple_16.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel17_mp_opaquemaps_simple_16.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel18_mp_opaquemaps_simple_16.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel19_mp_opaquemaps_simple_16.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel20_mp_opaquemaps_simple_16.bsmat",
	"maps/objects/magnetglovesp01cornerout90/imats/magnetglovesp01cornerout90_mp_opaquemaps_simple.bsmat",
	"maps/objects/magrockborderlava01/imats/magrockborderlava01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magrockborderlava02/imats/magrockborderlava02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magrockborderlava03/imats/magrockborderlava03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magrockborderlava04/imats/magrockborderlava04_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part25_x2_mapmodel22_mp_opaquemaps_simple_92.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part010_r7_mapmodel11_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel03_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel10_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel10_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel11_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel11_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel12_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel12_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel13_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel13_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel14_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part020_r6_mapmodel14_mp_opaquemaps_simple_24.bsmat",
	"maps/objects/chozomagassetn_02/imats/chozomagassetn_02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopipesthermal02x1/imats/chozopipesthermal02x1_pipes.bsmat",
	"maps/objects/chozopipesthermal02x3/imats/chozopipesthermal02x3_pipes.bsmat",
	"maps/objects/chozopipesthermal03x1/imats/chozopipesthermal03x1_pipes.bsmat",
	"maps/objects/chozopipesthermal04x1/imats/chozopipesthermal04x1_pipes.bsmat",
	"maps/objects/chozopipesthermal04x3/imats/chozopipesthermal04x3_pipes.bsmat",
	"maps/objects/chozopipesthermal05x3/imats/chozopipesthermal05x3_pipes.bsmat",
	"maps/objects/chozopipesthermal06x3/imats/chozopipesthermal06x3_pipes.bsmat",
	"maps/objects/chozopipesthermal07x1/imats/chozopipesthermal07x1_pipes.bsmat",
	"maps/objects/chozopipesthermal07x3/imats/chozopipesthermal07x3_pipes.bsmat",
	"maps/objects/magnetglovesp01cornerin/imats/magnetglovesp01cornerin_mp_opaquemaps_simple.bsmat",
	"maps/objects/savestationr/imats/savestationr_mp_opaquemaps_simple_01.bsmat",
	"actors/props/ev_kraid_entrance/models/imats/ev_kraid_entrance_mp_opaquemaps_simple_01.bsmat",
	"actors/props/ev_kraid_entrance/models/imats/ev_kraid_entrance_mp_opaquemaps_simple_02.bsmat",
	"actors/props/ev_kraid_entrance/models/imats/ev_kraid_entrance_mp_opaquemaps_simple_03.bsmat",
	"actors/props/ev_kraid_entrance/models/imats/ev_kraid_entrance_mp_opaquemaps_simple_04.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel11_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel13_mp_opaquemaps_simple_21.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_x1_mapmodel02_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_x1_mapmodel03_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel17_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel18_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel19_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel20_mp_opaquemaps_simple_18.bsmat",
	"maps/objects/chozomagassetn04/imats/chozomagassetn04_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagcolumn01/imats/chozomagcolumn01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagcolumn01/imats/chozomagcolumn01_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/magdigrocklava02/imats/magdigrocklava02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrocklava03/imats/magdigrocklava03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrocklava04/imats/magdigrocklava04_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrocklava05/imats/magdigrocklava05_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magnetglovesp01xhalf2/imats/magnetglovesp01xhalf2_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallpathgenjoint03/imats/chozoallpathgenjoint03_mp_opaque_02.bsmat",
	"actors/props/ev_kraid_entrance/models/imats/ev_kraid_entrance_mp_opaquemaps_simple_05.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_x1_mapmodel03_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_x1_mapmodel03_mp_opaquemaps_simple_16.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_x1_mapmodel03_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel07_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel17_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel17_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel20_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel20_mp_opaquemaps_simple_19.bsmat",
	"maps/objects/chozobgmagwall05endl/imats/chozobgmagwall05endl_mp_opaque_01.bsmat",
	"maps/objects/chozobgmagwallendright/imats/chozobgmagwallendright_mp_opaquemaps_simple01.bsmat",
	"maps/objects/chozobgmagwallendright/imats/chozobgmagwallendright_mp_opaquemaps_simple02.bsmat",
	"maps/objects/magnetziplinesp01x2/imats/magnetziplinesp01x2_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part027_n2_mapmodel13_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgmagwallendleft/imats/chozobgmagwallendleft_mp_opaquemaps_simple01.bsmat",
	"maps/objects/chozobgmagwallendleft/imats/chozobgmagwallendleft_mp_opaquemaps_simple02.bsmat",
	"maps/objects/chozomagplatform150/imats/chozomagplatform150_mp_opaque_02.bsmat",
	"maps/objects/chozopathmag02_endl/imats/chozopathmag02_endl_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopathmag02_endr/imats/chozopathmag02_endr_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopathmag02x1a/imats/chozopathmag02x1a_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozopathmag02x1b/imats/chozopathmag02x1b_mp_opaquemaps_simple.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/backfliptrail_left_backflip_trail_left_backfliptrail_left.bsmat",
	"maps/genericimats/cavrockbackground13_generic.bsmat",
	"maps/genericimats/cavrockbackground17_generic.bsmat",
	"maps/genericimats/magrockbackgorund01_generic.bsmat",
	"maps/objects/chozobgmagwall03x1/imats/chozobgmagwall03x1_mp_opaquemaps_simple01.bsmat",
	"maps/objects/chozobgmagwall03x1/imats/chozobgmagwall03x1_mp_opaquemaps_simple02.bsmat",
	"maps/objects/chozopathmag02x4/imats/chozopathmag02x4_mp_opaquemaps_simple.bsmat",
	"actors/props/ev_lavapump_mg_001/models/imats/ev_lavapump_mg_001_slimenolight.bsmat",
	"maps/objects/chozomagasset02/imats/chozomagasset02_mp_opaque_02.bsmat",
	"maps/objects/chozobgmagwall04/imats/chozobgmagwall04_mp_opaquemaps_simple01.bsmat",
	"maps/objects/chozobgmagwall04/imats/chozobgmagwall04_mp_opaquemaps_simple02.bsmat",
	"maps/objects/magmeltrock01/imats/magmeltrock01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magmeltrock02/imats/magmeltrock02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallasset02/imats/chozoallasset02_mp_opaque_01.bsmat",
	"maps/objects/maproom001l/imats/maproom001l_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrock05/imats/magdigrock05_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/magdigrock06/imats/magdigrock06_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozostationpath01end/imats/chozostationpath01end_mat01.bsmat",
	"maps/objects/chozostationpath01x1/imats/chozostationpath01x1_mat01.bsmat",
	"maps/objects/chozostationpath01x4/imats/chozostationpath01x4_mat01.bsmat",
	"maps/objects/magdigrock01/imats/magdigrock01_mp_opaquemaps_simple.bsmat",
	"maps/objects/magdigrock04/imats/magdigrock04_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_o7_mapmodel16_glass.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part021_r7_mapmodel03_glass.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part029_o8_mapmodel52_glass.bsmat",
	"actors/props/ev_lavapump_mg_001/models/imats/ev_lavapump_mg_001_slime.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_glass00_glass.bsmat",
	"maps/genericimats/chozodebriswall01_generic.bsmat",
	"maps/genericimats/rockcavegrey01_generic.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/magma_wave_magmawave.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/magmalaser_base_magmalaser_base.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part027_px_cooldown_00_part013ice.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/backfliptrail_right_backflip_right.bsmat",
	"actors/props/ev_dspiston_heat/models/imats/ev_dspiston_heat_part004_px.bsmat",
	"actors/props/ev_tpiston_heat/models/imats/ev_tpiston_heat_part004_px.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_l01_fxarm.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_l02_fxarm.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_r01_fxarm.bsmat",
	"actors/characters/cooldownxboss/models/imats/cooldownxboss_r02_fxarm.bsmat",
	"actors/props/cut_cooldownboss_machine/models/imats/cut_cooldownboss_machine_fog.bsmat",
	"maps/genericimats/snow01_generic.bsmat",
	"maps/genericimats/magnetmat02_generic_off.bsmat",
	"actors/props/db_dif_mg_002/models/imats/db_dif_mg_002_mp_opaquemaps_simple_dissolve_06.bsmat",
	"cutscenes/0081cooldowndeath/fx/imats/plasmabeam_chargedfull_projectile_rays.bsmat",
	"actors/props/ev_kraid_structure_ingame/models/imats/ev_kraid_structure_ingame_mapkraidlava01.bsmat",
	"actors/props/wagontrain/fx/imats/trainlightning_mp_lightningmtl00.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part027_n2_lshaft01_mapkraid01.bsmat",
	"actors/events/mapev_lightinsects/models/imats/mapev_lightinsects_lightinsects_mat.bsmat",
	"maps/genericimats/lavaglass02_generic.bsmat",
	"maps/genericimats/lavaglass01_generic.bsmat",
	"actors/weapons/cooldownxbosslavacarpet/fx/imats/lavafloor_bubblesfloor.bsmat",
	"maps/genericimats/chozomatpaintedyellow01_generic.bsmat",
	"maps/genericimats/chozomatpaintedwhite01_generic.bsmat",
	"cutscenes/0038magmaemmypresentation/fx/imats/emmycone_cone.bsmat",
	"maps/genericimats/chozomatmetalblack02_generic.bsmat",
	"maps/genericimats/chozomatpaintedred01_generic.bsmat",
	"maps/genericimats/chozomatplates03_generic.bsmat",
	"maps/genericimats/chozomatpipes06_generic.bsmat",
	"maps/genericimats/vertexmetalshiny_generic.bsmat",
	"maps/genericimats/vertexmetal_generic.bsmat",
	"actors/items/powerup_diffusionbeam/models/imats/powerup_diffusionbeam_mp_glass_01.bsmat",
	"maps/objects/gravitysuit_chozo/imats/gravitysuit_chozo_helmet.bsmat",
	"maps/objects/chozoalltunnel01curve/imats/chozoalltunnel01curve_mp_glass_01.bsmat",
	"maps/objects/chozoalltunnel01x1/imats/chozoalltunnel01x1_mp_glass_01.bsmat",
	"maps/objects/chozoalltunnel01x3/imats/chozoalltunnel01x3_mp_glass_01.bsmat",
	"actors/props/ev_lavapump_mg_001/models/imats/ev_lavapump_mg_001_id10.bsmat",
	"actors/props/ev_lavapump_mg_001/models/imats/ev_lavapump_mg_001_id9.bsmat",
	"actors/weapons/cooldownxbosswindtunneldamagetrigger/fx/imats/wall_bubbles_bubbles.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_a8_mattepaintclouds02_mattepaintingmagma015clouds01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_s3_mattepaintclouds01b_mattepaintingbaselab003smoke01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_s3_mattepaintclouds01_mattepaintingbaselab003smoke01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_a8_mattepaintclouds02_mattepaintingbaselab003smoke01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_s3_mattepaintclouds01_mattepaintingmagma015clouds02.bsmat",
	"maps/genericimats/vertexmetalfw2_generic.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part004_a8_mattepaintbackgorund01_mattepaintingmagma004background01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_mattepaintbackgorund01_part015_mattepaintbackgorund01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_mattepaintbackgorund02_mattepaintingmagma015background01.bsmat",
	"cutscenes/0061kraiddeath/fx/imats/magmaheatplane02_distortion.bsmat",
	"maps/fx/magmaheat/imats/magmaheatplane03_distortion.bsmat",
	"cutscenes/0061kraiddeath/fx/imats/kraidgrab_trail2.bsmat",
	"cutscenes/0078cooldownpresentation/fx/imats/morphball_trail.bsmat",
	"actors/props/cut_cooldownboss_machine/models/imats/cut_cooldownboss_machine_machine.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_s2_mattepaint_skybox_mattepaintingcooldownxskybox.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_mattepaintrocks01_part015_mattepaintrocks01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_mattepaintrocks02_mattepaintingmagma015rocks01.bsmat",
	"actors/characters/kraid/models/imats/kraid_damagebelly.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_s2_mattepaint_rocks_mattepaintingcooldownxrocks.bsmat",
	"maps/genericimats/guidemaplightkraid_generic.bsmat",
	"maps/genericimats/selfilumwhitenoglow_generic.bsmat",
	"actors/props/ev_lavapump_mg_001/models/imats/ev_lavapump_mg_001_machine.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part015_e7_mattepaintlightshaft02_mattepaintingmagma015lightshaft02.bsmat",
	"cutscenes/0059kraidpresentation/fx/imats/kraid_intro_fog_mat.bsmat",
	"cutscenes/0078cooldownpresentation/fx/imats/cooldown_intro_fog_mat.bsmat",
	"maps/fx/holograms/models/imats/holo_16_9_vfx1_holo_16_9.bsmat",
	"maps/fx/holograms/models/imats/holo_16_9_vfx2_holo_16_9.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part002_jp1_reflection_part002_magma_jp1_reflection.bsmat",
	"actors/events/mapev_insects/models/imats/mapev_insects_mp_opaqueconstantcolor.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part018_jp1_planereflect_01_maproom_magma018_01.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_planereflection00_mp_reflection_96.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part025_r5_planereflection01_mp_reflection_97.bsmat",
	"actors/characters/kraid/models/imats/kraid_eyesfx_fresnel.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part003_s3_shadow_part003.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part011_n2_planereflection_part011_floor.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part032_n2_planereflection_part032_floor.bsmat",
	"maps/levels/c10_samus/s020_magma/models/imats/part035_n2_planereflection_part035_floor.bsmat",
	"maps/objects/chozoallwagonrail01x16/imats/chozoallwagonrail01x16_mat02.bsmat",
	"actors/props/wagontrain/fx/imats/forcefield_glow.bsmat",
	"actors/props/wagontrain/models/imats/wagontrain_emisivo.bsmat",
	"cutscenes/0059kraidpresentation/fx/imats/kraid_camera_color.bsmat",
	"actors/characters/core_x/models/imats/core_x_mat04.bsmat",
	"actors/characters/core_x/models/imats/core_x_mat05.bsmat",
	"actors/weapons/kraidbouncingcreaturesunb/models/imats/kraidbouncingcreaturesunb_bouncingcreatures.bsmat",
	"actors/weapons/kraidbouncingcreatures/models/imats/kraidbouncingcreatures_bouncingcreatures.bsmat",
	"actors/characters/kraid/fx/imats/splashkraid_material.bsmat",
	"actors/weapons/kraidrottenmeat/models/imats/kraidrottenmeat_rottenmeat.bsmat",
	"actors/weapons/kraidnail/fx/imats/nailsfracture01_nails0.bsmat",
	"actors/weapons/kraidspike/fx/imats/spikes_spikes.bsmat",
	"actors/weapons/kraidspike/fx/imats/spikesfast_spikes.bsmat",
	"actors/weapons/kraidspike/models/imats/kraidspike_barriga.bsmat",
	"actors/weapons/kraidnail/models/imats/kraidnail01_cabeza.bsmat",
	"actors/weapons/kraidshockersplashprojectile/fx/imats/mudwave01fx_mudwave01fx.bsmat",
	"actors/weapons/kraidspike/fx/imats/slime_slimetail.bsmat",
	"actors/weapons/kraidacidblobs/fx/imats/blob_projectile_glowspit.bsmat",
	"actors/weapons/kraidacidblobs/fx/imats/blob_projectile_mainspit.bsmat",
	"actors/weapons/kraidrottenmeat/fx/imats/meat_slime_arc.bsmat",
	"actors/weapons/kraidnail/fx/imats/nailstrail_nailstrail.bsmat",
	"actors/weapons/kraidrottenmeat/fx/imats/meat_slime_tail.bsmat",
	"actors/weapons/kraidspike/fx/imats/slime_tail.bsmat",
	"actors/weapons/kraidspike/fx/imats/slime_arc.bsmat",
	"actors/characters/samus/fx/imats/kraidgrab_trail_02.bsmat",
	"actors/characters/kraid/fx/imats/kraid_fresnel.bsmat",
	"actors/weapons/cooldownxbosslavacarpet/fx/imats/lavabubbles_lavabubbles.bsmat",
	"actors/weapons/cooldownxbosslavacolumn/fx/imats/columndismiss_geodismiss.bsmat",
	"actors/weapons/cooldownxbosslavacarpet/fx/imats/lavaground_lavaground.bsmat",
	"actors/weapons/cooldownxbosslavacolumn/fx/imats/lavacolumn_lavacolumn.bsmat",
	"actors/characters/cooldownxboss/fx/imats/lifeabsorption_life.bsmat",
	"actors/characters/cooldownxboss/fx/imats/background_wind_mp_fxmeshmtl00_wind.bsmat",
	"actors/characters/cooldownxboss/fx/imats/ray_lateral_raylateral.bsmat",
	"actors/characters/cooldownxboss/fx/imats/ray_lateral_detail_ray.bsmat",
	"actors/characters/cooldownxboss/fx/imats/lifeabsorption_tail_lifeabsorptionbody.bsmat",
	"actors/characters/cooldownxboss/fx/imats/lifeabsorption_body_lifeabsorptionbody.bsmat",
	"actors/characters/cooldownxboss/fx/imats/lifeabsorption_body_lifeabbase.bsmat",
	"actors/characters/cooldownxboss/fx/imats/lifeabsorption_tail_lifeabbase.bsmat",
	"actors/characters/cooldownxboss/fx/imats/bubbles_splash.bsmat",
	"actors/characters/cooldownxboss/fx/imats/reaperdoubletrail_reapertrail.bsmat",
	"actors/characters/cooldownxboss/fx/imats/reapertrail_reapertrail.bsmat",
	"actors/characters/cooldownxboss/fx/imats/cooldown_grab_fog_mat.bsmat",
	"actors/characters/cooldownxboss/fx/imats/cooldownfresnel.bsmat",
	"actors/characters/shakernaut/models/imats/shakernaut_shell.bsmat",
	"actors/characters/shakernaut/models/imats/shakernaut_body.bsmat",
	"actors/characters/shelmit/fx/imats/shellmit_shellbreak_mp_shelmitfracture.bsmat",
	"actors/weapons/fulmitebellymine/models/imats/fulmitebellymine_fulmite.bsmat",
	"actors/characters/vulkran/models/imats/vulkran_material.bsmat",
	"actors/characters/fulmite/models/imats/fulmite_fulmite.bsmat",
	"actors/characters/sclawk/models/imats/sclawk_mp_opaque_01.bsmat",
	"actors/characters/shakernaut/models/imats/shakernaut_armright.bsmat",
	"actors/characters/shakernaut/models/imats/shakernaut_armleft.bsmat",
	"actors/characters/shelmit/models/imats/shelmit_mp_opaque_01.bsmat",
	"actors/characters/shakernaut/fx/imats/warm_right_rightarmback.bsmat",
	"actors/characters/shakernaut/fx/imats/warm_left_leftarmback.bsmat",
	"actors/characters/shakernaut/fx/imats/warm_right_rightintense.bsmat",
	"actors/characters/shakernaut/fx/imats/warm_left_leftintense.bsmat",
	"actors/characters/shakernaut/fx/imats/warm_right_rightwarm.bsmat",
	"actors/characters/shakernaut/models/imats/shakernaut_hoodright.bsmat",
	"actors/characters/shakernaut/fx/imats/warm_left_leftwarm.bsmat",
	"actors/characters/shakernaut/models/imats/shakernaut_hoodleft.bsmat",
	"actors/characters/vulkran/fx/imats/magma_muzzle_magma2.bsmat",
	"actors/characters/vulkran/fx/imats/magma_muzzle_magma.bsmat",
	"actors/weapons/fulmitebellymine/fx/imats/explosion_explosion.bsmat",
	"actors/weapons/fulmitebellymine/fx/imats/explosion_midetail.bsmat",
	"actors/weapons/fulmitebellymine/fx/imats/explosion_inner.bsmat",
	"actors/characters/emmy/fx/imats/protectorfresnel_02_protfresnel.bsmat",
	"actors/characters/emmylab/models/imats/emmylab_white_body.bsmat",
	"actors/characters/emmylab/models/imats/emmylab_white_head.bsmat",
	"actors/props/weightactivatedplatform_generator/models/imats/weightactivatedplatform_generator_material01.bsmat",
	"maps/fx/emmyventilationgridgas00/fx/imats/emmyventilationgridgas02_material.bsmat",
	"maps/fx/labsteam/fx/imats/labmist01_central_material.bsmat",
	"maps/fx/labsteam/fx/imats/labmist00_right_material.bsmat",
	"maps/fx/labsteam/fx/imats/labmist01_right_material.bsmat",
	"maps/fx/labsteam/fx/imats/labmist00_left_material.bsmat",
	"maps/fx/labsteam/fx/imats/labmist01_left_material.bsmat",
	"actors/props/weightactivatedplatform_generator/models/imats/weightactivatedplatform_mp_opaque_01.bsmat",
	"maps/fx/labdryice/fx/imats/labdryice_down00_material.bsmat",
	"maps/fx/labsteam/fx/imats/labdryicegreen_down00_material.bsmat",
	"maps/fx/labsteam/fx/imats/labdryicegreen_vertical00_material.bsmat",
	"maps/fx/labsteam/fx/imats/labmist02_center_material.bsmat",
	"actors/spawnpoints/spawnpointslidle/models/imats/spawnpointslidle_material.bsmat",
	"actors/spawnpoints/spawnpointautsharp/models/imats/spawnpointautsharp_lightl.bsmat",
	"actors/spawnpoints/spawnpointautsharp/models/imats/spawnpointautsharp_lightr.bsmat",
	"actors/events/mapev_disectedcreature/models/imats/mapev_disectedcreature_mp_opaque.bsmat",
	"actors/spawnpoints/spawnpointautsharp/models/imats/spawnpointautsharp_spawnpointautsharp.bsmat",
	"actors/spawnpoints/spawnpointslidle/models/imats/spawnpointslidleoutwall_material.bsmat",
	"actors/events/mapev_gooplot/models/imats/mapev_gooplot_event01.bsmat",
	"actors/spawnpoints/spawnpointslidle/models/imats/spawnpointslidleout_material.bsmat",
	"actors/props/powergeneratorengine/models/imats/powergeneratorengine_static_materiala.bsmat",
	"actors/props/powergeneratorengine/models/imats/powergeneratorengine_static_materialb.bsmat",
	"actors/props/powergeneratorengine/models/imats/powergeneratorengine_static_materialc.bsmat",
	"actors/props/powergeneratorengine/models/imats/powergeneratorengine_static_materiald.bsmat",
	"actors/props/mlm_block/models/imats/mlm_block_emisive01.bsmat",
	"actors/props/mlm_block/models/imats/mlm_block_emisive02.bsmat",
	"actors/props/mlm_block/models/imats/mlm_block_emisive03.bsmat",
	"actors/props/mlm_block/models/imats/mlm_block_emisive04.bsmat",
	"actors/props/mlm_block/models/imats/mlm_block_emisive05.bsmat",
	"actors/props/mlm_point/models/imats/mlm_point_mat01.bsmat",
	"actors/props/emergency_light/models/imats/emergency_light_.bsmat",
	"actors/props/powergenerator/models/imats/powergenerator_device.bsmat",
	"maps/objects/aquarocksaltcorner/imats/aquarocksaltcorner_mp_opaque_02.bsmat",
	"actors/items/powerup_bomb/models/imats/powerup_bomb_material.bsmat",
	"actors/events/mapev_celldoors/models/imats/mapev_celldoors_mp_opaque_01.bsmat",
	"maps/objects/aquarocksalt01/imats/aquarocksalt01_mp_opaque_02.bsmat",
	"maps/objects/aquarocksalt02/imats/aquarocksalt02_mp_opaque_02.bsmat",
	"maps/objects/aquarocksalt03/imats/aquarocksalt03_mp_opaque_02.bsmat",
	"maps/objects/fxwatersplashx1/imats/fxwatersplashx1_splash.bsmat",
	"actors/props/mlm_block/models/imats/mlm_block_mlm_block.bsmat",
	"maps/objects/aquarockplatform01x3/imats/aquarockplatform01x3_mp_opaque_01.bsmat",
	"maps/objects/aquarockwall01x3/imats/aquarockwall01x3_mp_opaque_01.bsmat",
	"maps/objects/aquarockwall02x3/imats/aquarockwall02x3_mp_opaque_02.bsmat",
	"maps/objects/aquarockwall03x3/imats/aquarockwall03x3_mp_opaque_01.bsmat",
	"maps/objects/aquarockwall04x3/imats/aquarockwall04x3_mp_opaque_01.bsmat",
	"maps/objects/aquarockwall05x3/imats/aquarockwall05x3_mp_opaque_01.bsmat",
	"maps/objects/aquarockwall06x3/imats/aquarockwall06x3_mp_opaque_01.bsmat",
	"maps/objects/aquarockwall07x3/imats/aquarockwall07x3_mp_opaque_02.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part016_jg5_mapmodel01_mp_opaque_52.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part016_jg5_mapmodel01_mp_opaque_53.bsmat",
	"maps/objects/chozobaseassets02/imats/chozobaseassets02_mp_opaque_simple.bsmat",
	"maps/objects/chozobaseassets03/imats/chozobaseassets03_mp_opaque_simple.bsmat",
	"maps/objects/aquarock01x3/imats/aquarock01x3_mp_opaque_01.bsmat",
	"maps/objects/aquarock02x3/imats/aquarock02x3_mp_opaque_01.bsmat",
	"maps/objects/aquarock02x4/imats/aquarock02x4_mp_opaque_01.bsmat",
	"maps/genericimats/decalpuddle01_generic.bsmat",
	"maps/objects/chozoallmecharm01/imats/chozoallmecharm01_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part016_jg5_mapmodel01_mp_opaque_58.bsmat",
	"maps/objects/chozoaqatrezzorot01/imats/chozoaqatrezzorot01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallpathgen01endr/imats/chozoallpathgen01endr_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallpathgen01x1/imats/chozoallpathgen01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallpathgen01x4/imats/chozoallpathgen01x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallpathgen02x1/imats/chozoallpathgen02x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestminis01/imats/plantforestminis01_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestminis02/imats/plantforestminis02_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobasebgasset01/imats/chozobasebgasset01_mp_opaque_01.bsmat",
	"maps/objects/chozowiderail01x3/imats/chozowiderail01x3_mp_opaquemaps_simple.bsmat",
	"maps/genericimats/chozomatcircuits03_generic.bsmat",
	"maps/objects/chozoaqtuberia/imats/chozoaqtuberia_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part005_r3_mapmodel04_mp_opaquemaps_30.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part005_r3_mapmodel06_mp_opaquemaps_30.bsmat",
	"maps/objects/chozobasepath01x1/imats/chozobasepath01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobasepath01x4/imats/chozobasepath01x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobasejaildoor01opena/imats/chozobasejaildoor01opena_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobasejaildoor01openb/imats/chozobasejaildoor01openb_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobasejaildoor02open/imats/chozobasejaildoor02open_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobaseproplaser01/imats/chozobaseproplaser01_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part005_r3_mapmodel08_mp_opaquemaps_29.bsmat",
	"actors/props/db_hdoor_b1_001/models/imats/db_hdoor_b1_001_mp_opaquemaps_simple_dissolve_08.bsmat",
	"maps/genericimats/wateremmyfront01_generic.bsmat",
	"actors/props/db_hdoor_b1_001/models/imats/db_hdoor_b1_001_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_b1_002/models/imats/db_reg_b1_002_mp_opaquemaps_simple_dissolve_05.bsmat",
	"actors/props/db_reg_b1_004/models/imats/db_reg_b1_004_mp_opaquemaps_simple_dissolve_05.bsmat",
	"actors/props/db_hdoor_b1_001/models/imats/db_hdoor_b1_001_mp_opaquemaps_simple_dissolve_02.bsmat",
	"actors/props/db_hdoor_b1_001/models/imats/db_hdoor_b1_001_mp_opaquemaps_simple_dissolve_04.bsmat",
	"actors/props/db_hdoor_b1_001/models/imats/db_hdoor_b1_001_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_b1_001/models/imats/db_reg_b1_001_mp_opaquemaps_simple_dissolve_04.bsmat",
	"actors/props/db_reg_b1_003/models/imats/db_reg_b1_003_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_dif_b1_001/models/imats/db_dif_b1_001_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_b1_001/models/imats/db_reg_b1_001_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_b1_002/models/imats/db_reg_b1_002_mp_opaquemaps_simple_dissolve_02.bsmat",
	"actors/props/db_reg_b1_004/models/imats/db_reg_b1_004_mp_opaquemaps_simple_dissolve_02.bsmat",
	"actors/props/db_reg_b1_004/models/imats/db_reg_b1_004_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_b1_002/models/imats/db_reg_b1_002_mp_opaquemaps_simple_dissolve_04.bsmat",
	"actors/props/db_reg_b1_004/models/imats/db_reg_b1_004_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_hdoor_b1_001/models/imats/db_hdoor_b1_001_mp_opaquemaps_simple_dissolve_05.bsmat",
	"actors/props/db_dif_b1_001/models/imats/db_dif_b1_001_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_b1_001/models/imats/db_reg_b1_001_mp_opaquemaps_simple_dissolve_02.bsmat",
	"actors/props/db_reg_b1_002/models/imats/db_reg_b1_002_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_b1_002/models/imats/db_reg_b1_002_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_b1_003/models/imats/db_reg_b1_003_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_b1_004/models/imats/db_reg_b1_004_mp_opaquemaps_simple_dissolve_04.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part011_e7_mapmodels05_ocean.bsmat",
	"maps/objects/communicationroomwalldoor/imats/communicationroomwalldoor_mat_01.bsmat",
	"actors/props/db_dif_b1_002/models/imats/chozomatconcretebase01_generic.bsmat",
	"actors/props/db_dif_b1_002/models/imats/chozomatconcretebase02_generic.bsmat",
	"actors/props/db_dif_b1_001/models/imats/db_dif_b1_001_mp_opaquemaps_simple_dissolve_05.bsmat",
	"actors/props/db_dif_b1_002/models/imats/db_dif_b1_002_mp_opaquemaps_simple_01.bsmat",
	"actors/props/db_dif_b1_002/models/imats/db_dif_b1_002_mp_opaquemaps_simple_02.bsmat",
	"actors/props/db_dif_b1_002/models/imats/chozomatmetalblue04_generic.bsmat",
	"actors/props/db_hdoor_b1_001/models/imats/db_hdoor_b1_001_cascamat.bsmat",
	"actors/props/db_reg_b1_004/models/imats/db_reg_b1_004_cascamat02.bsmat",
	"actors/props/db_reg_b1_004/models/imats/db_reg_b1_004_cascamat03.bsmat",
	"maps/objects/chozoallpath02x3/imats/chozoallpath02x3_mp_opaquemaps_simple.bsmat",
	"actors/props/db_reg_b1_002/models/imats/db_reg_b1_002_cascamat.bsmat",
	"actors/props/db_reg_b1_003/models/imats/db_reg_b1_003_cascamat01.bsmat",
	"actors/props/db_reg_b1_004/models/imats/db_reg_b1_004_cascamat04.bsmat",
	"actors/props/db_reg_b1_001/models/imats/db_reg_b1_001_cascamat.bsmat",
	"actors/props/db_dif_b1_001/models/imats/db_dif_b1_001_cascamat.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_r9_mapmodel01_mp_opaquemaps_simple_60.bsmat",
	"maps/objects/aquarocksaltcorner/imats/aquarocksaltcorner_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel06_mp_opaquemaps_simple_47.bsmat",
	"actors/props/ev_dna_centrifuge/models/imats/ev_dna_centrifuge_body.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel06_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_mapmodel03_chozoallcorner01b_jp1.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel06_mp_opaquemaps_simple_45.bsmat",
	"actors/items/powerup_bomb/models/imats/powerup_bomb_hologram.bsmat",
	"maps/objects/aquarocksalt01/imats/aquarocksalt01_mp_opaque_01.bsmat",
	"maps/objects/aquarocksalt02/imats/aquarocksalt02_mp_opaque_01.bsmat",
	"maps/objects/aquarocksalt03/imats/aquarocksalt03_mp_opaque_01.bsmat",
	"actors/items/powerup_widebeam/models/imats/powerup_widebeam_cangrejo.bsmat",
	"maps/objects/chozobasebgcorridor01x3cornerl/imats/chozobasebgcorridor01x3cornerl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorridor01x3cornerr/imats/chozobasebgcorridor01x3cornerr_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorridor02cornerl/imats/chozobasebgcorridor02cornerl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorridor02cornerr/imats/chozobasebgcorridor02cornerr_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobaseatrezzodeposit01a/imats/chozobaseatrezzodeposit01a_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobaseatrezzodeposit01b/imats/chozobaseatrezzodeposit01b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorridor02x3b/imats/chozobasebgcorridor02x3b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorridor02x3/imats/chozobasebgcorridor02x3_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part012_jg4_mapmodel03_mp_opaquemaps_simple_42.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_r9_breakable03sg_casca226_mp_opaquemaps_simple_54.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_r9_breakable04sg_casca227_mp_opaquemaps_simple_54.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_r9_breakable05sg_casca228_mp_opaquemaps_simple_54.bsmat",
	"maps/objects/aquarocksaltcornersimple/imats/aquarocksaltcornersimple_mp_opaquemaps_simple_01.bsmat",
	"actors/events/mapev_shrimps/models/imats/mapev_shrimps_shrimp01.bsmat",
	"actors/events/mapev_shrimps/models/imats/mapev_shrimps_shrimp02.bsmat",
	"actors/events/mapev_shrimps/models/imats/mapev_shrimps_shrimp03.bsmat",
	"maps/objects/chozobasebgcorridor01x3b/imats/chozobasebgcorridor01x3b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorridor01x3b/imats/chozobasebgcorridor01x3b_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part008_jg3_mapmodel006_mp_opaquemaps_simple_41.bsmat",
	"maps/objects/chozobasebgcorridor01x1/imats/chozobasebgcorridor01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorridor01x3/imats/chozobasebgcorridor01x3_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgcorridor01x3/imats/chozobasebgcorridor01x3_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/aquarocksalt03simple/imats/aquarocksalt03simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarocksalt03simple/imats/aquarocksalt03simple_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part005_r3_mapmodel06_mp_opaquemaps_simple_31.bsmat",
	"maps/objects/chozobasecolumn01x3/imats/chozobasecolumn01x3_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasecolumn01x3/imats/chozobasecolumn01x3_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobasehandrail01_stairsl/imats/chozobasehandrail01_stairsl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasehandrail01_stairsr/imats/chozobasehandrail01_stairsr_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasewallsetcorner01right/imats/chozobasewallsetcorner01right_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasewallsetcorner02right/imats/chozobasewallsetcorner02right_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mapmodel_05_mp_opaquemaps_simple_52.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mapmodel_05_mp_opaquemaps_simple_53.bsmat",
	"maps/objects/chozobasewallsetcorner01left/imats/chozobasewallsetcorner01left_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasewallsetcorner02left/imats/chozobasewallsetcorner02left_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmytunnelbg01corner2/imats/chozoemmytunnelbg01corner2_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_r9_breakable18sg_casca237_mp_opaquemaps_simple_66.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_r9_breakable19sg_casca238_mp_opaquemaps_simple_66.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_r9_breakable20sg_casca239_mp_opaquemaps_simple_66.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part009_f8_mapmodel006_mp_opaquemaps_simple_35.bsmat",
	"maps/objects/chozoallpipesset01xcorner2/imats/chozoallpipesset01xcorner2_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_r9_mapmodel01_mp_opaquemaps_simple_54.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part008_jg3_mapmodel001_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part026_jg4_mapmodel006_mp_opaquemaps_simple_37.bsmat",
	"maps/objects/chozobasebgwall06endl/imats/chozobasebgwall06endl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgwall06endr/imats/chozobasebgwall06endr_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarocksalt01simple/imats/aquarocksalt01simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarocksalt02simple/imats/aquarocksalt02simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgwall06mid/imats/chozobasebgwall06mid_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgwindow01cornerl/imats/chozobasebgwindow01cornerl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgwindow02cornerr/imats/chozobasebgwindow02cornerr_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasehandrail01_01/imats/chozobasehandrail01_01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasehandrail01_02/imats/chozobasehandrail01_02_mp_opaquemaps_simple_01.bsmat",
	"actors/events/mapev_disectedcreature/models/imats/mapev_disectedcreature_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part001_e5_mapmodel01_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part006_jg9_mapmodel008_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part008_jg3_mapmodel001_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_mapmodel16_chozoemmybg01ax4_jp01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part026_jg4_mapmodel003_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part026_jg4_mapmodel006_mp_opaquemaps_simple_32.bsmat",
	"maps/objects/chozobasesetadn01_a/imats/chozobasesetadn01_a_mp_opaquemaps_simplevcatt.bsmat",
	"maps/objects/chozobasesetadn01_b/imats/chozobasesetadn01_b_mp_opaquemaps_simplevcatt.bsmat",
	"maps/objects/chozobasesetadn01_c/imats/chozobasesetadn01_c_mp_opaquemaps_simplevcatt.bsmat",
	"maps/objects/chozobasesetadn01_d/imats/chozobasesetadn01_d_mp_opaquemaps_simplevcatt.bsmat",
	"maps/objects/chozobasesetadn02_a/imats/chozobasesetadn02_a_mp_opaquemaps_simplevcatt.bsmat",
	"maps/objects/chozobasesetadn02_b/imats/chozobasesetadn02_b_mp_opaquemaps_simplevcatt.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part010_s2_mapmodel_01_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part010_s2_mapmodel_01_mp_opaquemaps_simple_34.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part012_jg4_mapmodel00_mp_opaquemaps_simple_36.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_mapmodel16_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part005_r3_mapmodel00_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part005_r3_mapmodel07_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part006_jg9_mapmodel006_mp_opaquemaps_simple_49.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part013_o4_mapmodel06_mp_opaquemaps_simple_36.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel07_mp_opaquemaps_simple_22.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel12_mp_opaquemaps_simple_48.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part026_jg4_mapmodel001_mp_opaquemaps_simple_35.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mapmodel_04_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mapmodel_04_mp_opaquemaps_simple_57.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mapmodel_04_mp_opaquemaps_simple_58.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mapmodel_04_mp_opaquemaps_simple_59.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mapmodel_04_mp_opaquemaps_simple_60.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part012_jg4_break_00_mp_opaquemaps_simple_36.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part012_jg4_break_01_mp_opaquemaps_simple_36.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_mapmodel09_chozoemmypath01v3_jp001.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_mapmodel00_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_mapmodel_01_mp_opaquemaps_simple_41.bsmat",
	"maps/objects/chozoallpipesset01x1/imats/chozoallpipesset01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmybg01tur1/imats/chozoemmybg01tur1_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break00_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break01_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break02_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break03_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break04_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break05_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break06_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break07_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break08_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break09_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break10_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part015_jg5_break11_mp_opaquemaps_simple_32.bsmat",
	"maps/objects/chozobasebgwindow01x1/imats/chozobasebgwindow01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgwindow02x2/imats/chozobasebgwindow02x2_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_sg_casca199_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_sg_casca200_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_sg_casca201_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_sg_casca202_mp_opaquemaps_simple_56.bsmat",
	"maps/objects/aquarock01x3simple/imats/aquarock01x3simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarock02x4simple/imats/aquarock02x4simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarock03x4simple/imats/aquarock03x4simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarock04x4simple/imats/aquarock04x4simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoaquafloodgate/imats/chozoaquafloodgate_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasejaildoor01/imats/chozobasejaildoor01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobasejaildoor02/imats/chozobasejaildoor02_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobasewallset01/imats/chozobasewallset01_mp_opaquemaps_simple_03.bsmat",
	"maps/objects/chozobasewallset02/imats/chozobasewallset02_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobasewallset03/imats/chozobasewallset03_mp_opaquemaps_simple_03.bsmat",
	"maps/objects/chozobasewallset04/imats/chozobasewallset04_mp_opaquemaps_simple_03.bsmat",
	"maps/objects/chozobasewallset05/imats/chozobasewallset05_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_sg_casca240_chozoemmywall01x4_jp001.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_sg_casca241_chozoemmywall01x4_jp001.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel06_mp_opaquemaps_simple_27.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel06_mp_opaquemaps_simple_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel07_mp_opaquemaps_simple_28.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel07_mp_opaquemaps_simple_41.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel11_mp_opaquemaps_simple_27.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel11_mp_opaquemaps_simple_44.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel12_mp_opaquemaps_simple_27.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel12_mp_opaquemaps_simple_41.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel12_mp_opaquemaps_simple_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel12_mp_opaquemaps_simple_49.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel15_mp_opaquemaps_simple_27.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_sg_casca141_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_sg_casca142_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_sg_casca143_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_sg_casca144_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_sg_casca145_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_sg_casca146_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_sg_casca147_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_sg_casca148_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_sg_casca26000_mp_opaquemaps_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_sg_casca26001_mp_opaquemaps_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_sg_casca26002_mp_opaquemaps_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_sg_casca26004_mp_opaquemaps_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_sg_casca26005_mp_opaquemaps_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_sg_casca26007_mp_opaquemaps_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_sg_casca26008_mp_opaquemaps_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_sg_casca26009_mp_opaquemaps_43.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part026_jg4_mapmodel004_mp_opaquemaps_simple_38.bsmat",
	"maps/objects/chozobasebgwall06x1/imats/chozobasebgwall06x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasebgwall06x2/imats/chozobasebgwall06x2_mp_opaquemaps_simple_01.bsmat",
	"actors/props/cut_all_pathemmy01/models/imats/cut_all_pathemmy01_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca113_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca114_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca115_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca116_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca256_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca257_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca258_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca259_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca260_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca261_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca262_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_sg_casca263_mp_opaquemaps_simple_65.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part010_s2_mapmodel_01_mp_opaquemaps_simple_33.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part011_e7_mapmodels06_mp_opaquemaps_simple_35.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part012_jg4_mapmodel05_mp_opaquemaps_simple_35.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_mapmodel03_chozoemmywall01x4_jp001.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_mapmodel09_chozoemmypath01x1_jp001.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_mapmodel09_chozoemmywall01x4_jp001.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_mapmodel11_chozoemmywall01x4_jp001.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part017_jp6_mapmodel12_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_mapmodel02_mp_opaquemaps_simple_29.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_mapmodel06_mp_opaquemaps_simple_29.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_mapmodel_02_mp_opaquemaps_simple_36.bsmat",
	"maps/objects/chozobasetanklbroken01/imats/chozobasetanklbroken01_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part005_r3_mapmodel03_mp_opaquemaps_simple_52.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part011_e7_mapmodels04_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part013_o4_mapmodel21_mp_stained_glass_fog_01.bsmat",
	"maps/objects/aquarockwall01x3/imats/aquarockwall01x3_mp_opaque_02.bsmat",
	"maps/objects/aquarockwall02x3/imats/aquarockwall02x3_mp_opaque_01.bsmat",
	"maps/objects/aquarockwall03x3/imats/aquarockwall03x3_mp_opaque_02.bsmat",
	"maps/objects/aquarockwall04x3/imats/aquarockwall04x3_mp_opaque_02.bsmat",
	"maps/objects/aquarockwall05x3/imats/aquarockwall05x3_mp_opaque_02.bsmat",
	"maps/objects/aquarockwall06x3/imats/aquarockwall06x3_mp_opaque_02.bsmat",
	"maps/objects/aquarockwall07x3/imats/aquarockwall07x3_mp_opaque_01.bsmat",
	"maps/objects/chozoallpathgen03endright/imats/chozoallpathgen03endright_mp_opaque_01.bsmat",
	"maps/objects/chozobasetankempty01/imats/chozobasetankempty01_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part008_jg3_mapmodel001_mp_opaquemaps_simple_42.bsmat",
	"maps/objects/chozoallpathgen03endleft/imats/chozoallpathgen03endleft_mp_opaque_01.bsmat",
	"maps/objects/chozobasepath02endl/imats/chozobasepath02endl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasepath02endr/imats/chozobasepath02endr_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part009_f8_mapmodel000_mp_opaquemaps_simple_31.bsmat",
	"maps/objects/chozobaseasset04/imats/chozobaseasset04_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobaseasset04/imats/chozobaseasset04_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobaseasset05/imats/chozobaseasset05_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobaseasset05/imats/chozobaseasset05_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozobasepath02x01/imats/chozobasepath02x01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasepath02x1b/imats/chozobasepath02x1b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasepath02x4b/imats/chozobasepath02x4b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasepath02x4/imats/chozobasepath02x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoaquagrid01/imats/chozoaquagrid01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobasetank01/imats/chozobasetank01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallpathgen03x1/imats/chozoallpathgen03x1_mp_opaque_01.bsmat",
	"maps/objects/chozoallpathgen03x4/imats/chozoallpathgen03x4_mp_opaque_02.bsmat",
	"maps/objects/chozobasebg01x4b/imats/chozobasebg01x4b_mp_opaquemaps_simple_02.bsmat",
	"maps/genericimats/cavrockbackground27_generic.bsmat",
	"maps/genericimats/cavrockbackground28_generic.bsmat",
	"maps/genericimats/bubbleslab02_generic.bsmat",
	"maps/objects/aberration01_a/imats/aberration01_a_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aberration01_b/imats/aberration01_b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquanature06a_01/imats/aquanature06a_01_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature06a_02/imats/aquanature06a_02_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature06a_03/imats/aquanature06a_03_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature06a_04/imats/aquanature06a_04_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature06a_05/imats/aquanature06a_05_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature06b_02/imats/aquanature06b_02_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature06b_03/imats/aquanature06b_03_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquarock01x3/imats/aquarock01x3_mp_opaque_02.bsmat",
	"maps/objects/aquarock02x3/imats/aquarock02x3_mp_opaque_02.bsmat",
	"maps/objects/aquarock02x4/imats/aquarock02x4_mp_opaque_02.bsmat",
	"maps/objects/aquadigrock02/imats/aquadigrock02_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquadigrock03/imats/aquadigrock03_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquadigrock04/imats/aquadigrock04_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquadigrock05/imats/aquadigrock05_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgemmybot01/imats/chozobgemmybot01_mp_opaque_01.bsmat",
	"maps/objects/aquanature01a/imats/aquanature01a_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature01b/imats/aquanature01b_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature01c/imats/aquanature01c_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature01d/imats/aquanature01d_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature03b/imats/aquanature03b_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature04a/imats/aquanature04a_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature05a/imats/aquanature05a_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature05b/imats/aquanature05b_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature05c/imats/aquanature05c_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature05e/imats/aquanature05e_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature05f/imats/aquanature05f_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature03/imats/aquanature03_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature04/imats/aquanature04_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquarock04x4/imats/aquarock04x4_mp_opaque_01.bsmat",
	"maps/genericimats/forestwood02_generic.bsmat",
	"maps/genericimats/sanddunes03_generic.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part020_jg3_mapmodel08_hideable_white.bsmat",
	"maps/genericimats/skin06_generic.bsmat",
	"actors/props/powergeneratorengine/fx/imats/generatorlightning02_mp_lightningmtl00.bsmat",
	"actors/props/powergeneratorengine/fx/imats/generatorlightning03_mp_lightningmtl00.bsmat",
	"actors/props/powergeneratorengine/fx/imats/generatorlightning_mp_lightningmtl00.bsmat",
	"actors/events/mapev_disectedcreature02/fx/imats/creaturelightning_lightning.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_lightshaft_lightcave_cavelight.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_station01_part003lshaft01.bsmat",
	"maps/genericimats/glassrooforange_generic.bsmat",
	"cutscenes/0039labemmypresentation/fx/imats/emmycone_cone.bsmat",
	"maps/genericimats/chozomatmetalyellow01_generic.bsmat",
	"maps/genericimats/chozomatmetalgreen04_generic.bsmat",
	"maps/genericimats/chozomatmetalblue08_generic.bsmat",
	"maps/genericimats/chozomatmetalblue12_generic.bsmat",
	"maps/genericimats/chozomatmetalgray14_generic.bsmat",
	"maps/genericimats/chozomatflatgray02_generic.bsmat",
	"maps/genericimats/chozomatmetalred04_generic.bsmat",
	"maps/genericimats/chozomataqua_generic.bsmat",
	"maps/fx/stargate/imats/stargateportal_material.bsmat",
	"actors/items/powerup_widebeam/models/imats/powerup_widebeam_bola.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part001_lightshaft_station_part001lightshaft_station.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_mapmodel_lightshaft_part025lshaft0.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part025_s7_mapmodel_lightshaft_part025lshaft2.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_lightshaft_lightcave2_cavelight_near.bsmat",
	"maps/objects/chozobaseatrezzodeposit01b/imats/chozobaseatrezzodeposit01b_mp_bubblespipe.bsmat",
	"maps/genericimats/bubbleslab01_generic.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_lightshaft_lightcave2_windowslight.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part001_lightshaft_part001lightshaftblue.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part002_lightshaft_lightcave2_cavelight.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part005_lightshaft2_part005_lightshaft2.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part005_lightshaft_part005_lightshaft.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part011_cavelightshaft_cavelightshaft.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part012_lightshaft_part012_lightshaft.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/centrallight_lightshaft_centrallight.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part001_lightshaft_part001lightshaft.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part008_lightshaft_lightshaft.bsmat",
	"maps/objects/chozobasetanklbroken01/imats/chozobasetanklbroken01_mp_glass_01.bsmat",
	"maps/objects/chozobasetankempty01/imats/chozobasetankempty01_mp_glass_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mattepaint01_mattepaintingbaselab003smoke01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mattepaint01_mattepaintingbaselab003smoke02.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mattepaint01_part003_mattepaintbackground01.bsmat",
	"actors/items/powerup_widebeam/models/imats/powerup_widebeam_autoilum.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part003_e9_mattepaint01_part003_mattepaintrocks01.bsmat",
	"maps/genericimats/glassbluebase_generic.bsmat",
	"maps/genericimats/glassbluebase02_generic.bsmat",
	"maps/genericimats/selfilumchozo01_lowlight_generic.bsmat",
	"maps/genericimats/selfilumbaselab01_generic.bsmat",
	"maps/genericimats/selfilumbaselab02_generic.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part019_s010_mapmodel16_part019_hologram.bsmat",
	"maps/objects/decalcharco01/imats/decalcharco01_mp_blend_0001.bsmat",
	"maps/genericimats/slimedecal01_generic.bsmat",
	"maps/fx/holograms/models/imats/holo_16_9_vfx1_blackout_holo_16_9.bsmat",
	"maps/fx/holograms/models/imats/holo_16_9_vfx2_blackout_holo_16_9.bsmat",
	"actors/events/mapev_disectedcreature/models/imats/mapev_disectedcreature_mp_opaqueconstantcolor.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part014_jp1_planereflect_01_maproom_baselab014_01.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part027_jp1_planereflect01_part027_jp1_reflection.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part004_n1_planereflection_part004_floor.bsmat",
	"maps/levels/c10_samus/s030_baselab/models/imats/part021_n1_planereflection_part021_floor.bsmat",
	"actors/props/powergenerator/models/imats/powergenerator_tubeemissive.bsmat",
	"maps/objects/chozobasetank01/imats/chozobasetank01_emisive.bsmat",
	"actors/characters/gooshocker/models/imats/gooshockerx_ball.bsmat",
	"actors/characters/gooshocker/models/imats/gooshockerx_body.bsmat",
	"actors/characters/gooplot/fx/imats/gooplottail_gooplottail.bsmat",
	"actors/characters/gooplot/models/imats/gooplot_material01.bsmat",
	"actors/characters/armadigger/models/imats/armadigger_material.bsmat",
	"actors/characters/autector/models/imats/autector_mp_opaque_01.bsmat",
	"actors/characters/autsniper/models/imats/autsniper_main.bsmat",
	"actors/weapons/nailongthorn/models/imats/nailongthorn_mp_opaque_01.bsmat",
	"actors/characters/autsharp/models/imats/autsharp_autsharp.bsmat",
	"actors/characters/nailong/models/imats/nailong_mp_opaque_01.bsmat",
	"actors/weapons/nailongthorn/fx/imats/destruction_material.bsmat",
	"actors/characters/slidle/models/imats/slidle_material.bsmat",
	"actors/characters/dredhed/models/imats/dredhed_shield.bsmat",
	"actors/characters/rodotuk/models/imats/rodotuk_rodotuk.bsmat",
	"actors/characters/sharpaw/models/imats/sharpaw_body.bsmat",
	"actors/characters/autsniper/models/imats/autsniper_wheel.bsmat",
	"actors/characters/autsniper/fx/models/imats/autlaser_burstshoot_mp_fxmeshmtl00_autshootborder.bsmat",
	"actors/characters/autsniper/fx/models/imats/autlaser_burstshoot_mp_fxmeshmtl00_autshootcharge.bsmat",
	"actors/characters/autsniper/fx/models/imats/autlaser_burst_mp_fxmeshmtl00_burstcharge.bsmat",
	"actors/characters/autsharp/fx/imats/spikesaura_spikesaura.bsmat",
	"actors/characters/autsniper/fx/models/imats/autlaser_charge_mp_fxmeshmtl00_charge.bsmat",
	"actors/characters/rodotuk/fx/imats/souls_vortex_auras.bsmat",
	"actors/characters/rodotuk/fx/imats/souls_vortex_cone.bsmat",
	"actors/characters/sakai/fx/imats/sakaiplasma_plasma_invert.bsmat",
	"actors/characters/sakai/fx/imats/sakaiplasma_displacement_sakai.bsmat",
	"actors/characters/rodotuk/fx/imats/souls_vortex_souls.bsmat",
	"actors/characters/autector/fx/imats/fakelight_fakelight.bsmat",
	"actors/characters/autector/fx/imats/fakelight_fakeglow.bsmat",
	"actors/characters/gooshocker/fx/imats/floor_rays_rays.bsmat",
	"actors/characters/autsniper/fx/models/imats/autlightningfx_mp_lightningmtl00_rays02.bsmat",
	"actors/characters/autsniper/fx/models/imats/autlightningfx_mp_lightningmtl00_rays03.bsmat",
	"actors/characters/autsniper/fx/models/imats/autlightningfx_mp_lightningmtl00_rays04.bsmat",
	"actors/characters/autsniper/fx/models/imats/autlightningfx_mp_lightningmtl00_rays.bsmat",
	"actors/characters/sakai/fx/imats/displacement_rays_displacementrays_sakai.bsmat",
	"actors/characters/gooshocker/fx/imats/goolightning_gooshocker.bsmat",
	"actors/characters/autsharp/fx/imats/spikesaura_spikesaurastatic.bsmat",
	"actors/characters/gooplot/fx/imats/gooplotsplash_gooplotsplash.bsmat",
	"actors/characters/autector/models/imats/autector_mp_blend_01.bsmat",
	"actors/props/ev_watervalve_hydrogiga/fx/imats/watervalveinit_material.bsmat",
	"actors/props/ev_watervalve_hydrogiga/fx/imats/watervalveloop_material.bsmat",
	"actors/props/ev_watervalve_hydrogiga/fx/imats/watervalveend_material.bsmat",
	"actors/characters/hydrogiga/models/imats/hydro_trans_mp_opaque_01.bsmat",
	"maps/fx/waterstream/imats/waterstream02_water.bsmat",
	"maps/fx/waterstream/imats/waterstream03_water.bsmat",
	"actors/characters/hydrogiga/models/imats/hydro_trans_pistil.bsmat",
	"actors/characters/hydrogiga/models/imats/hydro_trans_bodybg.bsmat",
	"actors/characters/hydrogiga/models/imats/hydro_trans_root.bsmat",
	"actors/characters/hydrogiga/models/imats/hydro_trans_body.bsmat",
	"maps/fx/underwaterfall/imats/underwaterfall_bubbles_material.bsmat",
	"maps/fx/underwaterfall/imats/underwaterfall_mist_material.bsmat",
	"maps/fx/spraypipe/fx/imats/spraypipe_00_material.bsmat",
	"actors/spawnpoints/spawnpointslidlemetallic/models/imats/spawnpointslidlemetallicwall_spawnpointslidlemetallic.bsmat",
	"actors/spawnpoints/spawnpointslidlemetallic/models/imats/spawnpointslidlemetallic_spawnpointslidlemetallic.bsmat",
	"actors/props/shootactivatorhidrogiga/models/imats/shootactivatorhidrogiga_mat02.bsmat",
	"actors/spawnpoints/spawnpointslidle/models/imats/spawnpointslidlewall_material.bsmat",
	"maps/fx/splash00/fx/imats/splashout_00_material.bsmat",
	"actors/props/ev_demolition_grapple/fx/imats/destruction_boxgrapple.bsmat",
	"actors/props/ev_demolition_grapple/models/imats/ev_demolition_grapple_material.bsmat",
	"maps/objects/lightenedkrill01_a/imats/lightenedkrill01_a_.bsmat",
	"maps/objects/lightenedkrill01_b/imats/lightenedkrill01_b_.bsmat",
	"maps/objects/lightenedkrill02_a/imats/lightenedkrill02_a_.bsmat",
	"actors/items/powerup_gravitysuit/models/imats/powerup_gravitysuit_grav.bsmat",
	"actors/props/aeiongd_statue/models/imats/aeiongd_statue_head.bsmat",
	"actors/props/ev_aquadrain_right/models/imats/ev_aquadrain_right_ev_aquadrain_right.bsmat",
	"actors/events/mapev_fishes01/models/imats/mapev_fishes_mp_opaque_01.bsmat",
	"actors/props/shootactivatorhidrogiga/models/imats/shootactivatorhidrogiga_mat01.bsmat",
	"actors/props/ev_aquadrain_left/models/imats/ev_aquadrain_left_ev_aquadrain_left.bsmat",
	"actors/props/ev_tbdrainboss/models/imats/ev_tbdrainboss_mat01.bsmat",
	"actors/props/aeiongd_statue/models/imats/aeiongd_statue_body.bsmat",
	"maps/objects/seaslug01_a/imats/seaslug01_a_map_01.bsmat",
	"maps/objects/seaslug01_b/imats/seaslug01_b_map_01.bsmat",
	"maps/objects/seaslug01_c/imats/seaslug01_c_map_01.bsmat",
	"actors/items/powerup_gravitysuit/models/imats/powerup_gravitysuit_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables00sg_casca078_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables01sg_casca079_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables02sg_casca081_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables03sg_casca082_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables16sg_casca080_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables17sg_casca083_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables00sg_casca078_mp_opaque_02.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables01sg_casca079_mp_opaque_02.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables02sg_casca081_mp_opaque_02.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables03sg_casca082_mp_opaque_02.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables16sg_casca080_mp_opaque_02.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables17sg_casca083_mp_opaque_02.bsmat",
	"actors/characters/omnithon/models/imats/omnithon_fins.bsmat",
	"actors/props/hydrogigacorpse/models/imats/hydrogigacorpse_tentacles.bsmat",
	"actors/events/mapev_lapa_01/models/imats/mapev_lapa_01_mp_opaque_01.bsmat",
	"actors/events/mapev_lapa_02/models/imats/mapev_lapa_02_mp_opaque_01.bsmat",
	"actors/events/mapev_lum_ell/models/imats/mapev_lum_ell_mp_opaque_01.bsmat",
	"actors/props/ev_tentacle_001/models/imats/tentaculos_muertos_posicion1_material.bsmat",
	"actors/props/ev_tentacle_002/models/imats/tentaculos_muertos_posicion2_material.bsmat",
	"actors/props/ev_tentacle_003/models/imats/tentaculos_muertos_posicion3_material.bsmat",
	"actors/props/ev_tentacle_004/models/imats/tentaculos_muertos_posicion4_material.bsmat",
	"actors/props/hydrogigacorpse/models/imats/hydrogigacorpse_deadroots.bsmat",
	"maps/objects/siluro01_a/imats/siluro01_a_.bsmat",
	"maps/objects/siluro01_d/imats/siluro01_d_.bsmat",
	"maps/objects/siluro01_e/imats/siluro01_e_.bsmat",
	"actors/props/hydrogigacorpse/models/imats/hydrogigacorpse_deadbody.bsmat",
	"actors/props/hydrogigacorpse/models/imats/hydrogigacorpse_deadhead.bsmat",
	"maps/fx/aquasparksunderwater/imats/aquasparks01_aquasparks.bsmat",
	"maps/fx/aquasparksunderwater/imats/aquasparks03_aquasparks.bsmat",
	"actors/props/fan_reg/models/imats/fan_reg_mat01.bsmat",
	"maps/fx/waterfallaqua/imats/waterfallaqua02_splash.bsmat",
	"maps/fx/waterfallaqua/imats/waterfallaqua03_splash.bsmat",
	"actors/characters/sakai/models/imats/sakai_material.bsmat",
	"maps/fx/waterfallaqua/imats/waterfallaqua02_mist.bsmat",
	"maps/fx/waterfallaqua/imats/waterfallaqua03_mist.bsmat",
	"maps/objects/fish01_a/imats/fish01_a_mp_opaque_01.bsmat",
	"maps/objects/fish01_b/imats/fish01_b_mp_opaque_01.bsmat",
	"maps/objects/fish01_c/imats/fish01_c_mp_opaque_01.bsmat",
	"maps/objects/fish01_d/imats/fish01_d_mp_opaque_01.bsmat",
	"maps/objects/fish01_e/imats/fish01_e_mp_opaque_01.bsmat",
	"maps/objects/fish01_f/imats/fish01_f_mp_opaque_01.bsmat",
	"maps/objects/fish01_m/imats/fish01_m_mp_opaque_01.bsmat",
	"maps/objects/fish01_n/imats/fish01_n_mp_opaque_01.bsmat",
	"maps/objects/fish01_o/imats/fish01_o_mp_opaque_01.bsmat",
	"actors/characters/omnithon/models/imats/omnithon_body.bsmat",
	"actors/props/zipline_bottom_hydrogiga/models/imats/zipline_bottom_hydrogiga_mat01.bsmat",
	"maps/genericimats/barnacledecal01_generic.bsmat",
	"maps/genericimats/mossdecal01_generic.bsmat",
	"maps/genericimats/mossdecal04_generic.bsmat",
	"actors/characters/hydrogiga/models/imats/hydrogiga_pistil.bsmat",
	"actors/props/spacejump_marker/models/imats/spacejump_marker_.bsmat",
	"actors/characters/hydrogiga/models/imats/hydrogiga_body.bsmat",
	"maps/objects/chozoaqsubmarine01/imats/chozoaqsubmarine01_mp_opaque_simple.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part016_jp7_mapmodel09_mp_opaque_41.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part022_e4_mapmodel05_mp_opaque_41.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part016_jp7_mapmodel12_pasarelas_aq_01.bsmat",
	"maps/objects/chozoassetconsole01/imats/chozoassetconsole01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallpathgen02x4/imats/chozoallpathgen02x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqcorridorroof02x1/imats/chozoaqcorridorroof02x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqcorridorroof02x4/imats/chozoaqcorridorroof02x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqatrezzodoorbg01/imats/chozoaqatrezzodoorbg01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqcorridorbg01x1/imats/chozoaqcorridorbg01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqcorridorbg01x4/imats/chozoaqcorridorbg01x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqcorridorbg02x4/imats/chozoaqcorridorbg02x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqcorridorbg02/imats/chozoaqcorridorbg02_mp_opaquemaps_simple.bsmat",
	"actors/props/ev_demolition_tunnel/models/imats/ev_demolition_tunnel_aqua_tunel_01.bsmat",
	"maps/objects/chozoaqbg01endl/imats/chozoaqbg01endl_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqbg01endr/imats/chozoaqbg01endr_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqbg01x1/imats/chozoaqbg01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqbg01x4/imats/chozoaqbg01x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqbg01x6/imats/chozoaqbg01x6_mp_opaquemaps_simple.bsmat",
	"actors/props/db_reg_aq_007/models/imats/db_reg_aq_007_mp_opaquemaps_simple_14.bsmat",
	"actors/props/ev_demolition_db_001/models/imats/ev_demolition_db_001_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/ev_demolition_db_002/models/imats/ev_demolition_db_002_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/ev_demolition_db_003/models/imats/ev_demolition_db_003_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_mp_opaquemaps_simple_dissolve_20.bsmat",
	"actors/props/db_reg_aq_002/models/imats/db_reg_aq_002_mp_opaquemaps_simple_dissolve_19.bsmat",
	"actors/props/db_reg_aq_004/models/imats/db_reg_aq_004_mp_opaquemaps_simple_dissolve_42.bsmat",
	"actors/props/db_reg_aq_008/models/imats/db_reg_aq_008_mp_opaquemaps_simple_dissolve_09.bsmat",
	"actors/props/db_reg_aq_009/models/imats/db_reg_aq_009_mp_opaquemaps_simple_dissolve_12.bsmat",
	"actors/props/db_reg_aq_010/models/imats/db_reg_aq_010_mp_opaquemaps_simple_dissolve_20.bsmat",
	"actors/props/db_reg_aq_011/models/imats/db_reg_aq_011_mp_opaquemaps_simple_dissolve_20.bsmat",
	"maps/fx/amoebaparticles00/imats/amoebaparticles00_underwater.bsmat",
	"actors/props/db_reg_aq_009/models/imats/db_reg_aq_009_mp_opaquemaps_simple_dissolve_09.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_mp_opaquemaps_simple_dissolve_06.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_mp_opaquemaps_simple_dissolve_08.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_mp_opaquemaps_simple_dissolve_18.bsmat",
	"actors/props/db_reg_aq_002/models/imats/db_reg_aq_002_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_aq_002/models/imats/db_reg_aq_002_mp_opaquemaps_simple_dissolve_06.bsmat",
	"actors/props/db_reg_aq_002/models/imats/db_reg_aq_002_mp_opaquemaps_simple_dissolve_08.bsmat",
	"actors/props/db_reg_aq_003/models/imats/db_reg_aq_003_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_aq_007/models/imats/db_reg_aq_007_mp_opaquemaps_simple_dissolve_06.bsmat",
	"actors/props/db_reg_aq_007/models/imats/db_reg_aq_007_mp_opaquemaps_simple_dissolve_08.bsmat",
	"actors/props/db_reg_aq_008/models/imats/db_reg_aq_008_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_aq_008/models/imats/db_reg_aq_008_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_aq_008/models/imats/db_reg_aq_008_mp_opaquemaps_simple_dissolve_04.bsmat",
	"actors/props/db_reg_aq_010/models/imats/db_reg_aq_010_mp_opaquemaps_simple_dissolve_08.bsmat",
	"actors/props/db_reg_aq_010/models/imats/db_reg_aq_010_mp_opaquemaps_simple_dissolve_09.bsmat",
	"actors/props/db_reg_aq_010/models/imats/db_reg_aq_010_mp_opaquemaps_simple_dissolve_18.bsmat",
	"actors/props/db_reg_aq_011/models/imats/db_reg_aq_011_mp_opaquemaps_simple_dissolve_08.bsmat",
	"actors/props/db_reg_aq_010/models/imats/db_reg_aq_010_mp_opaquemaps_simple_dissolve_10.bsmat",
	"actors/props/db_reg_aq_011/models/imats/db_reg_aq_011_mp_opaquemaps_simple_dissolve_10.bsmat",
	"actors/props/db_reg_aq_008/models/imats/db_reg_aq_008_mp_opaquemaps_simple_dissolve_06.bsmat",
	"actors/props/db_reg_aq_005/models/imats/db_reg_aq_005_mp_opaquemaps_simple_09.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part014_e2_cristalera00_cristalpiscina019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part016_jp7_mapmodel06_cristalpiscina016_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part019_jp9_mapmodel09_cristalpiscina019_jp1.bsmat",
	"actors/props/db_reg_aq_007/models/imats/db_reg_aq_007_mp_opaquemaps_simple_12.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part010_e3_mapmodel04_cristalpiscina019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel00_cristalpiscina015_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part022_e4_mapmodel05_cristalpiscina019_jp1.bsmat",
	"maps/objects/chozoaqcorridorbg02x4/imats/chozoaqcorridorbg02x4_cristalpiscina015_jp1.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_mp_opaquemaps_simple_10.bsmat",
	"actors/props/db_reg_aq_002/models/imats/db_reg_aq_002_mp_opaquemaps_simple_10.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_mapmodel03_mp_aqua_window_64.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_mp_opaquemaps_simple_11.bsmat",
	"actors/props/db_reg_aq_002/models/imats/db_reg_aq_002_mp_opaquemaps_simple_11.bsmat",
	"actors/props/db_reg_aq_007/models/imats/db_reg_aq_007_mp_opaquemaps_simple_13.bsmat",
	"actors/props/ev_demolition_db_002/models/imats/ev_demolition_db_002_cascamat01.bsmat",
	"actors/props/ev_demolition_db_003/models/imats/ev_demolition_db_003_cascamat01.bsmat",
	"actors/props/ev_demolition_db_001/models/imats/ev_demolition_db_001_cascamat01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part018_jp10_mar01_ocean.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part004_m6_mapmodel005_ocean.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part019_jp9_mapmodel06_ocean.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_mp_opaquemaps_simple_09.bsmat",
	"actors/props/db_reg_aq_002/models/imats/db_reg_aq_002_mp_opaquemaps_simple_09.bsmat",
	"maps/objects/chozoaqbg01x6/imats/chozoaqbg01x6_cristalpiscina019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_matte_01_ocean.bsmat",
	"actors/props/db_reg_aq_009/models/imats/db_reg_aq_009_cascamat01.bsmat",
	"maps/fx/waterfallaqua/imats/waterfallaqua02_shine.bsmat",
	"maps/fx/waterfallaqua/imats/waterfallaqua03_shine.bsmat",
	"actors/props/db_reg_aq_005/models/imats/db_reg_aq_005_mp_opaquemaps_simple_10.bsmat",
	"actors/props/pool_aquaboss_aq/models/imats/pool_aquaboss_aq_aquabossn.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_cascamat01.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_cascamat02.bsmat",
	"actors/props/db_reg_aq_001/models/imats/db_reg_aq_001_cascamat03.bsmat",
	"actors/props/db_reg_aq_003/models/imats/db_reg_aq_003_cascamat01.bsmat",
	"actors/props/db_reg_aq_005/models/imats/db_reg_aq_005_cascamat.bsmat",
	"actors/props/db_reg_aq_010/models/imats/db_reg_aq_010_cascamat01.bsmat",
	"actors/props/db_reg_aq_011/models/imats/db_reg_aq_011_cascamat01.bsmat",
	"actors/props/db_reg_aq_008/models/imats/db_reg_aq_008_cascamat.bsmat",
	"actors/props/db_reg_aq_010/models/imats/db_reg_aq_010_cascamat02.bsmat",
	"actors/props/db_reg_aq_011/models/imats/db_reg_aq_011_cascamat02.bsmat",
	"actors/props/db_reg_aq_002/models/imats/db_reg_aq_002_cascamat01.bsmat",
	"actors/props/db_reg_aq_004/models/imats/db_reg_aq_004_mp_opaquemaps_simple_dissolve_35.bsmat",
	"maps/objects/chozoallpipe02/imats/chozoallpipe02_mp_opaquemaps_simple.bsmat",
	"cutscenes/0031gravitysuiteobtention/fx/imats/gravity_groundenergy_gravity_groundenergy.bsmat",
	"cutscenes/0031gravitysuiteobtention/fx/imats/gravity_jumpingaura_gravity_jumpingaura.bsmat",
	"actors/props/ev_demolition_block/fx/imats/waterwave_waterwave.bsmat",
	"actors/props/ev_demolition_block/fx/imats/waterwave_velocity.bsmat",
	"cutscenes/0031gravitysuiteobtention/fx/imats/gravity_trailsjump_gravity_trailsjump.bsmat",
	"maps/objects/chozoallbggenwall03x1/imats/chozoallbggenwall03x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallbggenwall03x1/imats/chozoallbggenwall03x1_mp_opaquemaps_simple_02.bsmat",
	"actors/props/db_reg_aq_004/models/imats/db_reg_aq_004_cascamat01.bsmat",
	"actors/characters/hydrogiga/models/imats/hydrogiga_roots.bsmat",
	"cutscenes/0063_hydrogiga-presentation/fx/imats/waterstream_waterstream.bsmat",
	"actors/props/box_magnet_aq_001/models/imats/box_magnet_aq_001_material.bsmat",
	"actors/characters/hydrogiga/models/imats/hydrogiga_bodybg.bsmat",
	"actors/characters/hydrogiga/models/imats/hydrogiga_root.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part020_jp6_mapmodel04_tentaculomalo.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables04sg_casca015_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables05sg_casca011_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables06sg_casca012_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables07sg_casca013_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables08sg_casca010_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables09sg_casca009_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables10sg_casca014_mp_opaquemaps_simple_14.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables15sg_casca008_mp_opaquemaps_simple_14.bsmat",
	"maps/objects/chozoaqdrain01/imats/chozoaqdrain01_chozoaqdrain_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part018_jp10_mapmodel_03_aquarocksalt03simple_jp1a.bsmat",
	"maps/objects/chozoaqatrezzofloorbg01/imats/chozoaqatrezzofloorbg01_mp_opaquemaps_simple_floor01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_sg_casca162_mp_opaquemaps_simple_49.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_sg_casca162_mp_opaquemaps_simple_50.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_sg_casca163_mp_opaquemaps_simple_49.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_sg_casca163_mp_opaquemaps_simple_50.bsmat",
	"maps/objects/chozoaqatrezzodoorbg01/imats/chozoaqatrezzodoorbg01_mp_opaquemaps_simple_floor.bsmat",
	"maps/objects/chozoaqatrezzodoorbg01/imats/chozoaqatrezzodoorbg01_mp_opaquemaps_simple_door01.bsmat",
	"maps/objects/chozoaqatrezzodoorbg01/imats/chozoaqatrezzodoorbg01_mp_opaquemaps_simple_door02.bsmat",
	"maps/objects/chozoaqatrezzodoorbg01/imats/chozoaqatrezzodoorbg01_mp_opaquemaps_simple_roof.bsmat",
	"maps/objects/chozoaqatrezzoroofbg01/imats/chozoaqatrezzoroofbg01_mp_opaquemaps_simple_roof.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part001_e6_mapmodel05_mp_opaquemaps_simple_39.bsmat",
	"maps/objects/aquarockwall02x3simple/imats/aquarockwall02x3simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarockwall03x3simple/imats/aquarockwall03x3simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarockwall04x3simple/imats/aquarockwall04x3simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarockwall05x3simple/imats/aquarockwall05x3simple_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/aquarockwall06x3simple/imats/aquarockwall06x3simple_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_sg_casca158_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_sg_casca159_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_sg_casca161_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part010_e3_mapmodel00_aquarockwall01x3simple.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part010_e3_mapmodel00_aquarockwall02x3simple.bsmat",
	"maps/objects/chozoaqbgcorridor01corner/imats/chozoaqbgcorridor01corner_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca43001_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca43002_mp_opaquemaps_simple_63.bsmat",
	"maps/objects/chozoallbgemmy01tur2/imats/chozoallbgemmy01tur2_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables14sg_casca018_mp_opaquemaps_simple_16.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables14sg_casca018_mp_opaquemaps_simple_17.bsmat",
	"maps/objects/chozoallpipesset01xcorner/imats/chozoallpipesset01xcorner_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgstructure01corner2/imats/chozobgstructure01corner2_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca050_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca051_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca052_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca057_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca058_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca059_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca060_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca061_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca062_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca063_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca066_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca067_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca068_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca069_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca070_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca071_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca072_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca073_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca074_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca150_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca151_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca152_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca153_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca154_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca155_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca156_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_sg_casca157_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_06_edificio2_mp_opaquemaps_simple_36.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_casca43000_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables15sg_casca008_mp_opaquemaps_simple_11.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_breakables15sg_casca008_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel05_mp_opaquemaps_simple_14.bsmat",
	"maps/objects/chozoaqbgcorridor01x1/imats/chozoaqbgcorridor01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoaqbgcorridor01x3/imats/chozoaqbgcorridor01x3_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoallbgemmy01bx4/imats/chozoallbgemmy01bx4_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part007_e6_bmapmodelb00_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel05_mp_opaquemaps_simple_12.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_sg_casca031_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_sg_casca032_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_sg_casca033_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_sg_casca034_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_sg_casca116_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_sg_casca118_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_sg_casca119_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_sg_casca120_mp_opaquemaps_simple_56.bsmat",
	"maps/objects/chozoaqbgcorridor02/imats/chozoaqbgcorridor02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgstructure01x4a/imats/chozobgstructure01x4a_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgstructure01x4b/imats/chozobgstructure01x4b_mp_opaquemaps_simple_01.bsmat",
	"actors/props/ev_demolition_debris/models/imats/ev_demolition_debris_aqua_tunel_03.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part010_e3_mapmodel00_aquarock02x4simple_jp1.bsmat",
	"maps/objects/chozobgstructure01x1/imats/chozobgstructure01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part007_e6_mapmodel13_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel05_mp_opaquemaps_simple_44.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part019_jp9_mapmodel10c_chozopathemmy02x4_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part022_e4_mapmodel04_mp_opaquemaps_simple_53.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part019_jp9_mapmodel02_chozoaqplatform01_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part023_e3_mapmodel00_mp_opaquemaps_simple_20.bsmat",
	"maps/objects/chozoaqplatform01blow/imats/chozoaqplatform01blow_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part001_e6_mapmodel03_mp_opaquemaps_simple_36.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part010_e3_mapmodel02_mp_opaquemaps_simple_34.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel05_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel05_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel05_mp_opaquemaps_simple_25.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part017_e2_mapmodel00_mp_opaquemaps_simple_84.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part022_e4_mapmodel04_mp_opaquemaps_simple_40.bsmat",
	"maps/objects/chozoaqplatform01low/imats/chozoaqplatform01low_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqcorridorpath01x1/imats/chozoaqcorridorpath01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqcorridorpath01x4/imats/chozoaqcorridorpath01x4_mp_opaquemaps_simple.bsmat",
	"maps/objects/savestationl/imats/savestationl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoaqplatform01b/imats/chozoaqplatform01b_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part020_jp6_mapmodel03_pasarelas_aq_01.bsmat",
	"maps/objects/chozoaqplatform01/imats/chozoaqplatform01_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_mm02_mp_opaquemaps_simple_36.bsmat",
	"maps/objects/chozoaqpath05x1/imats/chozoaqpath05x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoaqpath05x2/imats/chozoaqpath05x2_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoaqpath05x4/imats/chozoaqpath05x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathemmy01end/imats/chozopathemmy01end_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoaqdoor01a/imats/chozoaqdoor01a_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part018_jp10_mapmodel_03_aquanature01a_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part014_e2_cristalera00_mp_opaquemaps_simple_40.bsmat",
	"maps/objects/chozoaqpath01x1/imats/chozoaqpath01x1_mp_opaquemaps_simple_01.bsmat",
	"actors/props/ev_demolition_debris/models/imats/ev_demolition_debris_aqua_tunel_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part019_jp9_mapmodel09_chozoaqbg02endl_019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part010_e3_mapmodel04_chozoaqbg02endl_019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part022_e4_mapmodel05_mp_opaquemaps_simple_44.bsmat",
	"maps/objects/aquanature06b_01/imats/aquanature06b_01_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature06b_04/imats/aquanature06b_04_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature06b_05/imats/aquanature06b_05_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozoallasset03/imats/chozoallasset03_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part020_jp6_mapmodel00_algarojamalla.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part020_jp6_mapmodel01_algarojamalla.bsmat",
	"maps/objects/aquadigrock01/imats/aquadigrock01_mp_opaquemaps_simple.bsmat",
	"actors/events/mapev_coral01/models/imats/mapev_coral01_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature02a/imats/aquanature02a_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature02b/imats/aquanature02b_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature04b/imats/aquanature04b_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature04c/imats/aquanature04c_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature04d/imats/aquanature04d_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature04e/imats/aquanature04e_mp_opaquemaps_simple.bsmat",
	"maps/objects/aquanature05d/imats/aquanature05d_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel00_chozoaqbg02x3_jp1.bsmat",
	"maps/objects/chozoaqdoor01/imats/chozoaqdoor01_chozoaqdoor01.bsmat",
	"maps/genericimats/forestmoss02_generic.bsmat",
	"maps/genericimats/mudmatcave08_generic.bsmat",
	"cutscenes/0031gravitysuiteobtention/fx/imats/animfresnelnoise.bsmat",
	"maps/genericimats/sanddunes02_generic.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part016_jp7_mapmodel06_mp_opaquemaps_simple_60.bsmat",
	"actors/props/zipline_bottom_hydrogiga/models/imats/zipline_bottom_hydrogiga_hydra.bsmat",
	"maps/genericimats/skin04_generic.bsmat",
	"cutscenes/0031gravitysuiteobtention/fx/imats/gravity_groundrays_raysfeet.bsmat",
	"actors/characters/hydrogiga/fx/imats/lightning_mp_lightningmtl00.bsmat",
	"maps/genericimats/aquariver_01_generic.bsmat",
	"maps/genericimats/waterfallsanc02blue_generic.bsmat",
	"maps/objects/cloud00/imats/cloud00_mp_blendanimquads_00.bsmat",
	"actors/props/pool_aquaboss_aq/models/imats/pool_aquaboss_aq_watermask.bsmat",
	"actors/props/zipline_rail_hydrogiga/models/imats/zipline_rail_hydrogiga_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_mapmodel03_mp_opaquemaps_simple_60.bsmat",
	"maps/fx/waterfallaqua/imats/waterfallaqua02_material.bsmat",
	"maps/fx/waterfallaqua/imats/waterfallaqua03_material.bsmat",
	"maps/genericimats/chozomatmetalgreen09_generic.bsmat",
	"maps/genericimats/chozomatmetalblue10_generic.bsmat",
	"actors/props/ev_demolition_block/models/imats/ev_demolition_block_block.bsmat",
	"actors/items/powerup_gravitysuit/models/imats/powerup_gravitysuit_ball.bsmat",
	"maps/fx/waterdripping/imats/waterdripping_00_left_material.bsmat",
	"maps/fx/waterdripping/imats/waterdripping_00_material.bsmat",
	"maps/genericimats/rainwindowtrailmaps_generic.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lshaft_focos_jp_lshaft_03.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lshaft_focos_jp_lshaft_04.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lightshaft_01_aquatrench.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lightshaft_02_aquatrench.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lightshaft_03_aquatrench.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part018_jp10_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part013_jg9_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part010_e3_mapmodel03_jp_lshaft_06.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lshaft_jp_lshaft_00.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lshaft_jp_lshaft_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lshaft_jp_lshaft_02.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lshaft_jp_lshaft_03.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lshaft_jp_lshaft_04.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lshaft_jp_lshaft_06.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part018_jp10_lightshaft01_lights.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part004_m6_lshaft00_lights004jp.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_lightshaft01_lights.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_lshaftfoco_lights.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_mapmodel31_lights.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part0019_jp9_lshaft01_lights.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part004_m6_lshaft02_lights.bsmat",
	"maps/genericimats/glassblueaqua_generic.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel00_cristales_new_jp49.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_mapmodel08_mp_hologram_atlas_01.bsmat",
	"actors/events/mapev_coral01/models/imats/mapev_coral01_mp_vcolor.bsmat",
	"cutscenes/0063_hydrogiga-presentation/fx/imats/distortioncone_conedist.bsmat",
	"maps/genericimats/selfilumcyan02plants01_generic.bsmat",
	"maps/genericimats/selfilumcyan02plants02_generic.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part006_jp10_04_cristal2_mp_vtbackground_aqua_006.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part009_jp11_mapmodel03b_mp_vtbackground_aqua_009.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/handfresnel_sonar.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part014_e2_cristalera00_piscina019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part016_jp7_mapmodel06_piscina019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part019_jp9_mapmodel09_piscina019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part010_e3_mapmodel04_piscina019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part015_r4_mapmodel00_piscina015_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part022_e4_mapmodel05_piscina019_jp1.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part021_e11_mapmodel09_mp_blend_062.bsmat",
	"maps/fx/holograms/models/imats/holocyl_16_9_vfx1_holocyl_16_9.bsmat",
	"maps/fx/holograms/models/imats/holocyl_16_9_vfx2_holocyl_16_9.bsmat",
	"maps/objects/testrain01/imats/testrain01_mp_addblend_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part002_jp2_planereflect03_part002_jp2_reflection.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part011_jp2_planereflect03_part011_jp2_reflection.bsmat",
	"actors/props/zipline_rail_hydrogiga/models/imats/zipline_rail_hydrogiga_hydromagnet.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part012_jp1_planereflect_01_maproom_aqua014_01.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part008_n2_planereflection_part008_floor.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part024_n2_planereflection_part024_floor.bsmat",
	"maps/levels/c10_samus/s040_aqua/models/imats/part025_n2_planereflection_part025_floor.bsmat",
	"actors/props/ev_doorprof_open/models/imats/ev_doorprof_open_emisivo.bsmat",
	"actors/props/ev_doorprof/models/imats/ev_doorprof_emisivo.bsmat",
	"actors/props/ev_watervalve_hydrogiga/models/imats/fx_dc_quad.bsmat",
	"actors/characters/hydrogiga/fx/imats/braid_braid.bsmat",
	"actors/characters/hydrogiga/fx/imats/swirl_swirl.bsmat",
	"actors/characters/hydrogiga/fx/imats/polyp_material.bsmat",
	"actors/characters/batalloon/models/imats/batalloon_material.bsmat",
	"actors/characters/depthorn/models/imats/depthorn_depthorn.bsmat",
	"actors/characters/spittail/models/imats/spittail_spittail.bsmat",
	"actors/characters/slugger/models/imats/slugger_slugger.bsmat",
	"actors/characters/daivo/models/imats/daivo_mp_opaque_01.bsmat",
	"actors/weapons/spittailmagmaball/fx/imats/acidball_magma_tail.bsmat",
	"actors/weapons/spittailmagmaball/fx/imats/acidball_magma.bsmat",
	"actors/characters/daivoswarm/models/imats/daivoswarm.bsmat",
	"actors/characters/redenki/models/imats/redenki.bsmat",
	"actors/characters/sakai/fx/imats/lightningsakai_lightningsakai_variation.bsmat",
	"actors/characters/sakai/fx/imats/lightningsakai_sakailightning.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/explosion5meters_destructiondwn.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/explosion5meters_destructionup.bsmat",
	"actors/characters/chozorobotsoldier/models/imats/chozorobotsoldier_chozorbtdwn.bsmat",
	"actors/characters/chozorobotsoldier/models/imats/chozorobotsoldier_chozorbtturbines.bsmat",
	"actors/characters/chozorobotsoldier/models/imats/chozorobotsoldier_chozorbtup.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_charged_rings_01.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_charged_rings_02.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_charged_boder_01.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/ignition_border01.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/ignition_border02.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/ignition_core.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_boder_01.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_charged_center_02.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_charged_boder_02.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_charged_boder_03.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_charged_center.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_center.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_boder_03.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/uppercut_trail_uppercuttraillightning.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_charged_rays_02.bsmat",
	"actors/weapons/chozorobotsoldierbeam/fx/imats/projectile_charged_rays.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/dashend_trail_dashendtraillightning.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/uppercut_trail_uppercuttrail.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/dashend_trail_dashendtrail.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/uppercut_cone.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/chozo_chozoautoilum.bsmat",
	"actors/characters/chozorobotsoldier/fx/imats/surfaceanimfresnel.bsmat",
	"actors/characters/chozorobotsoldier/models/imats/chozorobotsoldier_chozoblade.bsmat",
	"actors/characters/emmyforest/models/imats/emmyforest_white_body.bsmat",
	"actors/characters/emmyforest/models/imats/emmyforest_white_head.bsmat",
	"maps/fx/resin/imats/material_resinhorizontal_vignette.bsmat",
	"maps/fx/resin/imats/material_resinhorizontal.bsmat",
	"maps/fx/resin/imats/material_resin.bsmat",
	"actors/props/doorgrappleclosed/models/imats/doorgrappleclosed_grapple01.bsmat",
	"actors/props/doorgrappleclosed/models/imats/doorgrappleclosed_grapple02.bsmat",
	"actors/characters/chozoprofessor_cut/models/imats/chozoprofessor_cut_feathers.bsmat",
	"actors/items/powerup_supermissile/models/imats/powerup_supermissile_mp_opaque_01.bsmat",
	"actors/events/mapev_planteater/models/imats/mapev_planteater_petalos.bsmat",
	"actors/events/mapev_planteater/models/imats/mapev_planteater_cuerpo.bsmat",
	"actors/events/mapev_planteater/models/imats/mapev_planteater_base.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part014_f8_mapmodel16_petalos.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part014_f8_mapmodel17_petalos.bsmat",
	"actors/props/aeionstatue/models/imats/aeionstatue_eyes.bsmat",
	"actors/props/aeionstatue/models/imats/aeionstatue_head.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part014_f8_mapmodel17_cuerpo.bsmat",
	"actors/props/doorgrappleclosed/models/imats/doorgrappleclosed_mat02.bsmat",
	"actors/characters/chozoprofessor_cut/models/imats/chozoprofessor_cut_mainbody.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part014_f8_mapmodel17_base.bsmat",
	"actors/events/mapev_plant002/models/imats/mapev_plant002.bsmat",
	"actors/events/mapev_plant001/models/imats/mapev_plant001_material.bsmat",
	"actors/events/mapev_plant003/models/imats/mapev_plant003_plant.bsmat",
	"actors/props/emmy_frozen/models/imats/emmy_frozen_black_eye.bsmat",
	"actors/props/emmy_frozen/models/imats/emmy_frozen_white_body.bsmat",
	"actors/props/emmy_frozen/models/imats/emmy_frozen_white_head.bsmat",
	"actors/characters/chozoprofessor/models/imats/chozoprofessor_camisa.bsmat",
	"actors/props/emmy_frozen/models/imats/emmy_frozen_black.bsmat",
	"maps/fx/waterfallforest/imats/waterfallforest02_splash.bsmat",
	"maps/fx/waterfallforest/imats/waterfallforest03_splash.bsmat",
	"maps/fx/waterfallforest/imats/waterfallforest02_mist.bsmat",
	"maps/fx/waterfallforest/imats/waterfallforest03_mist.bsmat",
	"actors/props/pf_mushr_fr/models/imats/pf_mushr_fr_material.bsmat",
	"actors/events/mapev_butterflygroup/models/imats/mapev_butterflygroup_body.bsmat",
	"actors/props/aeionstatue/models/imats/aeionstatue_body.bsmat",
	"actors/characters/autool_cut/models/imats/autool_cut_mp_opaque_01.bsmat",
	"actors/props/pf_mushr_fr_ice_cube/fx/imats/ice_explosion_explosion.bsmat",
	"actors/props/ice_cube/models/imats/ice_cube_large_material.bsmat",
	"actors/characters/chozoprofessor/models/imats/chozoprofessor_white_eyes.bsmat",
	"maps/objects/forestwallarenaboss01/imats/forestwallarenaboss01_mp_opaque_simple.bsmat",
	"maps/objects/forestwallarenaboss02/imats/forestwallarenaboss02_mp_opaque_simple.bsmat",
	"maps/objects/forestwallarenaboss03/imats/forestwallarenaboss03_mp_opaque_simple.bsmat",
	"maps/objects/forestwallarenaboss04/imats/forestwallarenaboss04_mp_opaque_simple.bsmat",
	"maps/objects/forestwallarenaboss05/imats/forestwallarenaboss05_mp_opaque_simple.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part012_x1_breakable_11_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part001_s2_mapmodel01_mp_opaque_17.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part012_f2_mapmodel07_mp_opaque_01.bsmat",
	"actors/props/doorgrappleclosed/models/imats/doorgrappleclosed_mat01.bsmat",
	"maps/objects/plantforestorganictree01/imats/plantforestorganictree01_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestorganictree02/imats/plantforestorganictree02_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestorganictree03/imats/plantforestorganictree03_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestorganictree04/imats/plantforestorganictree04_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestorganictree05/imats/plantforestorganictree05_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_06_mp_opaque_62.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_07_mp_opaque_62.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_10_mp_opaque_62.bsmat",
	"maps/objects/chozoforestpathwood01x2v2/imats/chozoforestpathwood01x2v2_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancplatform01x4/imats/chozosancplatform01x4_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008_r4_mapmodel06_mp_opaquemaps_simple31.bsmat",
	"maps/objects/chozosancfrieze02l/imats/chozosancfrieze02l_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancfrieze02r/imats/chozosancfrieze02r_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforesthongo01/imats/plantforesthongo01_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestminis03/imats/plantforestminis03_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestminis04/imats/plantforestminis04_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestminis05/imats/plantforestminis05_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestminis06/imats/plantforestminis06_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestminis07/imats/plantforestminis07_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobgmagmadoor01/imats/chozobgmagmadoor01_mp_opaquemaps_simple.bsmat",
	"maps/genericimats/waterforest01_generic.bsmat",
	"maps/fx/firefliesparticles/imats/firefliesparticles00_material.bsmat",
	"maps/fx/fliesparticles/imats/fliesparticles00_material.bsmat",
	"maps/genericimats/waterforestfront01_generic.bsmat",
	"maps/fx/sporesparticles00/imats/sporesparticles00.bsmat",
	"maps/fx/waterfallforest/imats/waterfallforest02_shine.bsmat",
	"maps/fx/waterfallforest/imats/waterfallforest03_shine.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/sphere_statue_secondary_trails.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/sphere_statue_trails.bsmat",
	"actors/characters/chozoprofessor/models/imats/chozoprofessor_overcoat.bsmat",
	"actors/characters/chozoprofessor/models/imats/chozoprofessor_strings.bsmat",
	"actors/items/powerup_doublejump/models/imats/powerup_doublejump_mp_opaque_01.bsmat",
	"actors/characters/chozoprofessor/models/imats/chozoprofessor_coat.bsmat",
	"actors/items/powerup_supermissile/models/imats/powerup_supermissile_hologram.bsmat",
	"actors/props/box_magnet_fr_001/models/imats/box_magnet_fr_001_material.bsmat",
	"actors/props/aeionstatue/models/imats/aeionstatue_tela.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/sphere_statue_base.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/sphere_statue_soft.bsmat",
	"actors/events/mapev_butterflygroup/models/imats/mapev_butterflygroup_wings.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_breakables09sg_casca64000_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_breakables10sg_casca64001_mp_opaquemaps_simple_46.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/sphere_statue_fresnel.bsmat",
	"maps/genericimats/glasssmoke_generic.bsmat",
	"maps/objects/chozoforestpathwood01x4v1/imats/chozoforestpathwood01x4v1_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part012_x1_breakable_00_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part012_x1_breakable_01_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part007_f5_casca67000_mp_opaquemaps_simple_49.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part007_f5_casca67001_mp_opaquemaps_simple_49.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part007_f5_casca69000_mp_opaquemaps_simple_49.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part007_f5_casca69001_mp_opaquemaps_simple_49.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part012_f2_mapmodel07_mp_opaquemaps_simple_24.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_sg_casca76000_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_sg_casca76001_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_sg_casca76002_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_sg_casca76003_mp_opaquemaps_simple_46.bsmat",
	"maps/objects/rockforestplatform01x1v1/imats/rockforestplatform01x1v1_mp_opaquemaps_simple.bsmat",
	"maps/objects/rockforestplatform01x1v2/imats/rockforestplatform01x1v2_mp_opaquemaps_simple.bsmat",
	"maps/objects/rockforestplatform01x1v3/imats/rockforestplatform01x1v3_mp_opaquemaps_simple.bsmat",
	"maps/objects/rockforestplatform01x4v1/imats/rockforestplatform01x4v1_mp_opaquemaps_simple.bsmat",
	"maps/objects/rockforestplatform01x4v2/imats/rockforestplatform01x4v2_mp_opaquemaps_simple.bsmat",
	"maps/objects/rockforestplatform01x4v3/imats/rockforestplatform01x4v3_mp_opaquemaps_simple.bsmat",
	"actors/characters/xparasite_cut/models/imats/xparasite_cut_body.bsmat",
	"maps/objects/chozopathnormalzone01x1cornera/imats/chozopathnormalzone01x1cornera_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathnormalzone01x1cornerb/imats/chozopathnormalzone01x1cornerb_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_sg_casca112_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_sg_casca113_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part005_f2_mapmodel006_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_mapmodel10_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_mapmodel06_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_mapmodel13_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part012_f2_mapmodel02_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/plantforestbranchbig01/imats/plantforestbranchbig01_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part018_pb7_mapmodel005_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozobgstructure01corner3/imats/chozobgstructure01corner3_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathnormalzone01x1/imats/chozopathnormalzone01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathnormalzone01x4/imats/chozopathnormalzone01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancplatform01endl/imats/chozosancplatform01endl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancplatform01endr/imats/chozosancplatform01endr_mp_opaquemaps_simple_01.bsmat",
	"actors/events/mapev_bird/models/imats/mapev_bird_bird.bsmat",
	"maps/objects/chozosancplatform01x1/imats/chozosancplatform01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_breakables00sg_casca054_mp_opaquemaps_simple_25.bsmat",
	"maps/objects/chozopathgeneric01endr/imats/chozopathgeneric01endr_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestchozostatue01l/imats/forestchozostatue01l_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestchozostatue01r/imats/forestchozostatue01r_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/plantforestroot09/imats/plantforestroot09_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestroot10/imats/plantforestroot10_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestroot11/imats/plantforestroot11_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_r9_sg_casca2133_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_r9_sg_casca2134_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_r9_sg_casca2135_mp_opaquemaps_simple_46.bsmat",
	"maps/objects/chozobgstructure01x4c/imats/chozobgstructure01x4c_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathgeneric01x1/imats/chozopathgeneric01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozopathgeneric01x4/imats/chozopathgeneric01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancwall01x1cornerout/imats/chozosancwall01x1cornerout_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_mapmodel08_mp_opaquemaps_simple_22.bsmat",
	"maps/objects/chozosanccolumn01x10left/imats/chozosanccolumn01x10left_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancwall01x1cornerin/imats/chozosancwall01x1cornerin_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancplatform01endr/imats/chozosancplatform01endr_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_02_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_02_mp_opaquemaps_simple_57.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_07_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_07_mp_opaquemaps_simple_57.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_07_mp_opaquemaps_simple_63.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_10_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_10_mp_opaquemaps_simple_57.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part009_x2_mapmodel_10_mp_opaquemaps_simple_63.bsmat",
	"maps/objects/magnetziplinesp01cornerout/imats/magnetziplinesp01cornerout_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_mapmodel20_mp_opaquemaps_simple_35.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008_x1_mapmodel10_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008_x1_mapmodel10_mp_opaquemaps_simple_24.bsmat",
	"maps/objects/chozosancplatform01x1/imats/chozosancplatform01x1_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozosancplatform01x4/imats/chozosancplatform01x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/magnetziplinesp01cornerin/imats/magnetziplinesp01cornerin_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoemmycolumn02x1/imats/chozoemmycolumn02x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancwall01x1b/imats/chozosancwall01x1b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestwallpath01/imats/forestwallpath01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancwall01x4/imats/chozosancwall01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/plantforestroot01/imats/plantforestroot01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/plantforestroot02/imats/plantforestroot02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/plantforestroot03/imats/plantforestroot03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/plantforestroot04/imats/plantforestroot04_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/plantforestroot05/imats/plantforestroot05_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/plantforestroot06/imats/plantforestroot06_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/plantforestroot07/imats/plantforestroot07_mp_opaquemaps_simple_1.bsmat",
	"maps/objects/plantforestroot08/imats/plantforestroot08_mp_opaquemaps_simple_1.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_mapmodel20_mp_opaquemaps_simple_31.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part006_f6_mapmodel02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestmushtree01/imats/forestmushtree01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestmushtree02/imats/forestmushtree02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestmushtree03/imats/forestmushtree03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestwallpath01v2/imats/forestwallpath01v2_mp_opaque_01.bsmat",
	"maps/objects/forestwallpath01v3/imats/forestwallpath01v3_mp_opaque_01.bsmat",
	"maps/objects/chozoforestbg01/imats/chozoforestbg01_mp_opaquemaps_simple.bsmat",
	"maps/objects/forestdigrock01/imats/forestdigrock01_mp_opaquemaps_simple.bsmat",
	"maps/objects/forestdigrock02/imats/forestdigrock02_mp_opaquemaps_simple.bsmat",
	"maps/objects/forestdigrock03/imats/forestdigrock03_mp_opaquemaps_simple.bsmat",
	"maps/genericimats/cavrockbackground08_generic.bsmat",
	"maps/genericimats/cavrockbackground19_generic.bsmat",
	"maps/genericimats/forestwaterplants01_generic.bsmat",
	"maps/genericimats/forestwaterplants02_generic.bsmat",
	"maps/objects/plantforestbigleaves02_a/imats/plantforestbigleaves02_a_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestbigleaves03_a/imats/plantforestbigleaves03_a_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestbigleaves04_a/imats/plantforestbigleaves04_a_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosanclamp01/imats/chozosanclamp01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosanclamp02/imats/chozosanclamp02_mp_opaquemaps_simple.bsmat",
	"maps/objects/maproom001r/imats/maproom001r_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/plantforestbigleaves01/imats/plantforestbigleaves01_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestbigleaves02/imats/plantforestbigleaves02_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestbigleaves03/imats/plantforestbigleaves03_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestbigleaves04/imats/plantforestbigleaves04_mp_opaquemaps_simple.bsmat",
	"maps/objects/forestflower/imats/forestflower_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestrock01/imats/forestrock01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestrock02/imats/forestrock02_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestrock03/imats/forestrock03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/forestrock04/imats/forestrock04_mp_opaquemaps_simple_01.bsmat",
	"maps/genericimats/forestplantscales_generic.bsmat",
	"maps/objects/chozomagpathchain01end/imats/chozomagpathchain01end_.bsmat",
	"maps/objects/chozomagpathchain02end/imats/chozomagpathchain02end_.bsmat",
	"maps/objects/rockforest01/imats/rockforest01_mp_opaquemaps_simple.bsmat",
	"maps/objects/rockforest02/imats/rockforest02_mp_opaquemaps_simple.bsmat",
	"maps/genericimats/forestgoundwet01_generic.bsmat",
	"maps/genericimats/forestgoundwet02_generic.bsmat",
	"maps/genericimats/foresttreeskin01_generic.bsmat",
	"maps/objects/chozomagpathchain01x1/imats/chozomagpathchain01x1_.bsmat",
	"maps/genericimats/forestmoss01_generic.bsmat",
	"maps/genericimats/forestmoss03_generic.bsmat",
	"maps/objects/plantforestblue01_a/imats/plantforestblue01_a_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestblue03_a/imats/plantforestblue03_a_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestblue01/imats/plantforestblue01_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestblue02/imats/plantforestblue02_mp_opaquemaps_simple.bsmat",
	"maps/objects/plantforestblue03/imats/plantforestblue03_mp_opaquemaps_simple.bsmat",
	"maps/genericimats/woodbark03_generic.bsmat",
	"maps/genericimats/woodbark04_generic.bsmat",
	"maps/genericimats/woodbark05_generic.bsmat",
	"maps/genericimats/woodbark07_generic.bsmat",
	"maps/genericimats/grassleaves04_generic.bsmat",
	"maps/genericimats/grassleaves05_generic.bsmat",
	"maps/genericimats/grass01_generic.bsmat",
	"maps/genericimats/skin09_generic.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008part009_pb5_lightshaft01_mattepaintingbasesanc009lightshaft.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part017_jp6_lightshaft01_mattepaintingforest019lightshaft.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_lightshaft01_mattepaintingforest019lightshaft.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_lightshaft01_mattepaintingforest019lightshaft.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_lightshaft03_mattepaintingforest019lightshaft.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_lightshaft05_mattepaintingforest019lightshaft.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_lightshaft01_mattepaintingforest019lightshaft.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_lightshaft02_mattepaintingforest019lightshaft.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_lightshaft04_mattepaintingforest019lightshaft.bsmat",
	"maps/fx/waterfallforest/imats/waterfallforest02_material.bsmat",
	"maps/fx/waterfallforest/imats/waterfallforest03_material.bsmat",
	"maps/objects/chozosancbg04/imats/chozosancbg04_mp_opaquemaps_simple_01.bsmat",
	"maps/genericimats/chozomatmetalgray12_generic.bsmat",
	"actors/props/cut_professorpanel/models/imats/cut_professorpanel_floatingpdisp.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part005_f2_lightshaft001_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part017_jp6_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part018_pb7_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part018_pb7_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part020_f3_lightshaft001_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part002_f2_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_lightshaft04_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_lightshaft06_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part006_f0_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part007_f5_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part007_f5_lightshaft02_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008_f4_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part010_f3_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part012_f2_lightshaft01_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part014_f8_mattepaint02_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_lightshaft03_aquatrench.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008_p_lshaft001_gateshaft.bsmat",
	"actors/props/cut_professorpanel/models/imats/cut_professorpanel_floatingpemmy.bsmat",
	"actors/props/cut_professorpanel/models/imats/cut_professorpanel_floatingp.bsmat",
	"actors/props/cut_professorpanel/models/imats/cut_professorpanel_base.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part017_jp6_mattepaint01_mattepaintingforest017background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part017_jp6_mattepaint01_mattepaintingforest019background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part017_jp6_mattepaint02_mattepaintingforest017background02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_mattepaint01_mattepaintingforest019background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_mattepaint02_mattepaintingforest019background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part005_f2_mattepaint00_mattepaintingforest005background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part007_f5_mattepaint00_mattepaintingforest019background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008part009_pb5_matte_01_mattepaintingsanctuary009rocks01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part020_f3_mattepaint00_mattepaintingforest019background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_mapmodel13_mattepaintingforest017background03.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008_f4_matte003_mattepaintingforest005background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part018_pb7_mattepaint001_mattepaintingforest019background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part010_f3_mattepaint00_mattepaintingforest019background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part014_f8_mattepaint00_mattepaintingforest014background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part014_f8_mattepaint01_mattepaintingforest014background02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part014_f8_mattepaint03_mattepaintingforest017background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_mapmodel13_mattepaintingforest014background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_mapmodel13_mattepaintingforest017background02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part003_e4_mapmodel13_mattepaintingforest019background02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part019_jp8_mattepaint02_mattepaintingforest019rocks01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_matte03_mattepaintingforest017background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_matte05_mattepaintingforest014background01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_matte_cinematic_mp_vtbackground_02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_matte04_mattepaintingforest019rocks01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part016_f8_matte01_mp_vtbackground_02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part017_jp6_mapmodel06_default.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part005_f2_mapmodel012_mat03.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008_f4_mapmodel14_mat03.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part020_f3_mapmodel05_mat03.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part005_f2_mapmodel012_mat02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part020_f3_mapmodel05_mat02.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part005_f2_mapmodel012_mat01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part007_f5_mapmodel06_mat01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part008_f4_mapmodel14_mat01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part020_f3_mapmodel05_mat01.bsmat",
	"actors/items/powerup_doublejump/models/imats/powerup_doublejump_mp_glass_01.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part021_jp1_reflection_part021_forest_jp1_reflection.bsmat",
	"cutscenes/0033sonarobtention/fx/imats/sphere_statue_purefresnel.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part013_jp1_planereflect_01_maproom_forest013_01.bsmat",
	"actors/props/cut_professorpanel/models/imats/cut_professorpanel_floatingpemmyeye.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part015_n2_planereflection_part015_floor.bsmat",
	"maps/levels/c10_samus/s050_forest/models/imats/part025_n2_planereflection_part025_floor.bsmat",
	"maps/objects/chozoallwagonrail01end/imats/chozoallwagonrail01end_mat01.bsmat",
	"actors/characters/scourge/models/imats/scourge_scourge.bsmat",
	"actors/characters/yampa/models/imats/yampa_body.bsmat",
	"actors/characters/chozowarriorx/models/imats/chozowarriorx_tentacles.bsmat",
	"actors/characters/chozowarrior/models/imats/chozowarrior_shield.bsmat",
	"actors/characters/chozowarrior/models/imats/chozowarrior_spear.bsmat",
	"actors/characters/chozowarriorx/models/imats/chozowarriorx_body.bsmat",
	"actors/characters/chozowarrior/models/imats/chozowarrior_eyes.bsmat",
	"actors/characters/chozowarriorx/models/imats/chozowarriorx_body_02.bsmat",
	"actors/characters/chozowarrior/models/imats/chozowarrior_body_02.bsmat",
	"actors/characters/chozowarrior/models/imats/chozowarrior_body.bsmat",
	"actors/characters/chozowarriorx/models/imats/chozowarriorx_tentaclesaux.bsmat",
	"actors/characters/specimen_x4a/models/imats/specimen_x4a_material.bsmat",
	"actors/characters/quetzoa/models/imats/quetzoa_body.bsmat",
	"actors/characters/fing/models/imats/fing.bsmat",
	"actors/weapons/quetzoaenergywave/fx/imats/floor_rays_rays.bsmat",
	"actors/characters/quetzoa/fx/imats/charge_rays_rays2.bsmat",
	"actors/characters/quetzoa/fx/imats/charge_rays_rays.bsmat",
	"actors/characters/superquetzoa/fx/imats/rays_wings_rays.bsmat",
	"actors/characters/superquetzoa/fx/imats/rays_body_rays.bsmat",
	"actors/characters/quetzoa/models/imats/quetzoa_wings.bsmat",
	"actors/characters/supergoliath/models/imats/supergoliath_supergoliathstone.bsmat",
	"actors/characters/supergoliath/models/imats/supergoliath_supergoliathbody.bsmat",
	"actors/characters/supergoliath/models/imats/supergoliath_fx01.bsmat",
	"actors/characters/supergoliath/models/imats/supergoliath_fx02.bsmat",
	"actors/characters/supergoliath/models/imats/supergoliath_fx03.bsmat",
	"actors/characters/supergoliath/models/imats/supergoliath_meat.bsmat",
	"actors/characters/core_x/models/imats/destroyer_destroyer.bsmat",
	"actors/characters/supergoliath/models/imats/supergoliath_rays.bsmat",
	"actors/characters/supergoliath/fx/imats/rays_rays.bsmat",
	"actors/characters/supergoliath/fx/imats/trail_mp_fxtrail.bsmat",
	"actors/characters/core_x/fx/imats/death_glow_core_x.bsmat",
	"actors/characters/core_x/models/imats/core_x_destroyerball.bsmat",
	"maps/fx/brownsmokes/fx/imats/brownsmoke01_material.bsmat",
	"maps/fx/labdryice/fx/imats/labdryicecorner00_left_material.bsmat",
	"actors/props/ev_gatesealed_aut_001/models/imats/ev_gatesealed_aut_001_doorsanctuary.bsmat",
	"actors/props/ev_gatesealed_aut_001/models/imats/ev_gatesealed_aut_001_doordecalls.bsmat",
	"actors/characters/chozozombiex_cut/models/imats/chozozombiex_cut_armor.bsmat",
	"actors/props/quarantine_bridge/models/imats/quarantine_bridge_mp_opaque_01.bsmat",
	"actors/props/ev_gatesealed/models/imats/ev_gatesealed_mat01.bsmat",
	"actors/props/ev_quarantine_roomlights/models/imats/ev_quarantine_roomlights_mat01.bsmat",
	"actors/props/ev_gatesealed_openned/models/imats/ev_gatesealed_openned_mat01.bsmat",
	"maps/genericimats/quarentinemuralastronomy_generic.bsmat",
	"actors/props/ev_gatesealed_closed/models/imats/ev_gatesealed_closed_mat01.bsmat",
	"actors/events/mapev_armor/models/imats/mapev_armor_mp_opaque_02.bsmat",
	"actors/events/mapev_armor/models/imats/mapev_armor_mp_opaque_01.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel06_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel11_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel23_mp_opaquemaps_simple.bsmat",
	"actors/items/powerup_plasmabeam/models/imats/powerup_plasmabeam_autoilum.bsmat",
	"maps/genericimats/quarantinedecal01_generic.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part005_n1_mapmodel24_mp_opaquealphatest_02.bsmat",
	"cutscenes/0013firstencounterchozozombie/fx/imats/mudtrail_mudhd.bsmat",
	"maps/genericimats/rustdecal04_generic.bsmat",
	"maps/objects/chozosancfullflag02/imats/chozosancfullflag02_flag2alpha.bsmat",
	"maps/objects/chozosancfullflag01/imats/chozosancfullflag01_flagalpha.bsmat",
	"maps/fx/fullflag03fx/fx/imats/fullflag03_flagalpha.bsmat",
	"maps/fx/fullflag02fx/fx/imats/fullflag02_flagalpha.bsmat",
	"maps/fx/fullflag01fx/fx/imats/fullflag01fx_flagalpha.bsmat",
	"actors/props/db_reg_qt_001/models/imats/db_reg_qt_001_mp_opaquemaps_simple_dissolve_01.bsmat",
	"maps/objects/chozosancflag01/imats/chozosancflag01_mp_blend_01.bsmat",
	"actors/events/mapev_bigdebrisqua01/models/imats/mapev_bigdebrisqua01_mp_opaquemaps_simple08.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel22_mp_opaquemaps_simple02.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel25_mp_opaquemaps_simple02.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part005_n1_mapmodel07_mp_opaquemaps_simple02.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part005_n1_mapmodel17_mp_opaquemaps_simple02.bsmat",
	"actors/events/mapev_bigdebrisqua01/models/imats/mapev_bigdebrisqua01_mp_opaquemaps_simple02.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel12c_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel08_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part004_n1_mapmodel03_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part004_n1_mapmodel06_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part005_n1_mapmodel27_mp_opaquemaps_simple.bsmat",
	"maps/genericimats/lshaftquarentinecave_generic.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part005_n1_mapmodel02_mp_opaquemaps_simple03.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel22_mp_opaquemaps_simple09.bsmat",
	"maps/genericimats/chozomatmetalyellow07_generic.bsmat",
	"maps/objects/statuegatesanctuary/imats/statuegatesanctuary_emisivo.bsmat",
	"actors/props/db_reg_qt_001/models/imats/db_reg_qt_001_mp_opaquemaps_simple_dissolve_05.bsmat",
	"actors/props/db_reg_qt_001/models/imats/db_reg_qt_001_mp_opaquemaps_simple_dissolve_07.bsmat",
	"actors/props/db_reg_qt_001/models/imats/db_reg_qt_001_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_qt_001/models/imats/db_reg_qt_001_mp_opaquemaps_simple_dissolve_04.bsmat",
	"actors/props/db_reg_qt_001/models/imats/db_reg_qt_001_mp_opaquemaps_simple_dissolve_06.bsmat",
	"actors/characters/chozozombiex_cut/models/imats/chozozombiex_cut_body.bsmat",
	"actors/props/ev_gatesealed_openned/models/imats/ev_gatesealed_openned_mat02.bsmat",
	"actors/props/ev_gatesealed_closed/models/imats/ev_gatesealed_closed_mat02.bsmat",
	"actors/props/db_reg_qt_001/models/imats/db_reg_qt_001_cascamat02.bsmat",
	"actors/props/db_reg_qt_001/models/imats/db_reg_qt_001_cascamat01.bsmat",
	"cutscenes/0113quarantinearrival/fx/imats/airpressure_waterstream.bsmat",
	"actors/items/powerup_plasmabeam/models/imats/powerup_plasmabeam_body.bsmat",
	"maps/objects/chozosancpillar01break/imats/chozosancpillar01break_mp_velvet.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel18_camera.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel18_base.bsmat",
	"maps/objects/chozosancfullflag02/imats/chozosancfullflag02_flag2.bsmat",
	"maps/objects/chozosancfullflag01/imats/chozosancfullflag01_flag.bsmat",
	"maps/fx/fullflag03fx/fx/imats/fullflag03_flag.bsmat",
	"maps/fx/fullflag02fx/fx/imats/fullflag02_flag.bsmat",
	"actors/props/camerasanc/models/imats/camerasanc_camera.bsmat",
	"maps/fx/fullflag01fx/fx/imats/fullflag01fx_flag.bsmat",
	"actors/props/camerasanc/models/imats/camerasanc_base.bsmat",
	"maps/objects/chozosancpillar01break/imats/chozosancpillar01break_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancwall01x1corneroutb/imats/chozosancwall01x1corneroutb_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagemmypath02x4/imats/chozomagemmypath02x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozomagemmypath02x4/imats/chozomagemmypath02x4_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozosanccolumn01x10right/imats/chozosanccolumn01x10right_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancwall01x1cornerinb/imats/chozosancwall01x1cornerinb_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosanccolumn01x5right/imats/chozosanccolumn01x5right_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosanccolumn02x2right/imats/chozosanccolumn02x2right_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozobase2statue01/imats/chozobase2statue01_mp_opaque_simple.bsmat",
	"maps/objects/chozosanccolumn08/imats/chozosanccolumn08_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancstatue01/imats/chozosancstatue01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancstatue02/imats/chozosancstatue02_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancwall01x4b/imats/chozosancwall01x4b_mp_opaquemaps_simple_01.bsmat",
	"maps/genericimats/chozomatmetalyellow08_generic.bsmat",
	"maps/objects/chozosancwall01x1/imats/chozosancwall01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancbgdoor/imats/chozosancbgdoor_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/statuegatesanctuary/imats/statuegatesanctuary_statuebody.bsmat",
	"actors/events/mapev_bigdebrisqua02/models/imats/mapev_bigdebrisqua02_mp_opaquemaps_simple09.bsmat",
	"maps/objects/chozosancpath01x4/imats/chozosancpath01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancpath02x1/imats/chozosancpath02x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancpilar/imats/chozosancpilar_mp_opaquemaps_simple_01.bsmat",
	"maps/genericimats/cavrockbackground14_generic.bsmat",
	"maps/objects/chozosanwall01x1/imats/chozosanwall01x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosanwall01x4/imats/chozosanwall01x4_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel06_columnaattrz1.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel06_columnaattrz2.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel22_columnaattrz1.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel22_columnaattrz2.bsmat",
	"actors/props/chozoastro/models/imats/chozoastro_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel14_path2.bsmat",
	"maps/fx/dustlight/imats/dustlight00_material.bsmat",
	"maps/fx/dustlight/imats/dustlight01_material.bsmat",
	"maps/genericimats/fabric04_generic.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_p_vignette_indoor.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part005_n1_mapmodel029_mapmodel.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel13_mapmodel.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_mapmodel14_mapmodel.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part005_n1_mapmodel14_mapmodel.bsmat",
	"actors/props/ev_gatesealed/models/imats/ev_gatesealed_gateshaft.bsmat",
	"maps/objects/chozosancbasestatue01/imats/chozosancbasestatue01_mp_opaquemaps_simple_01.bsmat",
	"maps/genericimats/chozomatmetalpurple01_generic.bsmat",
	"actors/items/powerup_plasmabeam/models/imats/powerup_plasmabeam_mp_glass_01.bsmat",
	"actors/props/ev_quarantine_roomlights/models/imats/ev_quarantine_roomlights_gateshaft2.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part003_n3_lshaft01_lights.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part004_n1_lshaft01_lights.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part004_n1_lshaft02_lights.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part004_n1_lshaft03_lights.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part005_n1_lshaft03_lights.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part001_p_lshaft02_lights.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_lshaft01_lights.bsmat",
	"actors/props/ev_gatesealed/models/imats/ev_gatesealed_gateshaft2.bsmat",
	"cutscenes/0067chozowarriorxpresentation/fx/imats/chozopres_trail_chozowarriorpresentation.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_a3_matepaint_mattepaintingquarantinepart01background01.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel22_mattepaintingquarantinepart01rocks01.bsmat",
	"cutscenes/0004quarantinedoorsopen/fx/imats/kraid_camera_color.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_a3_matepaint_mattepaintingquarantinepart01rocks01.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_a3_matepaint_mattepaintingquarantinepart01rocks02.bsmat",
	"maps/genericimats/selfilumred02_generic.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part005_n3_matepaint_mattepaintingquarentena.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel06_luzroja.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel10_luzroja.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel14_luzroja.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part01_n3_mapmodel23_luzroja.bsmat",
	"actors/props/ev_gatesealed/models/imats/ev_gatesealed_mat02.bsmat",
	"actors/props/ev_quarantine_roomlights/models/imats/ev_quarantine_roomlights_mat02.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part004_n1_planereflection_part004_floorq.bsmat",
	"maps/levels/c10_samus/s060_quarantine/models/imats/part001_n3_planereflection_part001_floor.bsmat",
	"actors/characters/emmysanc/models/imats/emmysanc_white_body.bsmat",
	"maps/fx/waterstream/imats/waterstream04_water.bsmat",
	"actors/characters/emmysanc/models/imats/emmysanc_white_head.bsmat",
	"maps/fx/resin/imats/material_resin_vignette.bsmat",
	"actors/props/ev_ph2drain_activator/models/imats/ev_ph2drain_activator_ev_ph2drain_activator.bsmat",
	"maps/fx/labdryice/fx/imats/labdryice_vertical00_material.bsmat",
	"actors/props/muralbreakeable_cut40/models/imats/muralbreakeable_cut40_mp_opaque_01.bsmat",
	"actors/props/mural_cut40/models/imats/mural_cut40_mp_opaque_01.bsmat",
	"actors/props/ev_ph2drain_platform/models/imats/ev_ph2drain_platform_ev_aquadrain_right.bsmat",
	"actors/characters/chozoprofessor/models/imats/chozoprofessor_feathers.bsmat",
	"actors/props/professor_death/models/imats/professor_death_mp_opaque_01.bsmat",
	"maps/objects/chozoallbggenwall06joint/imats/chozoallbggenwall06joint_mp_opaquemaps_simple.bsmat",
	"actors/characters/chozoprofessor/models/imats/chozoprofessor_mainbody.bsmat",
	"maps/fx/waterstream/imats/waterstream04_fallingsplash.bsmat",
	"actors/items/powerup_spacejump/models/imats/powerup_spacejump_mat01.bsmat",
	"actors/characters/superquetzoa/models/imats/superquetzoa_superquetzoa.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_02_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_15_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_01_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_03_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_09_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_12_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_pb6_mapmodel008_flagalpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel01_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part008_r3_mapmodel01_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_mapmodel03_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_mapmodel07_flag2alpha.bsmat",
	"maps/objects/chozosancfullflagn02/imats/chozosancfullflagn02_flag2alpha.bsmat",
	"maps/genericimats/skin08_generic.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_mapmodel06_flag2alpha.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_mapmodel08_flag2alpha.bsmat",
	"maps/objects/chozosancfrieze01/imats/chozosancfrieze01_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_05_mp_opaquemaps_81.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_05_mp_opaquemaps_84.bsmat",
	"maps/objects/statuegatesanctuarylow/imats/statuegatesanctuarylow_emisivo.bsmat",
	"maps/genericimats/chozomatmetalyellow06_generic.bsmat",
	"actors/props/db_reg_b2_005/models/imats/db_reg_b2_005_mp_opaquemaps_simple_dissolve_23.bsmat",
	"actors/props/db_reg_b2_006/models/imats/db_reg_b2_006_mp_opaquemaps_simple_dissolve_06.bsmat",
	"actors/props/db_reg_b2_003/models/imats/db_reg_b2_003_mp_opaquemaps_simple_dissolve_56.bsmat",
	"actors/props/db_reg_b2_004/models/imats/db_reg_b2_004_mp_opaquemaps_simple_dissolve_56.bsmat",
	"actors/props/db_reg_b2_005/models/imats/db_reg_b2_005_mp_opaquemaps_simple_dissolve_24.bsmat",
	"actors/props/db_reg_b2_006/models/imats/db_reg_b2_006_mp_opaquemaps_simple_dissolve_07.bsmat",
	"actors/props/db_reg_b2_009/models/imats/db_reg_b2_009_mp_opaquemaps_simple_dissolve_05.bsmat",
	"actors/props/db_reg_b2_011/models/imats/db_reg_b2_011_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_b2_005/models/imats/db_reg_b2_005_mp_opaquemaps_simple_dissolve_04.bsmat",
	"actors/props/db_reg_b2_003/models/imats/db_reg_b2_003_mp_opaquemaps_simple_dissolve_25.bsmat",
	"actors/props/db_reg_b2_005/models/imats/db_reg_b2_005_mp_opaquemaps_simple_dissolve_05.bsmat",
	"actors/props/db_reg_b2_007/models/imats/db_reg_b2_007_mp_opaquemaps_simple_dissolve_02.bsmat",
	"actors/props/db_reg_b2_008/models/imats/db_reg_b2_008_mp_opaquemaps_simple_dissolve_02.bsmat",
	"actors/props/db_reg_b2_010/models/imats/db_reg_b2_010_mp_opaquemaps_simple_dissolve_04.bsmat",
	"actors/props/db_reg_b2_001/models/imats/db_reg_b2_001_mp_opaquemaps_simple_57.bsmat",
	"actors/props/db_reg_b2_003/models/imats/db_reg_b2_003_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_b2_003/models/imats/db_reg_b2_003_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_b2_003/models/imats/db_reg_b2_003_mp_opaquemaps_simple_dissolve_15.bsmat",
	"actors/props/db_reg_b2_004/models/imats/db_reg_b2_004_mp_opaquemaps_simple_dissolve_01.bsmat",
	"actors/props/db_reg_b2_004/models/imats/db_reg_b2_004_mp_opaquemaps_simple_dissolve_57.bsmat",
	"actors/props/db_reg_b2_001/models/imats/db_reg_b2_001_mp_opaquemaps_simple_54.bsmat",
	"actors/props/db_reg_b2_004/models/imats/db_reg_b2_004_mp_opaquemaps_simple_dissolve_58.bsmat",
	"actors/props/db_reg_b2_003/models/imats/db_reg_b2_003_mp_opaquemaps_simple_dissolve_54.bsmat",
	"actors/props/db_reg_b2_003/models/imats/db_reg_b2_003_cascamat02.bsmat",
	"actors/props/db_reg_b2_001/models/imats/db_reg_b2_001_mp_opaquemaps_simple_55.bsmat",
	"actors/props/db_reg_b2_006/models/imats/db_reg_b2_006_mp_opaquemaps_simple_08.bsmat",
	"actors/props/db_reg_b2_006/models/imats/db_reg_b2_006_mp_opaquemaps_simple_09.bsmat",
	"actors/props/db_reg_b2_006/models/imats/db_reg_b2_006_mp_opaquemaps_simple_10.bsmat",
	"actors/props/db_reg_b2_009/models/imats/db_reg_b2_009_mp_opaquemaps_simple_01.bsmat",
	"actors/props/db_reg_b2_009/models/imats/db_reg_b2_009_mp_opaquemaps_simple_02.bsmat",
	"actors/props/db_reg_b2_010/models/imats/db_reg_b2_010_mp_opaquemaps_simple_01.bsmat",
	"actors/props/db_reg_b2_010/models/imats/db_reg_b2_010_mp_opaquemaps_simple_02.bsmat",
	"actors/props/db_reg_b2_011/models/imats/db_reg_b2_011_mp_opaquemaps_simple_01.bsmat",
	"actors/props/db_reg_b2_011/models/imats/db_reg_b2_011_mp_opaquemaps_simple_02.bsmat",
	"actors/props/db_reg_b2_004/models/imats/db_reg_b2_004_cascamat01.bsmat",
	"actors/props/db_reg_b2_004/models/imats/db_reg_b2_004_cascamat02.bsmat",
	"actors/props/db_reg_b2_006/models/imats/db_reg_b2_006_cascamat.bsmat",
	"actors/props/db_reg_b2_009/models/imats/db_reg_b2_009_cascamat.bsmat",
	"actors/props/db_reg_b2_010/models/imats/db_reg_b2_010_cascamat.bsmat",
	"actors/props/db_reg_b2_011/models/imats/db_reg_b2_011_cascamat.bsmat",
	"actors/props/db_reg_b2_003/models/imats/db_reg_b2_003_cascamat01.bsmat",
	"actors/props/db_reg_b2_010/models/imats/db_reg_b2_010_mp_opaquemaps_simple_dissolve_47.bsmat",
	"actors/props/db_reg_b2_007/models/imats/db_reg_b2_007_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_b2_008/models/imats/db_reg_b2_008_mp_opaquemaps_simple_dissolve_03.bsmat",
	"actors/props/db_reg_b2_010/models/imats/db_reg_b2_010_mp_opaquemaps_simple_dissolve_05.bsmat",
	"cutscenes/0040sancemmypresentation_part2b/fx/imats/fakelightshotbluebrigther_fakelight_shotbluebrighter.bsmat",
	"cutscenes/0040sancemmypresentation_part1/fx/imats/smokeshotmesh_smokeshotmesh.bsmat",
	"cutscenes/0040sancemmypresentation_part2b/fx/imats/fakelightshotblue_fakelight_shotblue.bsmat",
	"actors/props/db_reg_b2_007/models/imats/db_reg_b2_007_cascamat.bsmat",
	"actors/props/db_reg_b2_008/models/imats/db_reg_b2_008_cascamat.bsmat",
	"maps/objects/chozosancstatuebig02mirror/imats/chozosancstatuebig02mirror_mp_velvet.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_02_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_15_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_mapmodel06_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_mapmodel08_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_01_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_03_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_09_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_12_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_pb6_mapmodel008_flag.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel01_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel18_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part008_r3_mapmodel01_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_mapmodel03_flag2.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_mapmodel07_flag2.bsmat",
	"maps/objects/chozosancstatuebig01/imats/chozosancstatuebig01_mp_velvet.bsmat",
	"maps/objects/chozosancstatuebig02/imats/chozosancstatuebig02_mp_velvet.bsmat",
	"maps/objects/chozosancfullflagn02/imats/chozosancfullflagn02_flag2.bsmat",
	"maps/objects/chozosancstatue03/imats/chozosancstatue03_flag2.bsmat",
	"maps/objects/chozosancpillar01/imats/chozosancpillar01_mp_moss.bsmat",
	"actors/props/db_reg_b2_001/models/imats/db_reg_b2_001_mp_opaquemaps_simple_56.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel13_mp_opaquemaps_simple_11.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel20_mp_opaquemaps_simple_11.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_breakables00sg_casca021_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_breakables01sg_casca022_mp_opaquemaps_simple_20.bsmat",
	"maps/objects/chozosancstatuebig02mirror/imats/chozosancstatuebig02mirror_mp_opaquemaps_simple_1.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part008_r3_breakables00sg_casca139_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part008_r3_breakables01sg_casca140_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_mapmodel17_mp_opaquemaps_simple_44.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_12_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca05sg_casca098_mp_opaquemaps_simple_37.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca06sg_casca133_mp_opaquemaps_simple_37.bsmat",
	"maps/objects/chozosancbgwalljoint01b/imats/chozosancbgwalljoint01b_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozosancbgwalljoint01c/imats/chozosancbgwalljoint01c_mp_opaquemaps_simple_03.bsmat",
	"maps/objects/chozosancstatueshield/imats/chozosancstatueshield_mp_opaquemaps_simple_00.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_04_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_10_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_11_mp_opaquemaps_simple_32.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel13_mp_opaquemaps_simple_18.bsmat",
	"maps/objects/chozosancbgwalljoint01/imats/chozosancbgwalljoint01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancstatuenew03/imats/chozosancstatuenew03_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part007_o4_mapmodel02_mp_opaquemaps_simple_05.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_break00sg_casca123_mp_opaquemaps_simple_29.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca00sg_casca085_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca01sg_casca088_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca03sg_casca103_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca04sg_casca104_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca07sg_casca091_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca08sg_casca090_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca09sg_casca089_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca10sg_casca082_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca11sg_casca083_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_sg_casca12sg_casca084_mp_opaquemaps_simple_39.bsmat",
	"maps/objects/chozoemmytunnelbg01t2/imats/chozoemmytunnelbg01t2_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancstatuebig02/imats/chozosancstatuebig02_mp_opaquemaps_simple_1.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_12_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_02_mp_opaquemaps_simple_16.bsmat",
	"maps/objects/chozosancstatuebig01/imats/chozosancstatuebig01_mp_opaquemaps_simple.bsmat",
	"maps/objects/savestation001emmyl/imats/savestation001emmyl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/statuegatesanctuarylow/imats/statuegatesanctuarylow_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_07_mp_opaquemaps_simple_34.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_10_mp_opaquemaps_simple_31.bsmat",
	"maps/objects/chozosancpathfront01endr/imats/chozosancpathfront01endr_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozosancstatueshield/imats/chozosancstatueshield_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_12_mp_opaquemaps_simple_37.bsmat",
	"maps/objects/chozosanccolumn01x5left/imats/chozosanccolumn01x5left_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosanccolumn02corner/imats/chozosanccolumn02corner_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosanccolumn02x2left/imats/chozosanccolumn02x2left_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancpathfront04x1/imats/chozosancpathfront04x1_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_mapmodel01_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_mapmodel04_mp_opaquemaps_simple_45.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_mapmodel04_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_mapmodel05_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_mapmodel08_mp_opaquemaps_simple_45.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_mapmodel08_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_mapmodel09_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_mapmodel10_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_pb6_mapmodel007_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_pb6_mapmodel007_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_pb6_mapmodel017_part006statue.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_15_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_17_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_mapmodel04_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part002_x3_mapmodel_02_mp_opaquemaps_simple_21.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel04_mp_opaquemaps_simple_29.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel07_mp_opaquemaps_simple_15.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel09_mp_opaquemaps_simple_29.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel10_mp_opaquemaps_simple_29.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel11_mp_opaquemaps_simple_15.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel18_mp_opaquemaps_simple_15.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel18_mp_opaquemaps_simple_29.bsmat",
	"maps/objects/chozosancstatue03/imats/chozosancstatue03_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancstatue04/imats/chozosancstatue04_mp_opaquemaps_simple_04.bsmat",
	"maps/objects/chozosancstatue05/imats/chozosancstatue05_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancstatuel2/imats/chozosancstatuel2_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_05_mp_opaquemaps_simple078.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel03_mp_opaquemaps_simple_37.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel07_mp_opaquemaps_simple_37.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel11_mp_opaquemaps_simple_37.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel16_mp_opaquemaps_simple_37.bsmat",
	"maps/objects/chozosanccolumn02x1/imats/chozosanccolumn02x1_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancpathfront01endl/imats/chozosancpathfront01endl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancpathfront01endr/imats/chozosancpathfront01endr_mp_opaquemaps_simple_01.bsmat",
	"actors/props/ev_ph2drain_platform/models/imats/ev_ph2drain_platform_mp_opaque_02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part003_jg13_tapa01_mp_opaquemaps_simple_46.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_12_mp_opaquemaps_simple_36.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel10_mp_opaquemaps_simple_39.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mapmodel17_mp_opaquemaps_simple_39.bsmat",
	"maps/objects/chozosancpathfront01x1/imats/chozosancpathfront01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancpathfront01x4/imats/chozosancpathfront01x4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancpathfront02x1/imats/chozosancpathfront02x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancpathfront03x1/imats/chozosancpathfront03x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancpathfront04x1/imats/chozosancpathfront04x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancpillar01/imats/chozosancpillar01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancpath01endl/imats/chozosancpath01endl_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancpath01endr/imats/chozosancpath01endr_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancstatue/imats/chozosancstatue_mp_opaquemaps_simple_08.bsmat",
	"maps/objects/chozosancpath01x1/imats/chozosancpath01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancnest01/imats/chozosancnest01_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancnest02/imats/chozosancnest02_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancnest03/imats/chozosancnest03_mp_opaquemaps_simple.bsmat",
	"maps/objects/chozosancnest04/imats/chozosancnest04_mp_opaquemaps_simple.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part002_x3_mapmodel_13_piezapath.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_10c_pil.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part007_o4_mapmodel01_part007ice.bsmat",
	"cutscenes/0040sancemmypresentation_part1/fx/imats/metroidpulsetrails_metroidpulsetrails.bsmat",
	"cutscenes/0040sancemmypresentation_part1/fx/imats/dustslide_trail_dustslidetrail.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part002_x3_mapmodel_09b_sanccut.bsmat",
	"cutscenes/0040sancemmypresentation_part1/fx/imats/decalslide_decal_slide.bsmat",
	"maps/genericimats/skin05_generic.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaft01_mattepaintingsanctuary012lightshaft.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_lightshaft01_mattepaintingbasesanc009lightshaft.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_matte01_mattepaintingbasesanc009lightshaft.bsmat",
	"actors/weapons/emmywave/fx/imats/wavebeamimpact_cine.bsmat",
	"maps/genericimats/waterfallsanc01_generic.bsmat",
	"maps/objects/chozosancsidewall01x1cornerdown/imats/chozosancsidewall01x1cornerdown_mp_opaquemaps_simple_01.bsmat",
	"actors/characters/superquetzoa/models/imats/superquetzoa_wings.bsmat",
	"maps/objects/chozosancsidewall01x1cornerup/imats/chozosancsidewall01x1cornerup_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancsidewall05slice/imats/chozosancsidewall05slice_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancsidewall01x1/imats/chozosancsidewall01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozosancsidewall01x4/imats/chozosancsidewall01x4_mp_opaquemaps_simple_02.bsmat",
	"maps/genericimats/chozomatconcreteblack02_generic.bsmat",
	"maps/genericimats/chozomatmetalgreen08_generic.bsmat",
	"maps/genericimats/chozomatflatblack06_generic.bsmat",
	"maps/genericimats/chozomatmetalblue13_generic.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_pb6_mapmodel017_part006.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_10c_column.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_lightshaftinside01_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_lightshaftinside01_lightshaftindise02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaftinside01_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaftinside01_lightshaftindise02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaftinside02_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaftinside02_lightshaftindise02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaftinside03_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaftinside03_lightshaftindise02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaftinside04_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaftinside05_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_lightshaftinside05_lightshaftindise02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_lightshaftinside01_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_lightshaftinside01_lightshaftindise02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part007_o4_lightshaftinside01_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_lightshaftinside01_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_lightshaftinside01_lightshaftindise02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_lightshaftinside01_lightshaftindise03.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_lightshaftinside01_lightshaftindise04.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_lightshaft01_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_p_lshaft_lightshaftindise01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_p_lshaft_lightshaftindise02.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_p_lshaft_lightshaftindise03.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part008_r3_lshaft01_shaftexterior.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part008_r3_lshaft01_shaftinterior.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_o6_lshaft01_shaftexterior.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_o6_lshaft01_shaftinterior.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_o6_lshaft02_shaftexterior.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_o6_lshaft03_shaftexterior.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_o6_lshaft03_shaftinterior.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_p_lightshaft01_part006li.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_p_lshaft001_gateshaft.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_o5_lshaft01_lights.bsmat",
	"maps/objects/chozosanclamp03/imats/chozosanclamp03_lights.bsmat",
	"actors/props/cut_professorpanelagua/models/imats/cut_professorpanelagua_base.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mattepaintclouds01_mattepaintingbaselab003smoke01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mattepaintclouds01_mattepaintingbaselab003smoke01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_mattepaintclouds02_mattepaintingbaselab003smoke01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mattepaintclouds01_mattepaintingbaselab003smoke01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_matte_02_mattepaintingsanctuary012background01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_matte01_mattepaintingsanctuary012background01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_pb6_matte01_mattepaintingsanctuary004background01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_matte_02_mattepaintingsanctuary012background01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_matte02_mattepaintingsanctuary012background01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_matte01_mattepaintingsanctuary004background01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part007_o4_matte00_mattepaintingsanctuary007background01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_matte_01_mattepaintingsanctuary004rocks01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_matte_01_mattepaintingsanctuary012rocks01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part001_pb3_matte01_mattepaintingsanctuary012rocks01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_pb6_matte02_mattepaintingsanctuary004rocks01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part010_r6_matte_01_mattepaintingsanctuary012rocks01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part012_e11_matte01_mattepaintingsanctuary012rocks01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_matte02_mattepaintingsanctuary004rocks01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part007_o4_matte00_mattepaintingsanctuary007rocks01.bsmat",
	"actors/props/fedship_hol/models/imats/fedship_hol_holograma.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_02_mp_selfilum_fw.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_09_mp_selfilum_fw.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_17_mp_selfilum_fw.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part004_s5_mapmodel_10_mp_selfilum_fw.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part009_pb5_mapmodel_10_lightbluesanc.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part008_r3_mapmodel01_mp_selfilum_fw.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part011_jp1_planereflect01_part011_sanc_jp1_reflection.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part005_jp1_planereflect_01_maproom_sanc005_01.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part006_pb6_planereflection_part006_floorsanc.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part013_n2_planereflection_part024_floor.bsmat",
	"maps/levels/c10_samus/s070_basesanc/models/imats/part014_n2_planereflection_part014_floor.bsmat",
	"actors/characters/groundshocker/models/imats/groundshocker_mat01.bsmat",
	"actors/characters/quetshocker/models/imats/quetshocker_body.bsmat",
	"actors/characters/sabotoru/models/imats/sabotoru_mp_opaque_02.bsmat",
	"actors/characters/sabotoru/models/imats/sabotoru_mp_opaque_01.bsmat",
	"actors/characters/groundshocker/models/imats/groundshocker_rayshead.bsmat",
	"actors/characters/groundshocker/fx/imats/rayscenter_rays03.bsmat",
	"actors/characters/groundshocker/fx/imats/raysground_rays01.bsmat",
	"actors/characters/groundshocker/fx/imats/raysup_rays02.bsmat",
	"actors/characters/quetshocker/models/imats/quetshocker_wings.bsmat",
	"actors/characters/yojimbee/models/imats/yojimbee.bsmat",
	"actors/characters/blindfly/models/imats/blindfly_material.bsmat",
	"actors/characters/emmy/fx/imats/conepatrolsearch_sanc_material.bsmat",
	"actors/characters/emmysanc/fx/imats/emmywave.bsmat",
	"actors/weapons/superquetzoavoidmissiles/fx/imats/void_projectile_innerfront.bsmat",
	"actors/weapons/superquetzoavoidmissiles/fx/imats/void_projectile_energy.bsmat",
	"actors/weapons/superquetzoaenergywave/fx/imats/floor_rays_rays2.bsmat",
	"actors/weapons/superquetzoaenergywave/fx/imats/floor_rays_rays.bsmat",
	"actors/characters/superquetzoa/fx/imats/charge_rays_rays2.bsmat",
	"actors/characters/superquetzoa/fx/imats/charge_rays_rays.bsmat",
	"actors/weapons/superquetzoavoidmissiles/fx/imats/void_projectile_innervoid.bsmat",
	"actors/props/emmy_shipyard/models/imats/emmy_shipyard_white_body.bsmat",
	"actors/props/emmy_shipyard/models/imats/emmy_shipyard_white_head.bsmat",
	"actors/characters/emmyshipyard/models/imats/emmyshipyard_white_body.bsmat",
	"actors/props/emmy_shipyard/models/imats/emmy_shipyard_black_eye.bsmat",
	"actors/props/emmy_shipyard/models/imats/emmy_shipyard_black.bsmat",
	"actors/characters/emmyshipyard/models/imats/emmyshipyard_white_head.bsmat",
	"actors/props/planetzdr/models/imats/planetzdr_planet_end.bsmat",
	"cutscenes/0108shipyard/fx/imats/materia_x_commanderhead.bsmat",
	"cutscenes/0112endgame/fx/imats/materia_x_profesor.bsmat",
	"maps/fx/aquabubbles/imats/aquabubbles1_capsulebubbles02.bsmat",
	"maps/fx/aquabubbles/imats/aquabubbles_capsulebubbles02.bsmat",
	"actors/characters/chozowarriorelite/models/imats/chozowarriorelite_shield.bsmat",
	"actors/events/mapev_cwxencounter02_ship/fx/imats/shiprainsplash_material.bsmat",
	"actors/props/capsulelaunchershipyard/models/imats/capsulelaunchershipyard_material.bsmat",
	"cutscenes/0108shipyard/fx/imats/samus_splashenter_material.bsmat",
	"actors/characters/chozowarriorelite/models/imats/chozowarriorelite_spear.bsmat",
	"actors/props/capsulelaunchershipyard/models/imats/capsulelaunchershipyard_interior.bsmat",
	"actors/props/capsulelaunchershipyard/models/imats/capsulelaunchershipyard_capsula.bsmat",
	"cutscenes/0112endgame/fx/imats/rocks_planet_mat.bsmat",
	"actors/characters/chozocommander_facial/models/imats/chozocommander_face_nakedhead.bsmat",
	"actors/props/capsulelaunchershipyard/models/imats/capsulelaunchershipyard_materialaconst.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel25_door.bsmat",
	"actors/props/centralunitshipyard/models/imats/centralunitshipyard_emisivo.bsmat",
	"actors/props/centralunitshipyard/models/imats/centralunitshipyard_coraza.bsmat",
	"actors/props/block_hyperbeam/models/imats/block_hyperbeam_mp_opaque_01.bsmat",
	"actors/characters/chozowarriorelite/models/imats/chozowarriorelite_body_02.bsmat",
	"actors/characters/takumaku_cut/models/imats/takumaku_cut_takumaku.bsmat",
	"actors/characters/chozocommanderx/models/imats/chozocommanderx_feathers.bsmat",
	"actors/props/capsulelaunchershipyard/models/imats/capsulelaunchershipyard_materiala.bsmat",
	"actors/props/capsulelaunchershipyard/models/imats/capsulelaunchershipyard_materialb.bsmat",
	"actors/characters/chozowarriorelite/models/imats/chozowarriorelite_body.bsmat",
	"actors/props/samus_ship_s/models/imats/samus_ship_s_ship.bsmat",
	"actors/characters/chozocommander_facial/models/imats/chozocommander_face_white_eyes.bsmat",
	"maps/objects/chozoskybasecontroldesk01/imats/chozoskybasecontroldesk01_mp_opaque_01.bsmat",
	"actors/characters/chozocommanderx/models/imats/chozocommanderx_frontback.bsmat",
	"actors/characters/chozocommanderx/models/imats/chozocommanderx_bellydwn.bsmat",
	"actors/characters/chozocommanderx/models/imats/chozocommanderx_arms.bsmat",
	"actors/characters/chozocommanderx/models/imats/chozocommanderx_head.bsmat",
	"timelines/x_transformation/fx/imats/whirlwind_low_material.bsmat",
	"cutscenes/0112endgame/fx/imats/nebula_final_01_mat.bsmat",
	"cutscenes/0112endgame/fx/imats/nebula_final_02_mat.bsmat",
	"cutscenes/0112endgame/fx/imats/nebula_final_03_mat.bsmat",
	"actors/props/block_pbtube_002/fx/imats/cristal_fracture_cristalfracture.bsmat",
	"actors/props/capsulelaunchershipyard/fx/imats/sphere_shipyard_spheremat.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/centralunit_fresnel.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/melee_end.bsmat",
	"cutscenes/0112endgame/fx/imats/expanse_wave_01_expansivewave_mat.bsmat",
	"maps/objects/communicationroom3door/imats/communicationroom3door_mat_01.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/waves_fresnel.bsmat",
	"cutscenes/0112endgame/fx/imats/postpro_planet_mat.bsmat",
	"actors/props/block_pbtube_002/fx/imats/explosion_fracture.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/energy_absortion_absortion_big.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_bichos_armadigger_mp_opaquemaps_simple_02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_bichos_batalloon_mp_opaquemaps_simple_05.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/end_armmetroidnization_absortion.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/energy_absortion_lines_absortion.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel28_mp_opaquemaps_simple_37.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_bichos_depthorn_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_bichos_takumaku_mp_opaquemaps_simple_06.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_bichos_gooplot_mp_opaquemaps_simple_07.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_bichos_nailong_mp_opaquemaps_simple_08.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_bichos_klaida_mp_opaquemaps_simple_03.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_bichos_yampa_mp_opaquemaps_simple_04.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables10sg_casca089_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables05sg_casca111_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables09sg_casca087_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables10sg_casca089_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables11sg_casca130_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables12sg_casca129_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables13sg_casca127_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables15sg_casca128_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables30sg_casca066_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables70sg_casca131_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables73sg_casca077_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables74sg_casca088_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables77sg_casca085_mp_opaquemaps_simple_19.bsmat",
	"actors/characters/bigx_commanderx/models/imats/bigx_commanderx_body.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables01sg_casca132_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables06sg_casca135_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables07sg_casca133_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables08sg_casca134_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables11sg_casca130_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables12sg_casca129_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables13sg_casca127_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables14sg_casca126_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables15sg_casca128_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables70sg_casca131_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables71sg_casca137_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables72sg_casca136_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables32sg_casca068_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables34sg_casca071_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables36sg_casca073_mp_opaquemaps_simple_18.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables45sg_casca103_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables46sg_casca109_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables48sg_casca106_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables51sg_casca102_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables52sg_casca099_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables60sg_casca114_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables62sg_casca119_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables63sg_casca117_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables67sg_casca242_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables68sg_casca239_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca00_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca01_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca02_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca03_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca04_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca05_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca06_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca07_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca08_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca13_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca14_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_breakables00sg_casca15_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_mapmodel00_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_mapmodel01_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_mapmodel12_mp_opaquemaps_simple_30.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel01_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel02_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel10_mp_opaquemaps_simple_17.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part005_x2_mapmodel_14_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables29sg_casca067_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables30sg_casca066_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables31sg_casca069_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables32sg_casca068_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables33sg_casca070_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables34sg_casca071_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables35sg_casca072_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables36sg_casca073_mp_opaquemaps_simple_23.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel51_mp_opaquemaps_simple_20.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables02_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables03_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables04_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables75_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_breakables76_mp_opaquemaps_simple_19.bsmat",
	"maps/objects/chozobgstructure01corner1/imats/chozobgstructure01corner1_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part005_x2_mapmodel_15_mp_opaquemaps_simple_54.bsmat",
	"maps/objects/chozoskypathroofangle1/imats/chozoskypathroofangle1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskypathroofangle2/imats/chozoskypathroofangle2_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel01_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel07_mp_opaquemaps_simple_37.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel07_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel19_mp_opaquemaps_simple_37.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel19_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel27_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel30_mp_opaquemaps_simple_37.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel30_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel39_mp_opaquemaps_simple_37.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel39_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel01_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel02_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel10_mp_opaquemaps_simple_19.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel11_mp_opaquemaps_simple_19.bsmat",
	"maps/objects/chozoskypathroofcorner/imats/chozoskypathroofcorner_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskypathrooframp/imats/chozoskypathrooframp_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_breakables02_mp_opaquemaps_simple_25.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_mapmodel15_mp_opaquemaps_simple_02.bsmat",
	"maps/objects/chozoshiptunnel01x1/imats/chozoshiptunnel01x1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskypathroofend/imats/chozoskypathroofend_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part005_x2_mapmodel_14_metalemmybg01set03.bsmat",
	"maps/objects/chozoskypathroofx1/imats/chozoskypathroofx1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskypathroofx4/imats/chozoskypathroofx4_mp_opaquemaps_simple_01.bsmat",
	"actors/events/mapev_bridgeparts/models/imats/mapev_bridgeparts_mp_opaquemaps_simple_37.bsmat",
	"actors/events/mapev_bridgeparts/models/imats/mapev_bridgeparts_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel02_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel06_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel25_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel30_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel43_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_o4_mapmodel51_metalemmybg01set03.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_mapmodel03_mp_opaquemaps_simple_25.bsmat",
	"actors/props/block_pbtube_001/models/imats/block_pbtube_001_mp_opaquemaps_simple_37.bsmat",
	"actors/props/block_pbtube_001/models/imats/block_pbtube_001_mp_opaquemaps_simple_38.bsmat",
	"actors/props/block_pbtube_002/models/imats/block_pbtube_002_mp_opaquemaps_simple_37.bsmat",
	"actors/props/block_pbtube_002/models/imats/block_pbtube_002_mp_opaquemaps_simple_38.bsmat",
	"actors/props/block_pbtube_003/models/imats/block_pbtube_003_mp_opaquemaps_simple_37.bsmat",
	"actors/props/block_pbtube_003/models/imats/block_pbtube_003_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_capsule_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part005_x2_mapmodel_04_mp_opaquemaps_simple_55.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part005_x2_mapmodel_13_mp_opaquemaps_simple_57.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mapmodel03_mp_opaquemaps_simple_22.bsmat",
	"maps/objects/chozoshipcapsule/imats/chozoshipcapsule_mp_opaquemaps_simple_01.bsmat",
	"actors/props/cut_012_capsule/models/imats/cut_012_capsule_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_mapmodel08_mp_opaquemaps_simple_22.bsmat",
	"actors/props/block_cut43/models/imats/block_cut43_mp_opaquemaps_simple_53.bsmat",
	"actors/props/block_cut43/models/imats/block_cut43_mp_opaquemaps_simple_54.bsmat",
	"actors/props/ev_escape_3/models/imats/ev_escape_3_mp_opaquemaps_simple_38.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part001_o5_mapmodel03_mp_opaquemaps_simple_26.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel13_mp_opaquemaps_simple_26.bsmat",
	"maps/objects/chozoshipasset03/imats/chozoshipasset03_mp_opaquemaps_simple_02.bsmat",
	"actors/props/ev_escape_2_init/models/imats/ev_escape_2_init_mp_opaquemaps_simple_100.bsmat",
	"actors/props/ev_escape_2_end/models/imats/ev_escape_2_end_mp_opaquemaps_simple_100.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_px_skybasemodel07_chozoskypathx1_x_jp1.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_px_skybasemodel07_chozoskypathx4_x_jp1.bsmat",
	"maps/objects/shipyardship01_a/imats/shipyardship01_a_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/shipyardrock07/imats/shipyardrock07_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskypathramp/imats/chozoskypathramp_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskypathend/imats/chozoskypathend_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskypathx1/imats/chozoskypathx1_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskypathx4/imats/chozoskypathx4_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoshipcapsule/imats/chozoshipcapsule_glass.bsmat",
	"actors/props/cut_012_capsule/models/imats/cut_012_capsule_glass.bsmat",
	"actors/props/ev_escape_1/models/imats/ev_escape_1_metaltres.bsmat",
	"actors/props/ev_commanderx_rock01/models/imats/ev_commanderx_rock01_rock.bsmat",
	"actors/props/ev_escape_1/models/imats/ev_escape_1_metalcuatro.bsmat",
	"cutscenes/0012metroidnizationstrongreactionevent/fx/imats/melee_melee.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/melee_melee.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_mapmodel08_mp_opaquemaps_simple_21.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/rays_energy_absortion_secondary_rays.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/rays_secframe_secframe_rays.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/rays_energy_absortion_rays.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/voltaic_rays_voltaic_rays.bsmat",
	"actors/props/ev_escape_1/models/imats/ev_escape_1_metalcinco.bsmat",
	"cutscenes/0112endgame/fx/imats/rays_hand_rays_hand.bsmat",
	"actors/props/ev_escape_1/models/imats/ev_escape_1_metalseis.bsmat",
	"cutscenes/0112endgame/fx/imats/rays_ship_rayship.bsmat",
	"cutscenes/0108shipyard/fx/imats/rays_sky_rayssky.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/cu_rays_curays.bsmat",
	"maps/genericimats/chozomatconcretewhite01_generic.bsmat",
	"maps/objects/chozoaqwheeldevice01_a/imats/chozoaqwheeldevice01_a_wheel.bsmat",
	"maps/genericimats/chozomatplates01_generic.bsmat",
	"actors/props/capsulelaunchershipyard/models/imats/capsulelaunchershipyard_window.bsmat",
	"cutscenes/0043emmymetroidnization/fx/imats/spike_emissive_spikemssive.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o1_lshaft01_lights.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o1_lshaft02_lights.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o1_lshaft3_lights.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_o6_capsule_glass.bsmat",
	"actors/fx/escape_glass/fx/imats/escape_glass_glass.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_hideable00_mp_selfilumblink_fw.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mapmodel02_mp_selfilumblink_fw.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mapmodel03_mp_selfilumblink_fw.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mapmodel04_mp_selfilumblink_fw.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mapmodel05_mp_selfilumblink_fw.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mapmodel06_mp_selfilumblink_fw.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel09_mp_selfilumblink_fw.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mapmodel12_mp_selfilumblink_fw.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mattepaint01_mattepaintingshipyard007sky01_scroll00.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mattepaint01_mattepaintingshipyard007sky01_scroll04.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mattepaint01_mattepaintingshipyard007sky01_scroll05.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part001_o5_mattepaint01_mattepaintingshipyard007sky01_scroll00.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part001_o5_mattepaint01_mattepaintingshipyard007sky01_scroll01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part001_o5_mattepaint01_mattepaintingshipyard007sky01_scroll04.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint01_mattepaintingshipyard007sky01_scroll00.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint01_mattepaintingshipyard007sky01_scroll02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint01_mattepaintingshipyard007sky01_scroll03.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint02_mattepaintingshipyard007sky01_scroll00.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint02_mattepaintingshipyard007sky01_scroll01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint02_mattepaintingshipyard007sky01_scroll02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint02_mattepaintingshipyard007sky01_scroll03.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint02_mattepaintingshipyard007sky01_scroll04.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint02_mattepaintingshipyard007sky01_scroll05.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_s6_mattepaint01_mattepaintingshipyard007sky01_scroll00.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_s6_mattepaint01_mattepaintingshipyard007sky01_scroll01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_s6_mattepaint01_mattepaintingshipyard007sky01_scroll02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_s6_mattepaint01_mattepaintingshipyard007sky01_scroll03.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_s6_mattepaint01_mattepaintingshipyard007sky01_scroll04.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_s6_mattepaint01_mattepaintingshipyard007sky01_scroll05.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mattepaint02_mattepaintingshipyard006sky02.bsmat",
	"cutscenes/0071chozowarriorxelitepresentation/fx/imats/fronttrail_prep01_preptrail_front01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part001_o5_mattepaint01_mattepaintingshipyard006sky02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_s6_mattepaint02_mattepaintingshipyard006sky02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mattepaint01_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mattepaint01_mattepaintingshipyard006sky02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_hideable01_mattepaintingshipyard007sky01_scroll00.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_hideable01_mattepaintingshipyard007sky01_scroll01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_hideable01_mattepaintingshipyard007sky01_scroll02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_hideable01_mattepaintingshipyard007sky01_scroll03.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_hideable01_mattepaintingshipyard007sky01_scroll04.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_hideable01_mattepaintingshipyard007sky01_scroll05.bsmat",
	"cutscenes/0071chozowarriorxelitepresentation/fx/imats/backtrail_prep01_preptrail_front01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_mattepaint02_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part001_o5_mattepaint01_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint01_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint02_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part002_s6_mattepaint02_mattepaintingshipyard006sky02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_s6_mattepaint02_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mattepaint02_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mattepaint02_mattepaintingshipyard006sky02.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part006_e6_mattepaint03_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_hideable03_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part007_e11_hideable03_mattepaintingshipyard006sky02.bsmat",
	"maps/objects/magmaparticlesuniversal/imats/magmaparticlesuniversal.bsmat",
	"cutscenes/0112endgame/fx/imats/shipshiny_mat.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part004_px_skybasemodel06_skybase_matte02.bsmat",
	"actors/props/planetzdr_background_plane/models/imats/planetzdr_background_plane_background.bsmat",
	"cutscenes/0108shipyard/fx/imats/burn_sky_saturate.bsmat",
	"maps/objects/chozoshipcapsule/imats/chozoshipcapsule_glass2.bsmat",
	"actors/props/cut_012_capsule/models/imats/cut_012_capsule_glass2.bsmat",
	"maps/levels/c10_samus/s080_shipyard/models/imats/part003_jp1_reflection_part003_jp1_shipyard_reflection.bsmat",
	"cutscenes/0108shipyard/fx/imats/darkness_commander.bsmat",
	"actors/characters/chozowarriorxelite/models/imats/chozowarriorxelite_tentacles.bsmat",
	"actors/characters/chozowarriorelite/fx/imats/shieldbreak_material.bsmat",
	"actors/characters/chozowarriorxelite/models/imats/chozowarriorxelite_body.bsmat",
	"actors/characters/chozowarriorxelite/models/imats/chozowarriorxelite_body_02.bsmat",
	"actors/characters/chozowarriorxelite/models/imats/chozowarriorxelite_tentaclesaux.bsmat",
	"actors/characters/emmyshipyard/fx/imats/energy_absortion_energyemmy.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samushyperfacial_eyes.bsmat",
	"actors/props/cut_100_comandercap/models/imats/cut_100_comandercap_cap.bsmat",
	"actors/props/capsuleelevatorskybase/models/imats/capsuleelevatorskybase_materialaconst.bsmat",
	"cutscenes/0086commanderorbital/fx/imats/accesspoint01_mp_accesspoint.bsmat",
	"actors/props/capsuleelevatorskybase/models/imats/capsuleelevatorskybase_materiala.bsmat",
	"actors/props/capsuleelevatorskybase/models/imats/capsuleelevatorskybase_materialb.bsmat",
	"actors/props/commander_elevator/models/imats/commanderelevator_material.bsmat",
	"actors/props/wplatform_cm_elevator/models/imats/wplatform_cm_elevator.bsmat",
	"actors/props/capsuleelevatorskybase/models/imats/capsuleelevatorskybase_hatch.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samushyperfacial_hyperhelmet.bsmat",
	"actors/props/capsuleelevatorskybase/models/imats/capsuleelevatorskybase_interior.bsmat",
	"actors/props/capsuleelevatorskybase/models/imats/capsuleelevatorskybase_capsula.bsmat",
	"actors/characters/chozocommander_wing/models/imats/chozocommander_wing_r_wings.bsmat",
	"actors/props/capsule_commander/models/imats/capsule_commander_interior.bsmat",
	"actors/props/capsule_commander/models/imats/capsule_commander_capsula.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samushyperfacial_hypervisor.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samushyperfacial_face.bsmat",
	"actors/props/capsuleelevatorskybase/models/imats/capsuleelevatorskybase_stairs.bsmat",
	"actors/props/skybase/models/imats/skybase_skybase.bsmat",
	"actors/characters/chozocommander/fx/imats/ultimategrab_claw_end_seq1_claw_end.bsmat",
	"cutscenes/0101commanderlosehiswings/fx/imats/wavebeam_projectile_exterior_exterior_cap.bsmat",
	"cutscenes/100commandershowswings/fx/imats/explosion_wavebeam_exterior.bsmat",
	"cutscenes/0101commanderlosehiswings/fx/imats/explosion_game_fresnexplosion.bsmat",
	"actors/props/block_pbcolumn/fx/imats/fracture_cristal_fracture.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_base.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_cap.bsmat",
	"actors/props/block_pbcolumn/fx/imats/incandescent_incandescent.bsmat",
	"actors/props/capsuleelevatorskybase/fx/imats/capsule_sphere_spheremat.bsmat",
	"cutscenes/0101commanderlosehiswings/fx/imats/explosion_game_shine_wall.bsmat",
	"actors/weapons/wavebeam/fx/imats/explosion_fresnexplosion.bsmat",
	"cutscenes/100commandershowswings/fx/imats/explosion_wavebeam_long.bsmat",
	"actors/weapons/wavebeam/fx/imats/explosion_transparent.bsmat",
	"actors/weapons/wavebeam/fx/imats/explosion_inner_wall.bsmat",
	"actors/weapons/wavebeam/fx/imats/explosion_shine_wall.bsmat",
	"cutscenes/0101commanderlosehiswings/fx/imats/explosion_game_inner.bsmat",
	"cutscenes/0101commanderlosehiswings/fx/imats/explosion_game_shine.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_grunge.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_floor.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_core.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_wave.bsmat",
	"actors/weapons/wavebeam/fx/imats/explosion_inner.bsmat",
	"actors/weapons/wavebeam/fx/imats/explosion_shine.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/dissolveenergygauntlet_energydissolvegauntlet.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_energyabsorb_vertical.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_energyabsorb_small.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_energyabsorb_big.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_twist.bsmat",
	"cutscenes/100commandershowswings/fx/imats/explosion_wavebeam_shine_end.bsmat",
	"cutscenes/100commandershowswings/fx/imats/explosion_wavebeam_wind_end.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/energytosamus_helix_helix.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/skybasewind_wind.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/energytosamus_hand_energytobase.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/skybasetrails_trail.bsmat",
	"cutscenes/0101commanderlosehiswings/fx/imats/wavebeam_chargefume_fume.bsmat",
	"cutscenes/100commandershowswings/fx/imats/explosion_wavebeam_inner.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/dissolvedots_dissolvedots.bsmat",
	"actors/weapons/icemissile/fx/imats/muzzle_3d_muzzle_radial.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/energytosamus_energytobase.bsmat",
	"actors/weapons/icemissile/fx/imats/muzzle_3d_muzzle_main.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/energytobase_energytobase.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/skybasewind_fire.bsmat",
	"cutscenes/100commandershowswings/fx/imats/aura_charge_aura.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_mapmodel10_chozoskypathroofangle2_x_jp1.bsmat",
	"maps/objects/chozoskybasestatue01b/imats/chozoskybasestatue01b_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskybasestatue01/imats/chozoskybasestatue01_mp_opaquemaps_simple_01.bsmat",
	"maps/objects/chozoskybasestatue02/imats/chozoskybasestatue02_mp_opaquemaps_simple_01.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_mapmodel10_chozoskypathend_x_jp1.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_mapmodel10_chozoskypathx1_x_jp1.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_mapmodel10_chozoskypathx4_x_jp1.bsmat",
	"actors/props/shipyardrock01/models/imats/shipyardrock01_mp_opaquemaps_simple_03.bsmat",
	"actors/props/shipyardrock02/models/imats/shipyardrock02_mp_opaquemaps_simple_01.bsmat",
	"actors/props/shipyardrock03/models/imats/shipyardrock03_mp_opaquemaps_simple_02.bsmat",
	"actors/props/shipyardrock06/models/imats/shipyardrock06_mp_opaquemaps_simple_04.bsmat",
	"actors/props/shipyardrock07/models/imats/shipyardrock07_mp_opaquemaps_simple_01.bsmat",
	"actors/characters/chozocommander/fx/imats/ultimategrab_claw_seq1_claw.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/handragetrail_handragetrail.bsmat",
	"cutscenes/100commandershowswings/fx/imats/ghostdash_trail_gdashtrail.bsmat",
	"cutscenes/100commandershowswings/fx/imats/trails_feet_wind_jump.bsmat",
	"cutscenes/100commandershowswings/fx/imats/wind_wings_wind.bsmat",
	"cutscenes/100commandershowswings/fx/imats/windown_windown.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_handrays_disperse_fast.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_handrays_disperse_rays.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_raysabsorb_rays.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_floorrays_fast.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_floorrays_rays.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_footrays_fast.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_footrays_rays.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_handrays_fast.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/samus_handrays_rays.bsmat",
	"cutscenes/100commandershowswings/fx/imats/rays_fast_body_rays.bsmat",
	"cutscenes/100commandershowswings/fx/imats/rays_floor_rayslong.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/raystobase_fast.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/raystobase_rays.bsmat",
	"cutscenes/0108fallofskybase/fx/imats/wavebeamimpact_cine.bsmat",
	"maps/fx/skybasewindows/imats/skybase_windows_glow.bsmat",
	"maps/genericimats/chozomatflatblack05_generic.bsmat",
	"actors/props/capsuleelevatorskybase/models/imats/capsuleelevatorskybase_window.bsmat",
	"actors/props/capsule_commander/models/imats/capsule_commander_window.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_p0_lshaft02_lightsfinal2.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_p0_lshaft01_lightsfinal.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_lshaft02_lights01.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_lshaft03_lights01.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_lshaft04_lights01.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_p_lshaft01_lights01.bsmat",
	"maps/fx/skybasewindows/imats/skybase_windows_mp_glassenergyfield_mat.bsmat",
	"cutscenes/0086commanderorbital/fx/imats/roomdissolvevertical.bsmat",
	"cutscenes/0086commanderorbital/fx/imats/roomdissolve.bsmat",
	"cutscenes/0086commanderorbital/fx/imats/expansivewave.bsmat",
	"cutscenes/0086commanderorbital/fx/imats/bloomplane.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky005_hideable_skybase004_scroll00.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky005_hideable_skybase004_scroll01.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky005_hideable_skybase004_scroll02.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky005_hideable_skybase004_scroll03.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky005_hideable_skybase004_scroll04.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky004_skybase004_scroll00.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky004_skybase004_scroll01.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky004_skybase004_scroll02.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky004_skybase004_scroll03.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky004_skybase004_scroll04.bsmat",
	"actors/props/skybaseclouds_b/models/imats/skybaseclouds_b_mattepaintingshipyard007sky01_scroll00.bsmat",
	"actors/props/skybaseclouds_b/models/imats/skybaseclouds_b_mattepaintingshipyard007sky01_scroll01.bsmat",
	"actors/props/skybaseclouds_b/models/imats/skybaseclouds_b_mattepaintingshipyard007sky01_scroll02.bsmat",
	"actors/props/skybaseclouds_b/models/imats/skybaseclouds_b_mattepaintingshipyard007sky01_scroll03.bsmat",
	"actors/props/skybaseclouds_b/models/imats/skybaseclouds_b_mattepaintingshipyard007sky01_scroll04.bsmat",
	"actors/props/skybaseclouds_b/models/imats/skybaseclouds_b_mattepaintingshipyard007sky01_scroll05.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_mapmodel11_sky1_skybase004_scroll00.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_mapmodel11_sky1_skybase004_scroll01.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_mapmodel11_sky1_skybase004_scroll02.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_mapmodel11_sky1_skybase004_scroll03.bsmat",
	"actors/props/skybaseclouds_b/models/imats/skybaseclouds_b_mattepaintingshipyard006sky01.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky005_hideable_skybase004_map01.bsmat",
	"actors/props/block_pbcolumn/models/imats/block_pbcolumn_pbcolumn.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_mapmodel02_sky004_skybase004_map01.bsmat",
	"actors/props/skybaseclouds/models/imats/skybaseclouds_clouds.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part001_jp6_mapmodel11_sky1_skybase001_map02.bsmat",
	"actors/props/skybase/models/imats/skybase_clouds.bsmat",
	"actors/props/cut_86_fackeaccpoint/models/imats/cut_86_fackeaccpoint_crbg01.bsmat",
	"actors/characters/samus_facial/models/imats/cut_samushyperfacial_eyelash.bsmat",
	"actors/props/skybase/models/imats/skybase_background.bsmat",
	"actors/props/cut_86_fackeaccpoint/models/imats/cut_86_fackeaccpoint_crbg07.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_planereflect01_skybaseplanereflect01.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part004_jp5_planereflect02_skybaseplanereflect02.bsmat",
	"maps/levels/c10_samus/s090_skybase/models/imats/part002_n1_planereflection_part024_floor.bsmat",
	"actors/characters/chozocommander/fx/imats/plane_powerpulse_powerpulse.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_commander_counter_kistrike_end_claw_end.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_attack02_end_end.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_attack03_base_base.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_attack03_end_end.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_attack01_base_base.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_attack02_base_base.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_attack01_end_end.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_claw_seq1_end_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_back_fast_back_fast.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_claw_seq2_end_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_back_back_bot.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_energy_small.bsmat",
	"actors/characters/chozocommander/fx/imats/tricombo_01_end_claw_end.bsmat",
	"actors/characters/chozocommander/fx/imats/tricombo_02_end_claw_end.bsmat",
	"actors/characters/chozocommander/fx/imats/tricombo_03_end_claw_end.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_back_back.bsmat",
	"actors/characters/chozocommander/fx/imats/hyperspark_helix_trail_small.bsmat",
	"actors/characters/chozocommander/fx/imats/hyperspark_helix_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/hyperdash_trail_trail2.bsmat",
	"actors/characters/chozocommander/fx/imats/hyperdash_trail_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/zerolaser_cover.bsmat",
	"actors/characters/chozocommander/fx/imats/zerolaser_grunge.bsmat",
	"actors/characters/chozocommander/fx/imats/zerolaser_end_border.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_glow.bsmat",
	"actors/characters/chozocommander/fx/imats/air_charge_trail_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_floorsmoke_smoke.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_statue_bigimpact.bsmat",
	"actors/characters/chozocommander/fx/imats/beamburst_purple.bsmat",
	"actors/weapons/chozocommanderenergyshardsfragment/fx/imats/fragment_fragmentback.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_statue_impact.bsmat",
	"actors/weapons/chozocommanderenergyshardsfragment/fx/imats/fragment_fragmentsparks.bsmat",
	"actors/characters/chozocommander/fx/imats/zerolaser_border.bsmat",
	"actors/weapons/chozocommanderenergyshardsfragment/fx/imats/fragment_fragment.bsmat",
	"actors/characters/chozocommander/fx/imats/zerolaser_core.bsmat",
	"actors/characters/chozocommander/fx/imats/zerolaser_head.bsmat",
	"actors/characters/chozocommander/fx/imats/zerolaser_pink.bsmat",
	"actors/characters/chozocommander/fx/imats/beamburst_core.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_energy.bsmat",
	"actors/characters/chozocommander/fx/imats/hyperspark_cap_cap.bsmat",
	"actors/characters/chozocommander/fx/imats/zerolaser_exterior.bsmat",
	"actors/characters/chozocommander/fx/imats/zerolaser_orange.bsmat",
	"actors/weapons/chozocommanderenergyshardsfragment/fx/imats/fragment_fragmenttrail.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_charging_arc2.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_charging_arc.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_attack01_trail_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_attack02_trail_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_zerolaser_attack03_trail_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/air_charge_energy.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_commander_counter_kistrike_claw.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_claw_seq1_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_claw_seq2_trail.bsmat",
	"actors/characters/chozocommander/fx/imats/hyperdash_air_smoke.bsmat",
	"actors/characters/chozocommander/fx/imats/tricombo_01_claw.bsmat",
	"actors/characters/chozocommander/fx/imats/tricombo_02_claw.bsmat",
	"actors/characters/chozocommander/fx/imats/tricombo_03_claw.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_charging_rays_rays.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_warning_rays.bsmat",
	"actors/characters/chozocommander/fx/imats/aurascratch_rays.bsmat",
	"actors/weapons/chozocommanderenergyshardssphere/fx/imats/energyshards_init_trail01.bsmat",
	"actors/weapons/chozocommanderenergyshardssphere/fx/imats/energyshards_init_trail02.bsmat",
	"actors/weapons/chozocommanderenergyshardssphere/fx/imats/energyshards_init_trail03.bsmat",
	"maps/blocks/breakable_block_supermissile/imats/breakable_block_supermissile_mp_opaque_respawn.bsmat",
	"maps/blocks/breakable_block_screwattack/imats/breakable_block_screwattack_mp_opaque_respawn.bsmat",
	"maps/blocks/breakable_block_speedbuster/imats/breakable_block_speedbuster_mp_opaque_respawn.bsmat",
	"maps/blocks/breakable_block_missile/imats/breakable_block_missile_mp_opaque_respawn.bsmat",
	"maps/blocks/breakable_block_weight/imats/breakable_block_weight_mp_opaque_respawn.bsmat",
	"actors/characters/samus/fx/imats/samus_splashenter_material.bsmat",
	"maps/blocks/breakable_block_bomb/imats/breakable_block_bomb_mp_opaque_respawn.bsmat",
	"maps/blocks/breakable_block_powerbeam/imats/breakable_block_powerbeam_mp_opaque_respawn.bsmat",
	"actors/characters/samuszerolow/models/imats/samuszerolow_body.bsmat",
	"actors/characters/morphball/models/imats/morphballgravity_mp_opaque_03.bsmat",
	"actors/characters/morphball/models/imats/morphballpower_mp_opaque_01.bsmat",
	"actors/characters/morphball/models/imats/morphballvaria_material.bsmat",
	"actors/characters/samus/models/imats/samusgravity_gravityhandcine.bsmat",
	"actors/props/samus_deadsuit/models/imats/samus_deadsuit_deadsuit.bsmat",
	"actors/characters/samus/models/imats/samusgravity_gravitybody.bsmat",
	"actors/characters/samus/models/imats/samusgravity_gravityhead.bsmat",
	"timelines/x_transformation/fx/imats/splash_impact.bsmat",
	"actors/characters/samus/models/imats/samusgravity_sburst.bsmat",
	"actors/characters/samus/models/imats/samushyper_cannon.bsmat",
	"actors/characters/samus/models/imats/samuspower_sburst.bsmat",
	"actors/characters/samus/models/imats/samusvaria_sburst.bsmat",
	"actors/characters/samus/models/imats/samusgravity_cannon.bsmat",
	"actors/characters/samus/models/imats/samushyper_hyperbody.bsmat",
	"actors/characters/samus/models/imats/samushyper_hyperhead.bsmat",
	"actors/characters/samus/models/imats/samuspower_cannon.bsmat",
	"actors/characters/samus/models/imats/samusvaria_cannon.bsmat",
	"actors/characters/samus/models/imats/samusvaria_variabody.bsmat",
	"actors/characters/samus/models/imats/samusvaria_variahead.bsmat",
	"actors/characters/samus/models/imats/samusgravity_powerbody.bsmat",
	"actors/characters/samus/models/imats/samushyper_barrieraura.bsmat",
	"actors/characters/samus/models/imats/samushyper_powerbody.bsmat",
	"actors/characters/samus/models/imats/samuspower_powerbody.bsmat",
	"actors/characters/samus/models/imats/samuspower_powerhead.bsmat",
	"actors/characters/samus/models/imats/samusvaria_powerbody.bsmat",
	"actors/characters/samuszerolow/models/imats/samuszerolow_head.bsmat",
	"actors/characters/morphball/models/imats/morphballhyper_material.bsmat",
	"actors/characters/samus/models/imats/samusgravity_mlonmissile.bsmat",
	"actors/characters/samus/models/imats/samushyper_mlonmissile.bsmat",
	"actors/characters/samus/models/imats/samuspower_mlonmissile.bsmat",
	"actors/characters/samus/models/imats/samusvaria_mlonmissile.bsmat",
	"actors/weapons/powerbomb/models/imats/powerbomb_mat01.bsmat",
	"actors/characters/samus/models/imats/samusgravity_supermissile.bsmat",
	"actors/weapons/supermissile/models/imats/supermissile_mp_opaque_01.bsmat",
	"actors/characters/samus/models/imats/samushyper_supermissile.bsmat",
	"actors/characters/samus/models/imats/samuspower_supermissile.bsmat",
	"actors/characters/samus/models/imats/samusvaria_supermissile.bsmat",
	"actors/weapons/lockonmissile/models/imats/lockonmissile_mat01.bsmat",
	"actors/characters/samus/models/imats/samusgravity_icemissile.bsmat",
	"actors/weapons/icemissile/models/imats/icemissile_mp_opaque_01.bsmat",
	"actors/props/ice_cube/fx/imats/ice_explosion_explosion.bsmat",
	"actors/characters/samus/models/imats/samushyper_icemissile.bsmat",
	"actors/characters/samus/models/imats/samuspower_icemissile.bsmat",
	"actors/characters/samus/models/imats/samusvaria_icemissile.bsmat",
	"actors/weapons/linebomb/models/imats/bomb_mat01.bsmat",
	"timelines/x_transformation/fx/imats/liquishthing.bsmat",
	"actors/characters/samus/models/imats/samusgravity_fxmetroidglove00.bsmat",
	"actors/weapons/bomb/models/imats/bomb_mat01.bsmat",
	"actors/characters/samus/models/imats/samusgravity_missile.bsmat",
	"actors/characters/samus/models/imats/samushyper_fxmetroidglove00.bsmat",
	"actors/characters/samus/models/imats/samushyper_missile.bsmat",
	"actors/characters/samus/models/imats/samuspower_missile.bsmat",
	"actors/characters/samus/models/imats/samusvaria_missile.bsmat",
	"actors/characters/morphball/fx/imats/morphballicefracture_mp_morphballicefracture.bsmat",
	"actors/characters/samus/fx/imats/splash_lavaenter_material.bsmat",
	"actors/characters/samus/fx/imats/samusfallicefracture_mp_samusicefracture.bsmat",
	"actors/weapons/missile/models/imats/missile_mat01.bsmat",
	"actors/characters/samus/fx/imats/splash_lavaexit_material.bsmat",
	"actors/characters/samus/fx/imats/samusicefracture_mp_samusicefracture.bsmat",
	"actors/characters/chozowarriorx/fx/imats/mudfluid04fx_mudfluid04material.bsmat",
	"actors/characters/samus/fx/imats/frozenstate.bsmat",
	"timelines/x_transformation/fx/imats/whirlwind_out.bsmat",
	"timelines/x_transformation/fx/imats/whirlwind.bsmat",
	"actors/characters/chozocommander/fx/imats/ultimategrab_samus_counter_end_seq2_turn_counter_end.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_samus_counter_kistrike_end_counter_end.bsmat",
	"actors/characters/chozocommander/fx/imats/ultimategrab_samus_counter_end_seq1_counter_end.bsmat",
	"actors/characters/chozocommander/fx/imats/ultimategrab_samus_counter_end_seq2_counter_end.bsmat",
	"actors/weapons/specialrocket/models/imats/specialburst_rocketprojectile_mp_fxmeshmtl00_center.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeamcharged_projectile_mp_fxmeshmtl00_fire.bsmat",
	"actors/weapons/widebeam/models/imats/widebeamcharged_projectile_mp_fxmeshmtl00_fire.bsmat",
	"actors/weapons/specialrocket/models/imats/specialburst_rocketprojectile_mp_fxmeshmtl00_air.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_chargedprojectile_mp_fxmeshmtl00_border.bsmat",
	"actors/weapons/powerbeam/fx/imats/diffusion_explosion_game_fresnexplosion.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_chargedprojectile_mp_fxmeshmtl00_inner.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_chargedprojectile_projectile_particles.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeamcharged_projectile_mp_fxmeshmtl00_border.bsmat",
	"actors/weapons/widebeam/models/imats/widebeamcharged_projectile_mp_fxmeshmtl00_border.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_chargedprojectile_mp_fxmeshmtl00_fire.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_chargedprojectile_mp_fxmeshmtl00_tail.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeamcharged_projectile_mp_fxmeshmtl00_inner.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedprojectile_boder_int.bsmat",
	"actors/weapons/widebeam/models/imats/widebeamcharged_projectile_mp_fxmeshmtl00_inner.bsmat",
	"actors/characters/samus/models/imats/samusgravity_mp_fresnelmtl00_energy.bsmat",
	"actors/characters/samus/models/imats/samusgravity_mp_fresnelmtl00_lines2.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeam_waves_mp_fresnelmtl00_arcbig.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeamcharged_projectile_mp_fxmeshmtl00_tail.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedprojectile_tailgreen.bsmat",
	"actors/weapons/widebeam/models/imats/widebeamcharged_projectile_mp_fxmeshmtl00_tail.bsmat",
	"actors/weapons/powerbeam/fx/imats/diffusion_explosion_game_shine_wall.bsmat",
	"actors/characters/samus/models/imats/samuspower_mp_fresnelmtl00_energy.bsmat",
	"actors/characters/samus/models/imats/samuspower_mp_fresnelmtl00_lines2.bsmat",
	"actors/characters/samus/models/imats/samusvaria_mp_fresnelmtl00_energy.bsmat",
	"actors/characters/samus/models/imats/samusvaria_mp_fresnelmtl00_lines2.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedprojectile_03xray.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeam_waves_mp_fresnelmtl00_arc.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeam_waves_mp_fresnelmtl00_cannon_cover.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedprojectile_02xray.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_projectile_mp_fxmeshmtl00_border.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedprojectile_twist.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_projectile_mp_fxmeshmtl00_inner.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_projectile_projectile_particles.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_projectile_core.bsmat",
	"actors/characters/samus/fx/imats/hyperspark_helix_trail_small.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_burst.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_projectile_mp_fxmeshmtl00_fire.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_projectile_mp_fxmeshmtl00_tail.bsmat",
	"actors/weapons/powerbeam/fx/imats/diffusion_explosion_game_inner.bsmat",
	"actors/weapons/powerbeam/fx/imats/diffusion_explosion_game_shine.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_projectile_boder_int.bsmat",
	"actors/weapons/widebeam/models/imats/widebeam_projectile_mp_fresnelmtl00_border.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_long.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_cannoncover_cannon.bsmat",
	"actors/weapons/plasmabeam/fx/imats/auras_chargeprojectile_canon.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedball_cannon.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedprojectile_grunge.bsmat",
	"actors/weapons/widebeam/models/imats/widebeam_projectile_mp_fresnelmtl00_core.bsmat",
	"actors/weapons/widebeam/models/imats/widebeam_projectile_mp_fresnelmtl00_tail.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedball_smoke.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_projectile_03xray.bsmat",
	"actors/weapons/plasmabeam/fx/imats/explosion_game_transparent.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_chargefume_fume.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_projectile_02xray.bsmat",
	"actors/weapons/plasmabeam/fx/imats/explosion_game_shine_wall.bsmat",
	"actors/weapons/specialburst/fx/imats/spbcone_center.bsmat",
	"actors/weapons/wavebeam/fx/imats/explosion_game_shine_wall.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_projectile_twist.bsmat",
	"actors/characters/samus/fx/imats/cannon_smallcover_cover.bsmat",
	"actors/characters/samus/fx/imats/hyperspark_helix_trail.bsmat",
	"actors/weapons/hyperbeam/fx/imats/zerolaser_core_grunge.bsmat",
	"actors/weapons/specialburst/fx/imats/spbcone_small.bsmat",
	"cutscenes/0003firstcomunicationfakeadam/fx/imats/cannon_smallcover_cover.bsmat",
	"actors/characters/samus/models/imats/samusgravity_fxmetroidglove02.bsmat",
	"actors/weapons/specialrocket/fx/imats/cannon_sprcover_cover.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedprojectile_01xray.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedprojectile_center.bsmat",
	"actors/characters/samus/models/imats/samushyper_fxmetroidglove02.bsmat",
	"actors/weapons/icemissile/fx/imats/tail_ice_ashes.bsmat",
	"actors/weapons/missile/fx/imats/tail_fire_ashes.bsmat",
	"actors/weapons/missile/fx/imats/tail_fire_long.bsmat",
	"actors/weapons/supermissile/fx/imats/tail_fire_ashes.bsmat",
	"actors/weapons/supermissile/fx/imats/tail_fire_long.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_projectile_grunge.bsmat",
	"actors/weapons/hyperbeam/fx/imats/zerolaser_cover.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeam_projectile_boder_01.bsmat",
	"actors/weapons/specialburst/fx/imats/chargeenergy_center.bsmat",
	"actors/weapons/specialburst/fx/imats/chargeenergy_energy.bsmat",
	"actors/weapons/specialrocket/models/imats/specialburst_rocketprojectile_mp_fxmeshmtl00_core.bsmat",
	"actors/weapons/wavebeam/fx/imats/explosion_game_inner.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedprojectile_core.bsmat",
	"actors/weapons/specialrocket/models/imats/specialburst_rocketprojectile_mp_fxmeshmtl00_border.bsmat",
	"actors/characters/samus/fx/imats/absortion_parasite_hand_abs.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_base.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_cap.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_core.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_charge_ball_border.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_charge_ball_center.bsmat",
	"actors/weapons/specialburst/fx/imats/spbenergy_center.bsmat",
	"actors/weapons/specialburst/fx/imats/spbenergy_energy.bsmat",
	"actors/weapons/icemissile/fx/imats/tail_ice.bsmat",
	"actors/weapons/missile/fx/imats/tail_fire.bsmat",
	"actors/weapons/specialrocket/models/imats/specialburst_rocketprojectile_mp_fxmeshmtl00_capwaves.bsmat",
	"actors/weapons/supermissile/fx/imats/tail_fire.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_burst.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_charge_ball_core.bsmat",
	"actors/weapons/hyperbeam/fx/imats/zerolaser_end_border.bsmat",
	"actors/weapons/icemissile/fx/imats/tail_ice_long.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_projectile_01xray.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_projectile_center.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_core.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_burst_laser.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_projectile_core.bsmat",
	"actors/characters/morphball/fx/imats/grab_kraid_vel_shaft.bsmat",
	"actors/weapons/specialburst/fx/imats/spbcone_big.bsmat",
	"actors/characters/morphball/fx/imats/grab_kraid_vel_wind.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_charge_floor.bsmat",
	"actors/weapons/powerbomb/fx/imats/implosion_implosion.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_smallair.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_end_end.bsmat",
	"actors/characters/samus/fx/imats/speedbooster_cover_energy.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_border.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_grunge.bsmat",
	"actors/weapons/hyperbeam/fx/imats/zerolaser_head_core.bsmat",
	"actors/weapons/hyperbeam/fx/imats/zerolaser_head_pink.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeam_projectile_boder_03.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_floor.bsmat",
	"actors/characters/samus/fx/imats/speedbooster_spin_smoke.bsmat",
	"actors/characters/samus/models/imats/samusgravity_mp_fresnelmtl00_shaft2.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_wave.bsmat",
	"actors/weapons/powerbeam/models/imats/powerbeam_projectile_center.bsmat",
	"actors/characters/samus/fx/imats/speedbooster_cover_air.bsmat",
	"actors/characters/samus/fx/imats/speedbooster_spin_blue.bsmat",
	"actors/characters/samus/models/imats/samusgravity_mp_fresnelmtl00_shaft.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_air.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_border.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_grunge.bsmat",
	"actors/weapons/hyperbeam/fx/imats/zerolaser_border.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedball_helix.bsmat",
	"actors/weapons/wavebeam/fx/imats/wavebeam_chargedball_waves.bsmat",
	"actors/characters/samus/models/imats/samuspower_mp_fresnelmtl00_shaft2.bsmat",
	"actors/characters/samus/models/imats/samusvaria_mp_fresnelmtl00_shaft2.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_charge_floorsmoke_smoke.bsmat",
	"actors/characters/samus/models/imats/samuspower_mp_fresnelmtl00_shaft.bsmat",
	"actors/characters/samus/models/imats/samusvaria_mp_fresnelmtl00_shaft.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_base.bsmat",
	"actors/weapons/hyperbeam/fx/imats/zerolaser_core.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_floorsmokes_smokes.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_projectile_energy.bsmat",
	"system/fx/generic/imats/savecards_basic_mp_fxmeshmtl00_cardsbasic.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_shoulderenergy_forest.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_projectile_waves.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_shoulderenergy_magma.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_projectile_wind.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_shoulderenergy_sanc.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_impact_bigimpact.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_projectile_air.bsmat",
	"system/fx/generic/imats/savecards_chozocards_mp_fxmeshmtl00_chozocards.bsmat",
	"system/fx/generic/imats/savecards_general_mp_fxmeshmtl00_feets.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_shoulderenergy_lab.bsmat",
	"actors/props/teleporter/fx/imats/bigtrail_teleport_mp_bigtrailteleport.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_chargeenergy_air.bsmat",
	"actors/characters/samus/fx/imats/hyperspark_cap_cap.bsmat",
	"actors/props/teleporter/fx/imats/reverse_bigtrail_mp_reversebigtrail.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_impact_impact.bsmat",
	"system/fx/generic/imats/rings_teleport_mp_fxmeshmtl00_ringsteleport.bsmat",
	"system/fx/generic/imats/save_mesh_end_mp_fxmeshmtl00_cards.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_impact_cover.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_shoulderenergy.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_shoulderenergy_shipyard.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_wave.bsmat",
	"actors/weapons/plasmabeam/fx/imats/auras_chargeprojectile_aurasarm.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_upperarm_shipyard.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_burstglow.bsmat",
	"actors/weapons/plasmabeam/fx/imats/auras_chargeprojectile_armaura.bsmat",
	"system/fx/generic/imats/save_mesh_mp_fxmeshmtl00_cards.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_forearm_shipyard.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_upperarm_forest.bsmat",
	"actors/weapons/hyperbeam/fx/imats/zerolaser_border_border.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_dashshot_dashshot.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_upperarm_magma.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_chargeenergy_energy.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_3d_twist.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_cannonold_magma.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_forearm_forest.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_upperarm_sanc.bsmat",
	"actors/weapons/hyperbeam/fx/imats/zerolaser_core_orange.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_cannonold_cave.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_cannonold_sanc.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_forearm_magma.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_upperarm_lab.bsmat",
	"actors/props/teleporter/fx/imats/teleport_trails_mp_trailstp.bsmat",
	"system/fx/generic/imats/save_mesh_end_mp_fxmeshmtl00_base.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_cannonold_lab.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_forearm_sanc.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_thigh_shipyard.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_master_magma.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_forearm_lab.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_calf_shipyard.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_master_cave.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_master_sanc.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_thigh_forest.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_master_lab.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_thigh_magma.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_upperarm.bsmat",
	"system/fx/generic/imats/save_mesh_mp_fxmeshmtl00_base.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_calf_forest.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_cannonold.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_thigh_sanc.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/cannon_energy_cannonold.bsmat",
	"actors/characters/samus/fx/imats/absortion_metroidnization_absortion.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_calf_magma.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_forearm.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_thigh_lab.bsmat",
	"system/fx/generic/imats/rings_teleport_mp_ringmedium.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_calf_sanc.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_xray.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_calf_lab.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_master.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/cannon_energy_master.bsmat",
	"actors/characters/morphball/fx/imats/grab_kraid_vel_trail.bsmat",
	"actors/weapons/specialrocket/models/imats/specialburst_rocketprojectile_mp_fxmeshmtl00_cap.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_thigh.bsmat",
	"actors/characters/chozowarriorx/fx/imats/dashshot_dashshot.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_shoulderenergy.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_calf.bsmat",
	"actors/characters/samus/fx/imats/absortion_parasite_absortion.bsmat",
	"cutscenes/0003firstcomunicationfakeadam/fx/imats/energytube_energytube.bsmat",
	"cutscenes/0003firstcomunicationfakeadam/fx/imats/tubelighting_tubelighting.bsmat",
	"actors/weapons/powerbomb/fx/imats/explosion_explosion.bsmat",
	"actors/characters/xparasite/models/imats/xparasite_interior.bsmat",
	"actors/characters/chozocommander/fx/imats/ultimategrab_samus_counter_seq2_turn_counter.bsmat",
	"actors/characters/samus/fx/imats/speedbooster_start_energy.bsmat",
	"actors/characters/chozocommander/fx/imats/shootinggrab_samus_counter_kistrike_counter.bsmat",
	"actors/characters/xparasite/models/imats/xparasite_body.bsmat",
	"actors/characters/chozocommander/fx/imats/ultimategrab_samus_counter_seq1_counter.bsmat",
	"actors/characters/chozocommander/fx/imats/ultimategrab_samus_counter_seq2_counter.bsmat",
	"actors/characters/morphball/fx/imats/opticalcamo.bsmat",
	"actors/characters/samus/fx/imats/opticalcamo.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_end_shoulderenergy_forest.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_end_shoulderenergy_magma.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_burstcone_line.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_end_shoulderenergy_sanc.bsmat",
	"actors/characters/samus/fx/imats/shinespark_launchcone_line.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_end_shoulderenergy_lab.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_end_shoulderenergy.bsmat",
	"actors/characters/samus/fx/imats/shoulder_energy_emmy_end_shoulderenergy_shipyard.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_end_upperarm_shipyard.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_end_forearm_shipyard.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_end_upperarm_forest.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_burstcone_air.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_end_upperarm_magma.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_end_forearm_forest.bsmat",
	"actors/characters/samus/fx/imats/shinespark_launchcone_air.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_end_upperarm_sanc.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_end_forearm_magma.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_end_upperarm_lab.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_init_cannon_magma.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_end_forearm_sanc.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_end_thigh_shipyard.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodyshort_shipyard.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_init_cannon_cave.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_init_cannon_sanc.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_end_forearm_lab.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodylong_shipyard.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_end_calf_shipyard.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_init_cannon_lab.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_end_thigh_forest.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodyshort_forest.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_end_thigh_magma.bsmat",
	"actors/characters/samus/fx/imats/upperarm_energy_end_upperarm.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodylong_forest.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodyshort_magma.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_end_calf_forest.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_end_thigh_sanc.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodylong_magma.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodyshort_sanc.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_end_calf_magma.bsmat",
	"actors/characters/samus/fx/imats/forearm_energy_end_forearm.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_end_thigh_lab.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodylong_sanc.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodyshort_lab.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_end_calf_sanc.bsmat",
	"actors/characters/samus/fx/imats/cannon_energy_init_cannon.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/cannon_energy_init_cannon.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodylong_lab.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_end_calf_lab.bsmat",
	"actors/characters/samus/fx/imats/thigh_energy_end_thigh.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodyshort.bsmat",
	"actors/characters/samus/fx/imats/body_energy_bodylong.bsmat",
	"actors/characters/samus/fx/imats/calf_energy_end_calf.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_lines_shipyard.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_line_shipyard.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_lines_forest.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_line_forest.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_lines_magma.bsmat",
	"actors/characters/samus/fx/imats/planesonar.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_line_magma.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_lines_sanc.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_line_sanc.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_lines_lab.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_line_lab.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_lines.bsmat",
	"actors/characters/samus/fx/imats/hand_absortion_emmy_line.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_chargedprojectile_projectile_rays.bsmat",
	"actors/weapons/specialburst/models/imats/specialburst_ball_mp_lightningmtl00_rays02.bsmat",
	"actors/weapons/specialburst/models/imats/specialburst_ball_mp_lightningmtl00_rays03.bsmat",
	"actors/weapons/specialburst/models/imats/specialburst_ball_mp_lightningmtl00_rays04.bsmat",
	"actors/weapons/specialburst/models/imats/specialburst_ball_mp_lightningmtl00_rays.bsmat",
	"actors/characters/samus/models/imats/magnetglove_rays_mp_fresnelmtl00_rays.bsmat",
	"actors/weapons/plasmabeam/fx/imats/plasmabeam_projectile_projectile_rays.bsmat",
	"actors/characters/samus/models/imats/samusgravity_mp_lightningmtl00_rays.bsmat",
	"actors/characters/samus/fx/imats/ray_trail_mp_lightningmtl00_rays02.bsmat",
	"actors/characters/samus/fx/imats/ray_trail_mp_lightningmtl00_rays03.bsmat",
	"actors/characters/samus/fx/imats/ray_trail_mp_lightningmtl00_rays04.bsmat",
	"actors/characters/samus/models/imats/samuspower_mp_lightningmtl00_rays.bsmat",
	"actors/characters/samus/models/imats/samusvaria_mp_lightningmtl00_rays.bsmat",
	"actors/characters/samus/fx/imats/ray_trail_mp_lightningmtl00_rays.bsmat",
	"actors/weapons/emmywave/fx/imats/wavebeamimpact.bsmat",
	"actors/characters/samus/fx/imats/rays_emmywave_raysemmywave.bsmat",
	"actors/characters/emmycave/fx/imats/rays_absortion_rays_emmy.bsmat",
	"actors/characters/samus/fx/imats/ocduringchasequad_material.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_charge_souls.bsmat",
	"actors/characters/samus/fx/imats/rays_hand_rays_hand.bsmat",
	"actors/weapons/lockonmissilemarker/fx/imats/lockon_marker_material.bsmat",
	"actors/characters/morphball/fx/imats/emmywave_emmywave.bsmat",
	"actors/weapons/grapplebeam/fx/imats/grapplebeam_core.bsmat",
	"actors/weapons/grapplebeam/fx/imats/grapplebeam_edge.bsmat",
	"actors/weapons/grapplebeam/fx/imats/grapplebeam_init.bsmat",
	"actors/weapons/specialburst/models/imats/specialburst_burstprojectile_mp_fresnelmtl00_projectile.bsmat",
	"actors/characters/samus/models/imats/samushyper_mp_lightningmtl00_rays.bsmat",
	"actors/characters/samus/fx/imats/ghostdash_trail.bsmat",
	"actors/weapons/specialburst/models/imats/specialburst_bursttail_mp_fresnelmtl00_tail2.bsmat",
	"actors/weapons/lockonmissilemarker/fx/imats/lockon_bloom_lockonbloom.bsmat",
	"system/fx/death/imats/frozen_dissolve_internal_material.bsmat",
	"maps/blocks/breakable_block_powerbeam/imats/blockrespawn_veins_mp_selfilumlineartransition_veins02.bsmat",
	"maps/blocks/breakable_block_powerbeam/imats/blockrespawn_veins_mp_selfilumlineartransition_veins.bsmat",
	"system/fx/death/imats/dissolve_internal_material.bsmat",
	"actors/weapons/lockonmissile/fx/imats/lockon_missile_trail_material.bsmat",
	"actors/characters/samus/fx/imats/meleefloorslide_scorpius_meleefloorslide.bsmat",
	"actors/weapons/hyperbeam/fx/imats/hyperbeam_impactplane.bsmat",
	"actors/characters/samus/fx/imats/meleefloorslide_meleefloorslide.bsmat",
	"actors/characters/samus/fx/imats/uppercut_trail_uppercuttrail.bsmat",
	"actors/weapons/specialrocket/fx/imats/specialrocket_cameradistortion_dashshot.bsmat",
	"actors/characters/samus/models/imats/fresnel.bsmat",
	"actors/characters/samus/fx/imats/meleerun_meleerun.bsmat",
	"system/fx/sonar/models/imats/sonarbreakabletile_material.bsmat",
	"system/fx/death/imats/frozen_dissolve_dir_material.bsmat",
	"actors/characters/samus/fx/imats/kraidgrab_trail.bsmat",
	"actors/characters/samus/fx/imats/melee_melee.bsmat",
	"system/fx/death/imats/dissolve_dir_material.bsmat",
	"actors/characters/morphball/models/imats/morphballgravity_sonar.bsmat",
	"actors/characters/samus/models/imats/samushyper_mp_fresnelmtl00_energy.bsmat",
	"actors/characters/samus/models/imats/samushyper_mp_fresnelmtl00_lines2.bsmat",
	"actors/characters/samus/models/imats/samushyper_mp_fresnelmtl00_shaft2.bsmat",
	"actors/characters/morphball/models/imats/morphballhyper_sonar.bsmat",
	"actors/characters/morphball/models/imats/morphballpower_sonar.bsmat",
	"actors/characters/morphball/models/imats/morphballvaria_sonar.bsmat",
	"actors/characters/samus/models/imats/samushyper_mp_fresnelmtl00_shaft.bsmat",
	"actors/characters/samus/models/imats/samusgravity_sonar.bsmat",
	"actors/characters/samus/models/imats/samuspower_sonar.bsmat",
	"actors/characters/samus/models/imats/samusvaria_sonar.bsmat",
	"system/fx/laser/imats/lasersp_material.bsmat",
	"system/fx/laser/imats/laser_material.bsmat",
	"system/fx/sonar/custommaterials/sonarbreakableorganic.bsmat",
	"actors/characters/samus/fx/imats/animfresnel_vertical.bsmat",
	"actors/characters/samus/fx/imats/handfresnel_emmy.bsmat",
	"actors/weapons/powerbomb/fx/imats/burnexplosion_saturate.bsmat",
	"actors/characters/samus/fx/damage.bsmat",
	"actors/characters/samus/models/imats/samusgravity_fxmetroidglove01.bsmat",
	"actors/characters/samus/models/imats/samushyper_fxmetroidglove01.bsmat",
	"actors/characters/samus/fx/imats/savestation_fresnel.bsmat",
	"cutscenes/0048firstcupowerobtention/fx/imats/cannon_fresnel.bsmat",
	"actors/characters/samus/fx/imats/teleportfresnel.bsmat",
	"actors/weapons/lockonmissile/fx/imats/lockon_target_material.bsmat",
	"actors/characters/samus/fx/imats/cannon_fresnel_trail_cannon.bsmat",
	"actors/characters/samus/fx/imats/sonar_sphere_explosionsonar.bsmat",
	"actors/characters/samus/fx/imats/fresnel_light_renderlayer.bsmat",
	"actors/weapons/powerbomb/fx/imats/powerbomb_purefresnel.bsmat",
	"actors/characters/morphball/fx/imats/powerbomb_fresnel.bsmat",
	"actors/characters/samus/fx/imats/death_plane_material.bsmat",
	"maps/blocks/breakable_block_screwattack/imats/breakable_block_screwattack_mp_opaque_01.bsmat",
	"maps/blocks/breakable_block_speedbuster/imats/breakable_block_speedbuster_mp_opaque_01.bsmat",
	"maps/blocks/breakable_block_powerbomb/imats/breakable_block_powerbomb_mp_opaque_01.bsmat",
	"maps/blocks/breakable_block_missile/imats/breakable_block_missile_mp_opaque_01.bsmat",
	"maps/blocks/breakable_block_supermissile/imats/breakable_block_supermissile_mp_opaque_01.bsmat",
	"maps/blocks/breakable_block_weight/imats/breakable_block_weight_mp_opaque_01.bsmat",
	"actors/props/teleporter/models/imats/teleporter_teleporter_cables_frozen.bsmat",
	"actors/props/teleporter/models/imats/teleporter_teleportertorre.bsmat",
	"actors/props/teleporter/models/imats/teleporter_teleportertorre_frozen.bsmat",
	"actors/props/teleporter/models/imats/teleporter_teleporterbase_frozen.bsmat",
	"maps/blocks/breakable_block_powerbeam/imats/breakable_block_powerbeam_mp_opaque_fade.bsmat",
	"actors/props/teleporter/models/imats/teleporter_teleporterbase_cables.bsmat",
	"actors/props/teleporter/models/imats/teleporter_teleporterbase.bsmat",
	"actors/props/barelyice/models/imats/barelyice00_strong_material.bsmat",
	"actors/props/barelyice/models/imats/barelyice01_strong_material.bsmat",
	"actors/props/barelyice/models/imats/barelyice02_strong_material.bsmat",
	"actors/props/barelyice/models/imats/barelyice00_weak_material.bsmat",
	"actors/props/barelyice/models/imats/barelyice01_weak_material.bsmat",
	"actors/props/barelyice/models/imats/barelyice02_weak_material.bsmat",
	"maps/blocks/breakable_block_powerbeam/imats/breakable_block_powerbeam_mp_opaque_01.bsmat",
	"maps/blocks/breakable_block_bomb/imats/breakable_block_bomb_mp_opaque_01.bsmat",
	"actors/props/teleporter/models/imats/teleporter_teleporterdirection.bsmat",
	"system/engine/prjdecals/shotimpact00_def.bsmat",
	"system/engine/prjdecals/shotimpact01_def.bsmat",
	"system/engine/prjdecals/shotimpact00_ble.bsmat",
	"actors/items/drop_life/fx/imats/drop_life.bsmat",
	"actors/items/item_minix/imats/item_minix.bsmat",
	"system/fx/custommaterials/immune_blink.bsmat",
	"system/fx/custommaterials/immune.bsmat",
	"actors/items/item_ammo/imats/item_glow.bsmat",
	"actors/items/item_ammo/imats/item_ammo.bsmat",
]

@pytest.mark.parametrize("bsmat_path", all_bsmat)
def test_compare_dread_all(dread_file_tree, bsmat_path):
    parse_build_compare_editor(BSMAT, dread_file_tree, bsmat_path)